(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    403218,       7311]
NotebookOptionsPosition[    395916,       7198]
NotebookOutlinePosition[    396475,       7219]
CellTagsIndexPosition[    396432,       7216]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2f94b440-0b22-4549-b621-663571594013"],

Cell["Chapter 3, Section 3.8", "Section",ExpressionUUID->"cd88c690-521f-4a4c-89d1-d50dc4c2e993"],

Cell[TextData[{
 "Here we start by making use of the function ",
 StyleBox["Stability", "Input"],
 " (see ",
 StyleBox["Sect.3.7.nb",
  FontWeight->"Bold"],
 ") which returns, among other things, an analytical solution for motion \
around the chosen equilibrium point."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"22138f82-0454-4f6e-a6ad-84b75922f3f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Stability", "[", 
   RowBox[{"\[Mu]_", ",", " ", "ptid_Integer", ",", " ", 
    RowBox[{"{", 
     RowBox[{"X0_", ",", " ", "Y0_"}], "}"}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", " ", "r1", ",", " ", "r2", ",", " ", 
      RowBox[{"\[Mu]1", "=", 
       RowBox[{"1", "-", "\[Mu]"}]}], ",", " ", 
      RowBox[{"\[Mu]2", "=", "\[Mu]"}], ",", " ", "lageq"}], "}"}], ",", "\n", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"y", "=", "0"}], ";", "\n", "  ", 
        RowBox[{"\[Alpha]", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\n", "  ", 
        RowBox[{"r20", "=", 
         RowBox[{"\[Alpha]", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}], "*", 
           RowBox[{"\[Alpha]", "^", "2"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "9"}], ")"}], "*", 
           RowBox[{"\[Alpha]", "^", "3"}]}]}]}], ";", "\n", "  ", 
        RowBox[{"lageq", "=", 
         RowBox[{
          RowBox[{"\[Mu]1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "-", "r2"}], ")"}], "^", "2"}]}]}], ")"}]}], "-", 
          RowBox[{"\[Mu]2", "*", 
           RowBox[{"(", 
            RowBox[{"r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{"r2", "^", "2"}]}]}], ")"}]}]}]}], ";", "\n", "  ", 
        RowBox[{"r2", "=", 
         RowBox[{"r2", "/.", 
          RowBox[{"FindRoot", "[", 
           RowBox[{
            RowBox[{"lageq", "\[Equal]", "0"}], ",", 
            RowBox[{"{", 
             RowBox[{"r2", ",", "r20"}], "}"}]}], "]"}]}]}], ";", "\n", "  ", 
        
        RowBox[{"r1", "=", 
         RowBox[{"1", "-", "r2"}]}], ";", "\n", "  ", 
        RowBox[{"x", "=", 
         RowBox[{"\[Mu]1", "-", "r2"}]}]}]}], "]"}], ";", "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", "\[Equal]", "2"}], ",", 
       RowBox[{
        RowBox[{"y", "=", "0"}], ";", "\n", "  ", 
        RowBox[{"\[Alpha]", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\n", "  ", 
        RowBox[{"r20", "=", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}], "*", 
           RowBox[{"\[Alpha]", "^", "2"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "9"}], ")"}], "*", 
           RowBox[{"\[Alpha]", "^", "3"}]}]}]}], ";", "\n", "  ", 
        RowBox[{"lageq", "=", 
         RowBox[{
          RowBox[{"\[Mu]1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "r2"}], ")"}], "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]2", "*", 
           RowBox[{"(", 
            RowBox[{"r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{"r2", "^", "2"}]}]}], ")"}]}]}]}], ";", "\n", "  ", 
        RowBox[{"r2", "=", 
         RowBox[{"r2", "/.", 
          RowBox[{"FindRoot", "[", 
           RowBox[{
            RowBox[{"lageq", "\[Equal]", "0"}], ",", 
            RowBox[{"{", 
             RowBox[{"r2", ",", "r20"}], "}"}]}], "]"}]}]}], ";", "\n", "  ", 
        
        RowBox[{"r1", "=", 
         RowBox[{"1", "+", "r2"}]}], ";", "\n", "  ", 
        RowBox[{"x", "=", 
         RowBox[{"\[Mu]1", "+", "r2"}]}]}]}], "]"}], ";", "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", "\[Equal]", "3"}], ",", 
       RowBox[{
        RowBox[{"y", "=", "0"}], ";", "\n", "  ", 
        RowBox[{"\[Beta]", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"7", "/", "12"}], ")"}]}], "*", 
           RowBox[{"(", 
            RowBox[{"\[Mu]2", "/", "\[Mu]1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"7", "/", "12"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Mu]2", "/", "\[Mu]1"}], ")"}], "^", "2"}]}]}]}], ";", 
        "\n", "  ", 
        RowBox[{"r10", "=", 
         RowBox[{"1", "+", "\[Beta]"}]}], ";", "\n", "  ", 
        RowBox[{"lageq", "=", 
         RowBox[{
          RowBox[{"\[Mu]1", "*", 
           RowBox[{"(", 
            RowBox[{"r1", "-", 
             RowBox[{"1", "/", 
              RowBox[{"r1", "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]2", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "r1", "-", 
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "r1"}], ")"}], "^", "2"}]}]}], ")"}]}]}]}], 
        ";", "\n", "  ", 
        RowBox[{"r1", "=", 
         RowBox[{"r1", "/.", 
          RowBox[{"FindRoot", "[", 
           RowBox[{
            RowBox[{"lageq", "\[Equal]", "0"}], ",", 
            RowBox[{"{", 
             RowBox[{"r1", ",", "r10"}], "}"}]}], "]"}]}]}], ";", "\n", "  ", 
        
        RowBox[{"r2", "=", 
         RowBox[{"1", "+", "r1"}]}], ";", " ", 
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"-", "r1"}], "-", "\[Mu]2"}]}]}]}], "]"}], ";", "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", "\[Equal]", "4"}], ",", 
       RowBox[{
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "-", "\[Mu]2"}]}], ";", "\n", "  ", 
        RowBox[{"y", "=", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "]"}]}], ";", "\n", 
        "  ", 
        RowBox[{"r1", "=", "1"}], ";", "\n", "  ", 
        RowBox[{"r2", "=", "1"}]}]}], "]"}], ";", "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", "\[Equal]", "5"}], ",", 
       RowBox[{
        RowBox[{"x", "=", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "-", "\[Mu]2"}]}], ";", "\n", "    ", 
        RowBox[{"y", "=", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "2"}], "]"}]}], ";", "\n",
         "    ", 
        RowBox[{"r1", "=", "1"}], ";", "\n", "    ", 
        RowBox[{"r2", "=", "1"}]}]}], "]"}], ";", "\n", 
     RowBox[{"Print", "[", 
      RowBox[{
      "\"\<Mass ratio = \>\"", ",", " ", "\[Mu]", ",", "\"\<\\n\>\""}], "]"}],
      ";", "\n", 
     RowBox[{"Print", "[", 
      RowBox[{
      "\"\<Lagrangian Point \>\"", ",", " ", "ptid", ",", "\"\<\\n\>\""}], 
      "]"}], ";", "\n", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<{x0, y0} = \>\"", ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], ",", "\"\<\\n\>\""}], "]"}], ";", 
     "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ptid", " ", "==", " ", "1"}], " ", "||", " ", 
        RowBox[{"ptid", " ", "==", " ", "2"}], " ", "||", " ", 
        RowBox[{"ptid", " ", "==", "3"}]}], ",", "\n", "   ", 
       RowBox[{
        RowBox[{"abar", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Mu]"}], ")"}], "/", 
           RowBox[{"r1", "^", "3"}]}], " ", "+", " ", 
          RowBox[{"\[Mu]", "/", 
           RowBox[{"r2", "^", "3"}]}]}]}], ";", "\n", "   ", 
        RowBox[{"ceqq", " ", "=", " ", 
         RowBox[{
          RowBox[{"\[Lambda]", "^", "4"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "-", "abar"}], ")"}], "*", 
           RowBox[{"\[Lambda]", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "abar", "-", 
            RowBox[{"2", "*", 
             RowBox[{"abar", "^", "2"}]}]}], ")"}]}]}], ";", "\n", "   ", 
        RowBox[{"soln", " ", "=", " ", 
         RowBox[{"Chop", "[", 
          RowBox[{"\[Lambda]", " ", "/.", " ", 
           RowBox[{"NSolve", "[", 
            RowBox[{
             RowBox[{"ceqq", " ", "==", " ", "0"}], ",", " ", 
             RowBox[{"{", "\[Lambda]", "}"}]}], "]"}]}], "]"}]}]}]}], "]"}], 
     ";", "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ptid", " ", "==", " ", "4"}], " ", "||", " ", 
        RowBox[{"ptid", " ", "==", " ", "5"}]}], ",", "\n", "   ", 
       RowBox[{
        RowBox[{"ceqq", " ", "=", " ", 
         RowBox[{
          RowBox[{"\[Lambda]", "^", "4"}], " ", "+", " ", 
          RowBox[{"\[Lambda]", "^", "2"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"27", "/", "4"}], ")"}], "*", "\[Mu]2", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Mu]2"}], ")"}]}]}]}], ";", "\n", "   ", 
        RowBox[{"soln", " ", "=", " ", 
         RowBox[{"Chop", "[", 
          RowBox[{"\[Lambda]", " ", "/.", " ", 
           RowBox[{"NSolve", "[", 
            RowBox[{
             RowBox[{"ceqq", " ", "==", " ", "0"}], ",", " ", 
             RowBox[{"{", "\[Lambda]", "}"}]}], "]"}]}], "]"}]}]}]}], "]"}], 
     ";", "\n", 
     RowBox[{"abar", " ", "=", " ", 
      RowBox[{
       RowBox[{"\[Mu]1", "/", 
        RowBox[{"r1", "^", "3"}]}], " ", "+", " ", 
       RowBox[{"\[Mu]2", "/", 
        RowBox[{"r2", "^", "3"}]}]}]}], ";", "\n", 
     RowBox[{"cbar", " ", "=", " ", 
      RowBox[{"3", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]1", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "+", "\[Mu]2"}], ")"}], "/", 
           RowBox[{"r1", "^", "5"}]}]}], " ", "+", " ", 
         RowBox[{"\[Mu]2", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "-", "\[Mu]1"}], ")"}], "/", 
           RowBox[{"r2", "^", "5"}]}]}]}], ")"}], "*", "y"}]}], ";", "\n", 
     RowBox[{"dbar", " ", "=", " ", 
      RowBox[{"3", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]1", "*", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "+", "\[Mu]2"}], ")"}], "^", "2"}], "/", 
           RowBox[{"r1", "^", "5"}]}]}], " ", "+", " ", 
         RowBox[{"\[Mu]2", "*", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "\[Mu]1"}], ")"}], "^", "2"}], "/", 
           RowBox[{"r2", "^", "5"}]}]}]}], ")"}]}]}], ";", "\n", 
     RowBox[{"uxx", " ", "=", " ", 
      RowBox[{"1", " ", "-", " ", "abar", " ", "+", " ", "dbar"}]}], ";", 
     "\n", 
     RowBox[{"uxy", " ", "=", " ", "cbar"}], ";", "\n", 
     RowBox[{"Print", "[", "\"\<Eigenvalues :\>\"", "]"}], ";", "\n", 
     RowBox[{"Print", "[", 
      RowBox[{
       RowBox[{"ColumnForm", "[", "soln", "]"}], ",", "\"\<\\n\>\""}], "]"}], 
     ";", "\n", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"s", "[", "i", "]"}], " ", "=", " ", 
        RowBox[{"soln", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], ";", "\n", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"b", "[", "i", "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"s", "[", "i", "]"}], "^", "2"}], " ", "-", " ", "uxx"}], 
          ")"}], "*", 
         RowBox[{
          RowBox[{"a", "[", "i", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "*", 
             RowBox[{"s", "[", "i", "]"}]}], " ", "+", " ", "uxy"}], 
           ")"}]}]}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], ";", "\n", 
     RowBox[{"eq1", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "[", "1", "]"}], " ", "+", " ", 
        RowBox[{"a", "[", "2", "]"}], " ", "+", " ", 
        RowBox[{"a", "[", "3", "]"}], " ", "+", " ", 
        RowBox[{"a", "[", "4", "]"}]}], " ", "==", " ", "X0"}]}], ";", "\n", 
     RowBox[{"eq2", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"b", "[", "1", "]"}], " ", "+", " ", 
        RowBox[{"b", "[", "2", "]"}], " ", "+", " ", 
        RowBox[{"b", "[", "3", "]"}], " ", "+", " ", 
        RowBox[{"b", "[", "4", "]"}]}], " ", "==", " ", "Y0"}]}], ";", "\n", 
     RowBox[{"eq3", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "*", 
         RowBox[{"a", "[", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "*", 
         RowBox[{"a", "[", "2", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "[", "3", "]"}], "*", 
         RowBox[{"a", "[", "3", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "[", "4", "]"}], "*", 
         RowBox[{"a", "[", "4", "]"}]}]}], " ", "==", " ", "0"}]}], ";", "\n", 
     RowBox[{"eq4", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "*", 
         RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "*", 
         RowBox[{"b", "[", "2", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "[", "3", "]"}], "*", 
         RowBox[{"b", "[", "3", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "[", "4", "]"}], "*", 
         RowBox[{"b", "[", "4", "]"}]}]}], " ", "==", " ", "0"}]}], ";", "\n", 
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Chop", "[", 
        RowBox[{"NSolve", "[", "\n", "         ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "eq4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a", "[", "1", "]"}], ",", " ", 
            RowBox[{"a", "[", "2", "]"}], ",", " ", 
            RowBox[{"a", "[", "3", "]"}], ",", " ", 
            RowBox[{"a", "[", "4", "]"}]}], "}"}]}], "]"}], "]"}], "]"}]}], 
     ";", "\n", 
     RowBox[{"asol", " ", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "[", "1", "]"}], ",", " ", 
         RowBox[{"a", "[", "2", "]"}], ",", " ", 
         RowBox[{"a", "[", "3", "]"}], ",", " ", 
         RowBox[{"a", "[", "4", "]"}]}], "}"}], " ", "/.", " ", "sol"}]}], 
     ";", "\n", 
     RowBox[{"bsol", " ", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", "[", "1", "]"}], ",", " ", 
         RowBox[{"b", "[", "2", "]"}], ",", " ", 
         RowBox[{"b", "[", "3", "]"}], ",", " ", 
         RowBox[{"b", "[", "4", "]"}]}], "}"}], " ", "/.", " ", "sol"}]}], 
     ";", "\n", 
     RowBox[{"Print", "[", "\"\<\\nValues of \[Alpha] bar: \>\"", "]"}], ";", 
     "\n", 
     RowBox[{"Print", "[", 
      RowBox[{"ColumnForm", "[", "asol", "]"}], "]"}], ";", "\n", 
     RowBox[{"Print", "[", "\"\<\\nValues of \[Beta] bar: \>\"", "]"}], ";", 
     "\n", 
     RowBox[{"Print", "[", 
      RowBox[{"ColumnForm", "[", "bsol", "]"}], "]"}], ";", "\n", 
     RowBox[{
      RowBox[{"xx", "[", "t_", "]"}], " ", ":=", " ", "\n", 
      RowBox[{"Chop", "[", 
       RowBox[{"ComplexExpand", "[", "\n", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"a", "[", "1", "]"}], ",", " ", 
             RowBox[{"a", "[", "2", "]"}], ",", " ", 
             RowBox[{"a", "[", "3", "]"}], ",", " ", 
             RowBox[{"a", "[", "4", "]"}]}], "}"}], " ", ".", " ", "\n", 
           "    ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "1", "]"}], "*", "t"}], "]"}], ",", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "2", "]"}], "*", "t"}], "]"}], ",", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "3", "]"}], "*", "t"}], "]"}], ",", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "4", "]"}], "*", "t"}], "]"}]}], "}"}]}], 
          ")"}], " ", "/.", "\n", "sol"}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{
      RowBox[{"yy", "[", "t_", "]"}], " ", ":=", " ", "\n", 
      RowBox[{"Chop", "[", 
       RowBox[{"ComplexExpand", "[", "\n", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"b", "[", "1", "]"}], ",", " ", 
             RowBox[{"b", "[", "2", "]"}], ",", " ", 
             RowBox[{"b", "[", "3", "]"}], ",", " ", 
             RowBox[{"b", "[", "4", "]"}]}], "}"}], " ", ".", " ", "\n", 
           "    ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "1", "]"}], "*", "t"}], "]"}], ",", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "2", "]"}], "*", "t"}], "]"}], ",", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "3", "]"}], "*", "t"}], "]"}], ",", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"s", "[", "4", "]"}], "*", "t"}], "]"}]}], "}"}]}], 
          ")"}], " ", "/.", "\n", "sol"}], "]"}], "]"}]}], ";", "\n", 
     RowBox[{"Print", "[", "\"\<\\nX(t) = \>\"", "]"}], ";", "\n", 
     RowBox[{"Print", "[", 
      RowBox[{"xx", "[", "t", "]"}], "]"}], ";", "\n", 
     RowBox[{"Print", "[", "\"\<\\nY(t) = \>\"", "]"}], ";", "\n", 
     RowBox[{"Print", "[", 
      RowBox[{
       RowBox[{"yy", "[", "t", "]"}], ",", "\"\<\\n\>\""}], "]"}]}]}], "\n", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8909065306292257`*^9, 3.890906530633108*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"11f557bb-9f19-4495-b68f-312ee23bfca5"],

Cell["\<\
We are going to study the solution around the L4 point for a mass ratio of \
0.01.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1aaca9fd-8d64-4bdf-93bd-0c9a00847cff"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Stability", "[", 
  RowBox[{"0.01", ",", " ", "4", ",", " ", 
   RowBox[{"{", 
    RowBox[{"0.00001", ",", "0.00001"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.890906542829249*^9, 3.890906542833267*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"986f690b-3764-4de8-9c1b-f10617aa1ca7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mass ratio = \"\>", "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Mass ratio = ", 0.01, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.890906815113031*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"fae314b1-e9b8-4556-8f7d-ec60101da6ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Lagrangian Point \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Lagrangian Point ", 4, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.890906815118905*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"804e8b71-0b1e-49f9-b290-e052472f133d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{x0, y0} = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.49`", ",", "0.8660254037844386`"}], "}"}], 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["{x0, y0} = ", {0.49, 0.8660254037844386}, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.890906815123555*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"a2ba7201-51d9-4540-9bd4-323cb544dc28"],

Cell[BoxData["\<\"Eigenvalues :\"\>"], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.8909068151278057`*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"559e1d09-f9c0-459c-9307-2c4e6884f309"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   InterpretationBox[GridBox[{
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"0.26834774854251275`", " ", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.26834774854251275`", " ", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"0.9633221090850995`", " ", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.9633221090850995`", " ", "\[ImaginaryI]"}]}]}
     },
     BaselinePosition->{Baseline, {1, 1}},
     GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
    ColumnForm[{
      Complex[0., -0.26834774854251275`], 
      Complex[0., 0.26834774854251275`], 
      Complex[0., -0.9633221090850995], 
      Complex[0., 0.9633221090850995]}],
    Editable->False], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm[
   ColumnForm[{
     Complex[0., -0.26834774854251275`], 
     Complex[0., 0.26834774854251275`], 
     Complex[0., -0.9633221090850995], 
     Complex[0., 0.9633221090850995]}], "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.8909068151319933`*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"3ac98d6d-d8a1-44b0-91a9-8e6540e5e594"],

Cell[BoxData["\<\"\\nValues of \[Alpha] bar: \"\>"], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.890906815136808*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"c6dd3b3b-ff04-43e1-9b1e-ce54d0da0818"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{"0.000017237846529918217`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00015337644256131216`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{"0.00001723784652991825`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.00015337644256131213`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.00001223784652991822`"}], "-", 
      RowBox[{"0.00004272529681673925`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.000012237846529918234`"}], "+", 
      RowBox[{"0.000042725296816739246`", " ", "\[ImaginaryI]"}]}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
  ColumnForm[{
    Complex[0.000017237846529918217`, 0.00015337644256131216`], 
    Complex[0.00001723784652991825, -0.00015337644256131213`], 
    Complex[-0.00001223784652991822, -0.00004272529681673925], 
    Complex[-0.000012237846529918234`, 0.000042725296816739246`]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.890906815141436*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"657365bb-6bca-4052-a2e2-e31c36af7cc4"],

Cell[BoxData["\<\"\\nValues of \[Beta] bar: \"\>"], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.89090681514585*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"0c15eebe-1b9e-4709-80b6-658a4744bfc5"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{"0.000025999744015632008`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.00008807388248169476`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{"0.00002599974401563198`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00008807388248169474`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.000020999744015632002`"}], "+", 
      RowBox[{"0.000024534294237061656`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.000020999744015631988`"}], "-", 
      RowBox[{"0.00002453429423706166`", " ", "\[ImaginaryI]"}]}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
  ColumnForm[{
    Complex[0.000025999744015632008`, -0.00008807388248169476], 
    Complex[0.00002599974401563198, 0.00008807388248169474], 
    Complex[-0.000020999744015632002`, 0.000024534294237061656`], 
    Complex[-0.000020999744015631988`, -0.00002453429423706166]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.890906815150597*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"061659e2-1b04-430d-a372-7d8a2bf41bb8"],

Cell[BoxData["\<\"\\nX(t) = \"\>"], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.890906815154982*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"c9e89a72-843b-45f4-8fc9-6d08f2932e82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.00003447569305983647`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
  RowBox[{"0.000024475693059836455`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}], "+", 
  RowBox[{"0.00030675288512262426`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2.710505431213761`*^-20", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
     RowBox[{"6.776263578034403`*^-21", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}], "+", 
     RowBox[{"3.3881317890172014`*^-20", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
     RowBox[{"1.3552527156068805`*^-20", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"0.00008545059363347849`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.8909068151600523`*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"d5032ad2-c676-48e5-bd4b-92eb24aed269"],

Cell[BoxData["\<\"\\nY(t) = \"\>"], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.8909068151646748`*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"72e84018-5ba5-486f-99ec-1f26755066f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"0.00005199948803126399`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00004199948803126399`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00017614776496338949`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1.3552527156068805`*^-20"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
       RowBox[{"3.3881317890172014`*^-21", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}], "-", 
       RowBox[{"2.710505431213761`*^-20", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "+", 
       RowBox[{"1.3552527156068805`*^-20", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.00004906858847412331`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm[
  0.00005199948803126399 Cos[0.26834774854251275` $CellContext`t] - 
   0.00004199948803126399 Cos[0.9633221090850995 $CellContext`t] - 
   0.00017614776496338949` Sin[0.26834774854251275` $CellContext`t] + 
   Complex[0, 1] ((-1.3552527156068805`*^-20) 
      Cos[0.26834774854251275` $CellContext`t] - 3.3881317890172014`*^-21 
     Cos[0.9633221090850995 $CellContext`t] - 2.710505431213761*^-20 
     Sin[0.26834774854251275` $CellContext`t] + 
     1.3552527156068805`*^-20 Sin[0.9633221090850995 $CellContext`t]) + 
   0.00004906858847412331 Sin[0.9633221090850995 $CellContext`t], "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.890906543414941*^9, 3.8909068151694517`*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"2e27b077-bf11-4bc3-b9d1-521cc24d55fc"]
}, Open  ]],

Cell[TextData[{
 "The X(t) and Y(t) solutions given above were stored internally in ",
 StyleBox["Stability", "Input"],
 " as ",
 StyleBox["xx[t]", "Input"],
 " and ",
 StyleBox["yy[t]", "Input"],
 ".  We can illustrate the fact that there are two fundamental motions by \
carrying out a rotation of 30\[Degree] clockwise about the equilibrium point. \
 First we define the rotation matrix, ",
 StyleBox["rot", "Input"],
 ". (see Eq.(3.152).)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"490dc328-b641-479c-9f8b-048489a96aef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rot", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"30", "\[Degree]"}], "]"}], ",", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"-", "30"}], "\[Degree]"}], "]"}]}], "}"}], ",", "\n", 
      "         ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"30", "\[Degree]"}], "]"}], ",", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"30", "\[Degree]"}], "]"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.890906557645824*^9, 3.89090655988822*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"0eef0f29-318f-4c4a-bb18-46fee837af82"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "rot", "]"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"6c319b7c-3a26-4433-bf72-87f84f0c086a"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.8660254037844386`", 
      RowBox[{"-", "0.5`"}]},
     {"0.5`", "0.8660254037844386`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.890906571625107*^9, 3.890906815215476*^9},
 CellLabel->
  "Out[4]//MatrixForm=",ExpressionUUID->"d0652c5c-15e7-4613-9285-\
ab92fde2a3cb"]
}, Open  ]],

Cell[TextData[{
 "Then we apply ",
 StyleBox["rot", "Input"],
 " to the functions ",
 StyleBox["xx[t]", "Input"],
 " and ",
 StyleBox["yy[t]", "Input"],
 ", \"chopping\" to remove any small imaginary parts.  (cf. Eq.(3.153).)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c3ea4aca-8947-405a-8563-68dabe003e3c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ctranxy", " ", "=", " ", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"rot", " ", ".", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xx", "[", "t", "]"}], ",", " ", 
        RowBox[{"yy", "[", "t", "]"}]}], "}"}]}], "]"}], ",", "0.00001"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.890906584051566*^9, 3.890906584055813*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"96e1baa3-d4ec-45ab-ab74-7f1915b35971"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.0003537296736820569`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00009853667909211485`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.00006227072414877771`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00004861047011093332`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}]}], "}"}]], "Output",\

 CellChangeTimes->{3.890906585135293*^9, 3.8909068152511044`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"a6565ba6-80d9-419c-b10e-d6d6fc9fed56"]
}, Open  ]],

Cell["\<\
Note that the ratio of the magnitude of the two short period terms is \
approximately 2, implying that the motion around the epicycle is \
approximately that of a 2:1 centred ellipse.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.856766522755649*^9, 3.856766523396735*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"89218f8e-d4b2-4db6-93ff-ac9e365124e6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"0.00009853667909211485", "/", "0.00004861047011093332"}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"88a1ef3e-9959-4db8-865c-e051331867ce"],

Cell[BoxData["2.027066985101061`"], "Output",
 CellChangeTimes->{3.890906605293912*^9, 3.890906815267981*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"994525ab-7e06-4526-ab56-5ec19c7b6923"]
}, Open  ]],

Cell["\<\
Plot the trajectory that results from the analytical solution for the motion \
around the equilibrium point.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7585e019-be2f-4dd6-8df2-272641ccd667"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"traj", "=", "\n", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "[", "t", "]"}], ",", 
      RowBox[{"yy", "[", "t", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"25", "Pi"}]}], "}"}], ",", "\n", 
    RowBox[{"PlotPoints", "->", "50"}], ",", "\n", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0005"}], ",", "0.0005"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.00025"}], ",", "0.00025"}], "}"}]}], "}"}]}], ",", 
    "\n", 
    RowBox[{"AspectRatio", "->", "0.5"}], ",", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.89090661751527*^9, 3.89090661751923*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"29c1c606-cf35-4f68-8504-18950ccfe9b2"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwsW3k41N/3tytLljBjNzOWGWbGGMbwiTmiREmSqEQISZQoypYUSpEsrdJK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       "]]},
     Annotation[#, "Charting`Private`Tag$3938#1"]& ]}, {}},
  AspectRatio->0.5,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-0.0005, 0.0005}, {-0.00025, 0.00025}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.890906618963254*^9, 3.890906816032529*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"098368ff-00a3-4c51-8feb-19baf8675152"]
}, Open  ]],

Cell[TextData[{
 "Now define a function ",
 StyleBox["czvn", "Input"],
 " that returns the value of the Jacobi constant of the zero velocity curve \
at the point ",
 StyleBox["(x,y)", "Input"],
 " where ",
 StyleBox["x", "Input"],
 " and ",
 StyleBox["y", "Input"],
 " are the coordinates referred to the L4 equilibrium point.  (See Eq.(3.39).)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9d1875ef-bbd4-46f4-9c19-380aefe1761e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"czvn", "[", 
    RowBox[{"x_", ",", "y_", ",", "\[Mu]_"}], "]"}], " ", ":=", "\n", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xn", " ", "=", " ", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"1", "/", "2"}], " ", "-", " ", "\[Mu]"}]}], ",", " ", 
       RowBox[{"yn", " ", "=", " ", 
        RowBox[{"y", " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}]}]}], "}"}], ",", " ", 
     "\n", 
     RowBox[{
      RowBox[{"xn", "^", "2"}], "+", 
      RowBox[{"yn", "^", "2"}], "+", "\n", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Mu]"}], ")"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xn", "+", "\[Mu]"}], ")"}], "^", "2"}], "+", 
            RowBox[{"yn", "^", "2"}]}], "]"}]}], " ", "+", " ", 
         RowBox[{"\[Mu]", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xn", "-", "1", "+", "\[Mu]"}], ")"}], "^", "2"}], "+", 
            
            RowBox[{"yn", "^", "2"}]}], "]"}]}]}], ")"}]}]}]}], "\n", "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.890906637253243*^9, 3.890906637257141*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"f9de7783-a154-439d-a9fe-3ef44dfcce95"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["jacobin", "Input"],
 " that gives the value of the Jacobi constant for a given position and \
velocity in the rotating frame and for a given mass ratio, ",
 StyleBox["\[Mu]", "Input"],
 ".  Note that the position ",
 StyleBox["(x,y)", "Input"],
 " and velocity ",
 StyleBox["(xd,yd)", "Input"],
 " are expressed with respect to the L4 point."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f8e2428b-d941-4728-b6aa-54a5f4e9cbc5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"jacobin", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_", ",", " ", "y_", ",", " ", "xd_", ",", " ", "yd_"}], "}"}],
      ",", " ", "\[Mu]_"}], "]"}], " ", ":=", " ", "\n", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xb", " ", "=", " ", 
        RowBox[{"x", "+", 
         RowBox[{"1", "/", "2"}], "-", "\[Mu]"}]}], ",", " ", 
       RowBox[{"yb", " ", "=", " ", 
        RowBox[{"y", " ", "+", " ", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "]"}]}]}]}], "}"}], 
     ",", "\n", 
     RowBox[{
      RowBox[{"xb", "^", "2"}], "+", 
      RowBox[{"yb", "^", "2"}], "-", 
      RowBox[{"xd", "^", "2"}], "-", 
      RowBox[{"yd", "^", "2"}], "+", " ", "\n", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Mu]", "+", "xb"}], ")"}], "^", 
             "2"}], "+", 
            RowBox[{"yb", "^", "2"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Mu]"}], ")"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Mu]", "+", "xb"}], ")"}], "^", "2"}], "+", 
            RowBox[{"yb", "^", "2"}]}], "]"}]}]}], ")"}]}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.890906650029386*^9, 3.890906650033348*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"f0938003-53e6-4a44-8930-a2989c1dd690"],

Cell[TextData[{
 "Calculate the value of the Jacobi constant for our trajectory by evaluating \
it at the starting point using ",
 StyleBox["jacobin", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7e5af23e-3594-45b7-ab02-f82d9baeb051"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jcon", " ", "=", " ", 
  RowBox[{"jacobin", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xx", "[", "0", "]"}], ",", " ", 
      RowBox[{"yy", "[", "0", "]"}], ",", " ", "0", ",", " ", "0"}], "}"}], 
    ",", " ", "0.01"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890906662890161*^9, 3.8909066628952923`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"81acda16-68dd-416a-8984-c882e0f4f55d"],

Cell[BoxData["2.990100000554607`"], "Output",
 CellChangeTimes->{3.890906663909051*^9, 3.890906816298118*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"e2e5f575-3d30-4495-ae23-0b7b36c221ce"]
}, Open  ]],

Cell["\<\
Plot the zero velocity curve for this value of the Jacobi constant.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e6417aae-5254-4a2f-8f40-8a4bad80feed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"zvcurve", "=", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"czvn", "[", 
      RowBox[{"x", ",", "y", ",", "0.01"}], "]"}], ",", "\n", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.0004"}], ",", "0.0004"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "0.0002"}], ",", "0.0002"}], "}"}], ",", 
     RowBox[{"PlotPoints", "->", "100"}], ",", "\n", 
     RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
     RowBox[{"Axes", "->", "None"}], ",", 
     RowBox[{"ContourStyle", "->", "Red"}], ",", "\n", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", "jcon", "}"}]}], ",", 
     RowBox[{"ContourShading", "->", "False"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.890906678076187*^9, 3.8909066780835333`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"0a7096ed-afa3-448c-882b-ca1a0285aa93"],

Cell["\<\
Plot the zero velocity curve and the trajectory on the same plot.  Note how \
the trajectory can touch but never cross the zero velocity curve.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d44321c0-761b-4129-af36-bfc1a9ee77ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trajcurve", "=", "\n", 
  RowBox[{"Show", "[", 
   RowBox[{"zvcurve", ",", "traj", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Point", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "]"}], "]"}], ",", 
    RowBox[{"Frame", "->", "False"}], ",", 
    RowBox[{"PlotRange", "->", "All"}], ",", "\n", 
    RowBox[{"AspectRatio", "->", "Automatic"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8909066905148773`*^9, 3.89090669052142*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"f30d5b27-bcca-4c30-80bb-4a10c98973a8"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxc3X/sv/tcx/Hjx3SSxeHg4OD4EU5CPw4i0Y/ZWlLN0mT5g2qUiWmV+MOK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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[1, 0, 0], Opacity[0.5], CapForm["Butt"], 
          LineBox[CompressedData["
1:eJwl1nfcj1UYx/GfLRGSImVUosfMKKRCCkkks2RVUsoWESEjlMqKkD1ShLLJ
JjORlT3LyoqE6H29+uPz+lzX+Z773Of53fd9Xk+epq1qtkyWSCS6JE8kJhRM
JMZgHMbiYfyYlEh8wIULJBLduBDXxw11PU6FJeYs07+kLoKGuKl/hdNgmXy5
vpH6YbyKZIUSiaacFsvlK+SvqYvhTaSQN+d0WClfJX9LXQJvI6W8Bd+KVfLV
8nfUJdEWqeVtOD3WyNfK26kfQae4r7wj34af5Ovk76lL4X3cIu/CmbBevl7e
VV0aPeK+8u6cGRvkG+Q91WXQJ+4r7823Y7N8s7yvuiw+jvvKB/Ad2CLfIv9E
/QQ+Q0b5p3wntsp/kX+ufhJD477yIXwXtsm3yoepy+EjdXnux9PxLcpip3k7
eFTcl7/iLNYZzY/rd8t38Xh9Vp4Ylk+Ifen3yHfz5NgXTw3Lp8S+9Hvlv/E3
sS/OwfuM7Yk9qCtiFrK7ZibfgwPyffLZ6qcxDznkc/leHJIfkM9XPxO/nXpg
/FaYhYo4as5hXiq/m5dzTmssizX1x+VHeXWszWs5t3xNrKmvhPXqPMbW8X34
wzXHjG9QV8XPuF++OYwT8uPyLern4pmpB8Uzwhw8i9PmnIjfPfYTvy8/aI1d
cY3+T/kp3hf74QOcX76fn9dX46NIMnaEH8A515yRHYs5GKweiiGYixdw0Zxz
cf+4Ju7Dhaxxhl/UX5Jf4AuxH87Ll41djGvV1TFfvQDz8HfMwxVzhum/QGd0
wfX4pq19jevqr5nzNyeQhHzGrxu7ok6GGvrhsU8ewYuwMM4O3DTvGqeNcwb5
zWkZ33WcDXhR35iboClaIbmxhpyCG3BzvIk3kCHOjDi7UAS3Ij1qxfcde499
qh/CYvUSfImacQbE2Yd0+Df2buxlTo0S/t40XBCpcBU37L1+7APF5Sm5QOwP
/8Qa8noxL844+c24b4zHbx9ryOvEXH1R+dV4F/RX+FKMy2vHs9MXkV/mfPq/
+K94RvJafE5fWH6e8+rP8vmYJ6/JJ/UF5afiPdaf4LPxLshr8O/6AvI/4juI
b4f/5PPy6nwo9i0/HN+L/iCfjvvIq8UZEfuS7+Vc+t/4JJ+RV+XtsS/5jvi+
9b/Gt8an5FV4a7yz8m1xPuh/4d9j3/LKvDH2Jd/E7+k7xbem/jT2bk4e9U+Y
rf8B36OKfhWOxHdjTm71itifdVZyZfwYZ438iDxXvA+xP/kSroRFOCg/LM+p
XhD7ky/kp4xXiPvF+WNsTpxxcW/eH7+Ra8rzDH02+Xdh/XTey/vl5fjrODfl
07ij/l0MQP/4Hc252/gkzNDPxHd4Sj8OO9W7zMmuHoM7rDOWK2Aktst3yLOp
s8R7zr/G8zD2GA/X3+6aEeH4xnlbPB95GR6kzyQfzB307dEXfeIZmZPV+EB8
rf8G0/C4vn+cneqfzcmi/ggZrNOPH0MvbJJvkmfmTPjQ2MZ41sZKczd9Otd8
wO30bdEbvbDOnIzGO2Oyfiqm4FH9u/EuqNeak0HdHmms04FLxZw4Q9SpjLXm
jPqWvIZXu+YRnoSesSf0iG9b/gZWqleYc4v6dSS3RjMuGecDGqsTxppwG31r
FFV356WuSx3nCSbqG3BxLoZmqKt/Nc4X7hrnSNyDv8JovIJGSBnvpbXeVo/C
SNQ21oKT4hzhxfKlXEd/G48v+P//ef8BHkmupQ==
           "]]},
         "2.990100000554607`"],
        Annotation[#, 2.990100000554607, 
         "Tooltip"]& ], {}, {}}}], {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwsW3k41N/3tytLljBjNzOWGWbGGMbwiTmiREmSqEQISZQoypYUSpEsrdJK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        "]]},
      Annotation[#, "Charting`Private`Tag$3938#1"]& ]}, {}}, PointBox[{0, 0}]},
  AspectRatio->Automatic,
  Axes->None,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->False,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.89090669104854*^9, 3.890906817755851*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"38912042-d257-44cb-83bb-7102ae0464e5"]
}, Open  ]],

Cell["\<\
Remind ourselves of the solution for the compound motion.  Note the two \
frequencies in the motion.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4573b8b5-96b4-4063-8f7f-b25d45eb5d64"],

Cell[CellGroupData[{

Cell[BoxData["ctranxy"], "Input",
 CellChangeTimes->{{3.890906701554838*^9, 3.8909067015588818`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"be2f87a0-e0bd-44bd-9ce9-c580bfd23841"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.0003537296736820569`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00009853667909211485`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.00006227072414877771`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00004861047011093332`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}]}], "}"}]], "Output",\

 CellChangeTimes->{3.890906701914916*^9, 3.8909068177689333`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"c5505bb6-c159-4554-a75d-aee79ad4a558"]
}, Open  ]],

Cell["\<\
Let us choose a particular time at which to illustrate the solution.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ec29e408-dfa5-4c6a-974b-dc2baa341608"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tt", " ", "=", " ", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.890906714354411*^9, 3.8909067143614397`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"eb32ef30-6600-4a7c-baa7-19d2df08f5d3"],

Cell["\<\
We can calculate the position of the guiding centre at this time by isolating \
just the long period part of the motion.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6b2ef736-dccf-4bf4-bb07-b5df06f8d4ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"centre1", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.00035373", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"0.268348", "*", "t"}], "]"}]}], ",", " ", 
     RowBox[{"0.0000622707", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"0.268348", "*", "t"}], "]"}]}]}], "}"}], " ", "/.", " ", 
   RowBox[{"t", " ", "->", " ", "tt"}]}]}]], "Input",
 CellChangeTimes->{{3.890906727297762*^9, 3.890906727301635*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"061b4cf0-a751-4e74-9a89-e3054c04611b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "0.0000622707`"}], "}"}]], "Output",
 CellChangeTimes->{3.890906728595852*^9, 3.890906817801605*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"c19e1ea1-553b-44d4-9826-d2353f7357ab"]
}, Open  ]],

Cell["\<\
Now we reverse the effects of the previous rotation by creating a rotation of \
30\[Degree] in the opposite direction.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5996ea6a-c8c6-49be-ace8-c7e1b675b92b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rot", " ", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"30", "\[Degree]"}], "]"}], ",", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"30", "\[Degree]"}], "]"}]}], "}"}], ",", "\n", "         ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"-", "30"}], "\[Degree]"}], "]"}], ",", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"30", "\[Degree]"}], "]"}]}], "}"}]}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.890906743795546*^9, 3.8909067438050537`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"9af4c738-a04f-4089-98ff-07b79f642525"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.8660254037844386`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5`"}], ",", "0.8660254037844386`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.890906744213377*^9, 3.8909068178310757`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"83f7e34e-8fa2-41b4-b764-05caa2ea01a6"]
}, Open  ]],

Cell[TextData[{
 "Construct a dashed-line plot showing the epicyclic motion at this time by \
adding ",
 StyleBox["centre1", "Input"],
 " to the short period terms in the solution (and reversing the previous \
rotation)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0d34882a-64b0-4949-8a98-e42b341f1d66"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ellipse1", " ", "=", " ", "\n", 
  RowBox[{"ParametricPlot", "[", "\n", " ", 
   RowBox[{
    RowBox[{"rot", ".", 
     RowBox[{"(", 
      RowBox[{"centre1", " ", "+", " ", "\n", "  ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.0000985367"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"0.963322", "*", "t"}], "]"}]}], ",", "\n", "   ", 
         RowBox[{
          RowBox[{"-", "0.0000486105"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"0.963322", "*", "t"}], "]"}]}]}], "}"}]}], ")"}]}], ",", 
    "\n", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", 
       RowBox[{"Pi", "/", "0.963322"}]}]}], "}"}], ",", "\n", " ", 
    RowBox[{"AspectRatio", " ", "->", " ", "Automatic"}], ",", "\n", " ", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"Dashing", "[", 
      RowBox[{"{", 
       RowBox[{"0.01", ",", "0.01"}], "}"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890906755218094*^9, 3.8909067552237587`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"2698cc96-8815-4182-abaa-d1aff2bebf0b"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], Dashing[{0.01, 0.01}], FaceForm[Opacity[0.3]], 
      LineBox[CompressedData["
1:eJwtm3k41N/7/+3rjN2MbWZUtkqlVQvnlkhKJamEyC6kXdpQ1lQiKu1SqSQh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       "]]},
     Annotation[#, "Charting`Private`Tag$15129#1"]& ]}, {}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-0.00005759376451779525, 
   0.00011986446152651064`}, {-0.000010876330212918606`, 
   0.00011873237380848936`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.890906756050311*^9, 3.8909068178699083`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"0a73c1f3-5d61-4afb-a28f-56bc763f7d95"]
}, Open  ]],

Cell["\<\
Do the same to plot the motion of the epicentre by isolating just the long \
period terms.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"660cbb8f-67bb-4c08-98f5-3c78d11fefb8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ellipse2", " ", "=", " ", "\n", 
  RowBox[{"ParametricPlot", "[", "\n", " ", 
   RowBox[{
    RowBox[{"rot", ".", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.00035373", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"0.268348", "*", "t"}], "]"}]}], ",", " ", 
       RowBox[{"0.0000622707", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"0.268348", "*", "t"}], "]"}]}]}], "}"}]}], ",", "\n", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", 
       RowBox[{"Pi", "/", "0.268348"}]}]}], "}"}], ",", "\n", " ", 
    RowBox[{"AspectRatio", " ", "->", " ", "Automatic"}], ",", "\n", " ", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"Dashing", "[", 
      RowBox[{"{", 
       RowBox[{"0.01", ",", "0.01"}], "}"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890906770290043*^9, 3.890906770295072*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"09a22c75-6234-4b53-8761-b2ddca896b4d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], Dashing[{0.01, 0.01}], FaceForm[Opacity[0.3]], 
      LineBox[CompressedData["
1:eJwt2nk0Vt/XAHAkmSlDhsj03PuYwr0PzbYhKUqmklKRolQqRVIUJZEhpBJR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       "]]},
     Annotation[#, "Charting`Private`Tag$15155#1"]& ]}, {}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-0.00030791735020047084`, 
   0.000307917292195736}, {-0.00018490386676737845`, 0.00018490385762770227`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8909067705886307`*^9, 3.89090681791049*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"980ddeab-eebb-4250-b4cc-ef0b06805631"]
}, Open  ]],

Cell["\<\
Show both plots together without axes, adding a point to denote the location \
of the equilibrium position.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6029bef1-5767-42f0-a479-30e8f111f07d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ellipses", " ", "=", " ", "\n", 
  RowBox[{"Show", "[", 
   RowBox[{"ellipse1", ",", "ellipse2", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Point", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "]"}], "]"}], ",", "\n", "     ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0005"}], ",", "0.0005"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.00025"}], ",", "0.00025"}], "}"}]}], "}"}]}], ",", 
    "\n", "     ", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8909067836194563`*^9, 3.8909067836235533`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"46730cf9-75fc-4ec2-b8eb-8e0e17a771a3"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], Dashing[{0.01, 0.01}], FaceForm[Opacity[0.3]], 
       LineBox[CompressedData["
1:eJwtm3k41N/7/+3rjN2MbWZUtkqlVQvnlkhKJamEyC6kXdpQ1lQiKu1SqSQh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        "]]},
      Annotation[#, "Charting`Private`Tag$15129#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], Dashing[{0.01, 0.01}], FaceForm[Opacity[0.3]], 
       LineBox[CompressedData["
1:eJwt2nk0Vt/XAHAkmSlDhsj03PuYwr0PzbYhKUqmklKRolQqRVIUJZEhpBJR
pgZCqRSxUxQqqXyNkRKhSaHMvee31vsP67PueM7Ze59913rUt+513C7Ax8dn
Sv7877+X0Megfkc+SK9oAYXl4vDHf8sfzQw+qJ44q7VOQRyy9p3b7vqLD6Y7
9DEx/WJwMG/G2+I4fihokh7tiRWDntHE52YvBWCjxxVPmyZRSHD8b5Xfsukw
8M0wqNVLBHTOMItfGYpCTkqiuW+oEFhU9J5LHpsJ9drFwe05fPDd0bpu2G4O
FPYrLPLR7zDV3p+UofRYA45ulBgPyxwot3B3vrpwlILLU4dVL4gLYvT4Fvqf
ti7syLIWbDGRxqHKADel7HkQHZhitfKRHGb7bT24+pchuE/1Vs1yUcYuwffz
4pYwIJmVl5M+Tw3H7d78emnGgMzfgUvB89Xw7yHaRsiKAbXHDzJczNSwt7fz
/q7VDPx30uLzPwc11K/V38a/mYGYgbBBNX81vHrg4zyXEAZiN0x5Z5aoYY9k
/5PsUgasd2oIpVioo8W5XltnZODAIXD5a6OO4ek3baeeMNCev+DwGid1vBzz
I3dZLQOGzC160FMdKehtvNTMwNv0dX9mhKvj8JIGud1DDBzze5ay/Zk6mm7i
7UrlsnCBu2R5l5UG/nnZLjuuy4KUtG3yZjsNnPhrZONswILmkpnFDes08GCU
uPMfYxbU6zRX3vbWwJ0/oXbEggVD2fUndSM1kFnsdeDPRhZWWlyw1HihgT6C
o1fqIlkIWJ6eLGyriYEit6cHR7OQZ3/3frOjJl74lNbKiWNh1rbtzpkbNNGg
Tf6t1zkWHjuiMNdHE1+p5X3KTmPBuCtz9s/TmqiXaNE3+w4L2371du+v0sSa
APfGZw0shBs/Wrt4kRbeFS3ZdqWRhau82IsdZlp4bPTdDP9mFgbKq/87aq2F
vs6Ho6Tes5C4oXfBTWctlHVU9xfpIsfb9A9W+2ohumcelx5g4fSq+rUzM7Sw
6oUJnfKLheWnJo96XtfCdOHWNrVBFuI8ek8W5mvh7/y6PSp/WNh84IHh4lIt
jNump9M2zkJv9LuXsxq0UDMn7f4OIR7EmhVhjSAHHzglymTN4MF+VbFFNaIc
PEarH24V5oFuXcnRp9IcrMz4z22BGA/s5huvvT6Hg/NjT4Y8kOIBNntrszwO
KvrPUXgpzYPhj8vLhBdxsM5O+EHrTB6MZz+TaAEOxuXXi/TJ8KA8rrtjpy0H
R4SUf9TM5sGBY+cVV23lYHGNWdE9BR54NXj7/PXmoAlUHk1VJPdzCNh9eQ8H
rybzzdmozIObA7dDWgI5WJO1ITxVlQf/HuLdmXEcPDGwz9t9Lg8iVGJ2JJzj
4IaKpavmqvFAwOH0E4lLHOxrNVWJVefB24xkz6EsDvYk/Wsy0OLB4OPdvNAS
Dsb8+K+qmtheSkPzEXJw6/G2HjcOD+7FK3b9quTgAcveigCKB/lUy5vVrzlY
bZN3ZIK42EZ76kADB6PnK+4Ipnmw4tmLP+daOFg07WDzPi4PjkZwVjzv4uD9
Ttqti9ioxjetuZeD+9KkZzlo84DaOO/R5+8czLJTlFXV4QHIWaz8/peDKt7C
7sHE6/SZ+30TZDx5te1NxKoB9d2d/BRGXj3gG6LLg7PsptMoRmHiFSa0llgz
6ddIjjSFOT7+VTP1eNDIf5yOlKNwjaDuYmfi3fEds7yUKFx7wfJTPHFB6ueH
S+dS+MSvsKSW+GGZj7K0FoUfRLdVThEz9TYm7VwKF486/NPX50H6ry0i2foU
5k347lpPnBl6KtGbIfcbLRQOITbXSH2nNZ/CrBHJpjRinQfHqt8vptBVO7Sx
hHjSZ+b+ODMKQz/wzXhLHJXNvFxiRWHYudM7PhMryj9r/rySwplfZMZ/ERfk
FyRF2FG4KCW9fIzYNruBn+NEoccl7aIpYpODynPKXChcOljYPPk/t+7qWuNG
4fsWY4MR4o7W/HXt7hReu/bw/nfil+V1B7dvp3B9m+neDuJemeIlvTspFFCs
WV9LfOOW863tvhSK6Ww6cJvYNTupqt2PQoNJPkwkdtyw86T9IQqDckoX7yc2
9XvcW3aEQtstSX0rid1bon9xjlO4+tSFahXi6icVl0+fpPBI+svmb2Q+0647
fes+TaGcs5lSMbHrqgXvl8ZQpH7/iz5KLFLstftsPIUTP2YbLSWOWtiU0p5E
oV9UgkQhWV8JhmRIGhm/rfzyrcSKRUfasjIovH3LpFCK+NTWiuD3ORTasJcV
3Ui8rDrZEre4gMJ+dUnFcRJvwytvTW4tovDMiv02ScSK3UUC4cUUtu3eZ1lK
4jPT16fuAZJ42GwmZk28iI9KrH1KoeR+n+l1JL7pfN2vjc8pjA8wj39F4r+p
bZHDh9cUbkr2EU0k+RO/vbg1/wOFKzOeiH7VJPO9yb2kr4vC5XvKti0l3qNi
ME+1l0K+h1uoNyQf1dojXh0YoPCW957YWcRuzqV/zg1RaMTrt7cj+TsQ6l1Q
MELh/Z+SPXdJvuu+OFv7ho/GFw+0H35Q4cGFN1U6LYI0PnRK/iJIHLmtS65V
mMYbKr4upqRe7BzYeLpamsZ7AcJRe0i9+RVggS5qNErMazHdJU/yU7zARVeL
xoDZ8g6ecjwY+7jIb4SmMXvJVKwFqVdNrK/2MQMaXfwED5dJkud1toaZmpLn
2VxXj5Ug8cN5KdlhTuOyTp6OqzgPMvojZA9Z0fgkYptbhwipZ6tcIpNW0dgz
NW6XLcgDi/BTEyc20BjV/4Bv5TQeKIkPLPq5icZbc8zkvvDzwPvAsq9OHjQW
iizZMesfC59GOi+L7CDPU9Ou4IyysCbmniHlT6OH0+5zqX9ZWN9r/NktkMYt
ao9fSZB6/x87XyDmCI0zEjcc/PCbhQ23dYJaQsl4JMcuwzcWCreBuWYsjeLW
6/Ij+1kI9Ncy5MST6yf3cOt6WXhScj5M7RyNqzSeblzezULN/Jd20y7R2F4s
8GqwnQUPy5N7DmfT6HXqm51lHQvXMqNn0aU0Tm+1venykgWj9n1ZCWU0yk9W
G3jXsiBSMbRzBGlU7RMoPfSMBSHH8Jg7lTT6Dwp0bi5ngXO8jPr4ikZKoTF5
1SMWTEQjrVTraYyj7oQal7AwWbg7ce1bGjsGzraP3CP7Z7hTyZ1GGvfeCmmw
ukX2syVvOPQHGrWcKAmJXBYyboXnG3+k8b2zRODr6yyEnOdsNe0i9xuu7bHK
YqE9Um+F6RcajWZenT96iYWp1uf8Iz9onCZ1gA6KYMGmeedTx0kaXZVtq4dO
snArzuXJtH80HtpWmOUTxsIRw77P+XxcrJtKm7UimAUvx/WJg9O4mFhU1FDj
R/oDa5coE1Eush3nPFX3sWAfYJvyQIyLmRpKrO8eFobkal7yJLjY6H/n/D9v
cv2NH3HK0lwMi64K63Nj4exJuZgMOS6m3vLRVtjAQmRS8MVheS4+HZOVt3Bh
4dWuwgoLBS6qX4TKCAcWUt2Y3S+UuBjfdymi1YqFo8eUFc/P5eK9LVJ+XaT/
8XhvKVqixkXrYfb6F2BhqU2DfLM6Fxc0BI59XMhCqPPsUAEtLhaMX7FN02fh
RPb7BGkuFx8ul4011WGhuTPkiqI2F6lrcfYtFImvjdqorMPFF8KnXKfmspD8
ZN88MT0uHs4duXp6DpnP48dCRoi7srf6Siiy4KcV1NGhz0WB+SoXhGax8Dpb
79V5Ay5GCvkNB0my0GLptXGHIRe705619YmSeLaOG2GMuMj9eHpZ8TQWqN7q
zUUMFwUdZ9TI8bGwyXgXvZPl4ojCtRbfCQYGrNWmZvO4GL43OFN6mIFx4YkG
d2Mu3rJ5s9n1FwNyrpUNY8R+s0Jvpn5n4NftTx9jTLiY5ZQe0drHwMZOvQnF
+VxU0zH7O6uHgZSCIM104hNmh8esPjFwtC/bRWUBF1teeyQc6GDAY13UxXPE
n6blnCxvZOBR11/wXchF8c75H9veMqAea5FTT3wws7txsI6BgGM1CnqLuJhi
U+cl9IL0t4f9Lhwnjt48K0HmOQPVSzgadcQRQ+9clZ8ykHv6xQPZxeT9b5mg
Cumn1yo7bHQmvnN/y1Ml0m/X3c4UiSE+/tzfe1YxA1Mzip6WE/dpXM0TLGKg
sHlfZB+x/Xmxc7/yGbjYXr9BYgkXnQ53qrbcZMD5dfV8HeKAW6vsSnMY2Lfd
Xs2M+NXlEM2LGQzsWechu4Y40zQnfW8aAyUuf2VciCmJ4afmlxgoV5Geu55Y
QiotXvI8A/Ubc40diU3f/ifSGM+AWWWtixVx8O63+hdjGLAX9gs3IhY78mLK
OZIBk+accnni1RpjweLhDCh07Zs2TN43SCI5r/w4+V5panF6SbzA9/OZXUcZ
UPb4XpBKbD2hqCITyICu/sPZXsRzhwM97h1gQKJn1RkucbqyxQbHvWS+jUtE
P5P5vFZcLNzvw8DQU9nzF4nLk1R8j3ox0LfAT385canQwzMiWxk4s6i//htZ
r00f6rfGbyLfP3vOH48mHj10a0jGlYFTAQlLOMQzWttXi9iT+T37u8WcrH/K
p5rZR20ZoLoulFaReCni5l7tW85Ad7TUTQtipdDYsbtLGehcL5lPk3i7pz7U
La7LwPkrn9elkfj9HqgwuItiIP9aw8R3Et8xV6jxKnUGhIe9fpkQKy+m+Hcp
MMBXZvr8LsmPbF0RkcPTGViv+lDXneRTZ0v1zEI+BuaF5K0KIvm2RvjT3E/j
RmA3LFoeo8vF5j9+DvN/G0HvfenEKyR/D5y6ZJDTYQTj/W0SARwufhm/dvpe
ixH4BhQ/3EDy3+xp4y9sMII/5ksfLNDkoreR/FhVrREcsY7K7yT1I21Jq/CF
+0bgaLgtslOZiyuEW1ztYoxgnvUf6yukfiXrx7hJnTaCBK7CCiUpLgbm/Q1/
EWYEN8Yrr8SQendRt9LRONAIoucGbnIn9TFo1drJuq1GkDNRLH2f1M8rsae7
lOcbgdwri2qNYRpjrLiZ1HtDOG46zp3+jtTvRXKOdxsNIWmiauQd2R/uy0oM
LX1jCJuaf0tcriMe3SJv9cwQhqqTRFVracw4emlUo9AQvr0wd2t7TCM/9Xq7
6glDcLmBHyxv0Ti+RdBThTKEsK9VmfVkfxw79XCmnpohCDbmWvSF0FhtuvWD
iZIh8PyvL5og+6nkR5t2M0lD8OktXjAzgMaLCjdmr/5mQPazRaF/d9JYFus+
eCDKAPreJPXes6extqXxp3zFPDhV2hX8T5FGXU+lA7pF86Ba289TXp7sn7M8
ls8n3+/x7WcfU7NoHH5c9Y0XOQ/6Q4a7WVHyvpny16vt58Gdb/8m/o1SmBtI
bVjboQ9bBK23uDeT/mxbL09tUA/aZNb62pylsFzN6am3oC4cL3APkiDfE3zS
N8Y7FWgwK/XyTwrSwluBVIHNAQ04urQYbGM10COw0vCAmjLwHqoV7XFRw0aH
+Yssz80EYZfMei+ROWivLdUW/XDcNNCv7XJQuDyuu+txyYe/rzwgf/TxKP9M
rHvcN1DeKYLTfnWUvCwUwolHJxWvus3GZSNlJvySQ+WnI0Q3b3dTw+OWrVen
zF6bPgpx3j7K4WCAg6GK1stJ0xwZzVO5QdoY0luWa+EqBoxPrar9XH38L2XB
0d5lMqD6u2fhzZWGKKStMRjArwjLeJFdjzKNsNYsecnhPypwc32Sadh1I4y+
ML9cREQVhKOavCxvGaFafZFyorIqtJw8rPTwvhFuu5Sz/qyZKnz68+LH/hoj
ZAWDtvCiVOHe/ftOCj/I+aXpdapz5kK3rfBJQx6DM7+5hhioqMG8hdYn1xYx
WDi+fVu9gTrYtf6RXVfMoGxCe3DzAnUI9HLe4VDK4PS38lVt5uowsDLbccFT
BqX/Fb9956QOSrWV8s/fMihetS0r8pA69OwT3PVlgMHagC2DIuXE/Gf49bRZ
9N8zS2GVtQYkHrvTFqbHYsFkh9q9NRpwZ3uJS4MBiwL6biKK6zVALP+ekbcJ
i/LZgvve7NCAKqv7TqssWRxbnuUoGKUBGzrvRMi4sVi+Kt5r3wsNeH37Vllc
JItmLkkfHWw0waQ7NFcsmsVLes9zYxw0obq79b+wWBZ3D5c/rlyvCY3G99q3
JrLoxDf6VMtbE94eCr3Rl8pi2ZPMqdwTmrB39WThzAIWdRdOr/ivVBMuC51V
N7/NYnfHHO+qJ5rgzTtftauIRVrbc0lhjSb07f2YfaeYxaNZ5XsONWmCTNjQ
A6HHLKZ8f/7oxW9NwMAfD56/ZnHYuuRiFFcLvpR807z5hsU87Rk+egZaEBQY
WBLxjsXs2tn2NcZawBPasYPXxKKbhYzzkIUWvKg0KXXqYFFRNV1SapMWyGl8
e3/jK4unqty/rj2rBXOKn780/c5iU6K2zfXzWnBAKfBj3Q8W6+VCsoZTtaD+
yNtDnb9YXFGWYxV6QwuOWkva1fxlUWLMQsrtiRZMJEQ53Bbg4cB5GV/VQS2I
YOquywjyMDiptO7KqBZ0xyQt2zedh5kh5/RV+Diw+on6CgVhHoaV7u6YJsGB
Ia28g5oSPAxXUW85TXHgHzek20WSh/HX8v+26nHA3rjrwikpHna6VEynWQ4I
20g8fjuThztY87484MD9p69kKXkeqp1JTtm7ngO3exQi9Wbz8EQTIxi/mQP6
2XuX6CuQ++fJ2uVt48D1SOUtKko8nGy5G1K/jwPPnWqjH6jwMEmwQ+P1aQ6c
0K/8dVaVh67y1HaM5YBybm6i51weVpj2B904x4HY704xf9XI+aoaSruucKA0
tNmhVZOHl7Y6jmQWc+DdB4GLJ7V4GCC7/9rWMg5InfJS1ObwMDSxcI7yUw4E
d6i+cqd4+FNdyOlwHQdGbJX+DRKHPmqVntvAgWWBqbtCaR5eXLw6tryFA0J3
zg1GcXmolJda0f+Z3L+oXHKGNg83H1l+8FA/BxZtavIMJq74SndO/uRAAtqV
rtfh4fJ50P53jAMrr/mWlREngP2uXXwUmJz7NzJHl4dL9q/Ja55OwQdxkTm1
xJFRn8yuSFPwQ8B+moIeD2XV3ePH5CjofJul6U6cZ5Iea6dMwYOG30cziE21
FeenqlEwQ5iW+kD8iVoZ2cWhYEzGsFVOn4eW8/JOaOlS4GY91b6cWFmqQmuL
IQUpF08o+RGn+wjvSjSmSJ9bFHeB+HuR4NqKRRTcu3tiaTHxPsNFH3uBgrI7
/ZpviN1G5kmKWlEw3fijRTfxjL8+rVo2FGwK9Lg0SOz19dCyhWsoWOnhrTPx
v+t3fLSxdqZA8OjA7ynimP943+xcKTg6MT44Tjziy0/bb6ZgQ3mU/v+uX7C8
edTGk4JVrnMr/3f/uzP3Jn31pmDO5D37d8Qch8KLp3ZTYGPl9K6U2OGSv8Cc
/RQckJq0TSf+15v8JtefgnVHSkqCiXXSRwVNgih40Z841+V/7x/ul1ISQsFz
/sQgXeKvtV2JC09Q4Jzz5MUYmb+VQvO+34mg4ByfgUwV8TJjNoeKpuBhULd9
FPG6ssayc2fJ+CuGTtoQf9w1yUyeo+Bpxe6C6cThATGC7skUWN/aXF9K1tP5
iK9R2WUKeofff9lNrBsa+UA2g4JXt+vGkMTDvQcKb+7cpCDdac8fD2IHIS/3
0XwKsgp+9E6ReFobk261qIiC09WTd7SJ08WTJXJLKVj49HFUMYnHK/uX/mhF
Cu4O1ruaEQv1n1ebXknBfSuHDgsSv2sizANWvKTgWBHfuUckvnX9wi541FNw
8ucRcyPijxMuQv4NFIQs3XpSjOSHoEZhddR7CgSCxPJPaPBwy9MfT/d/oyCg
UZ/6T53E75ss400DFHgeX3tBnTji1+9vFkMUSKzfuT2X5OeIxUHu5DgFGWkt
98Lm8JDx5jzQE6PhpZbzeK4yD0eX5C3ul6TB9vWmxfUk/8PVdSavzqLhvMN4
rogiD93b15rwKdGgeSx/rZkcDw31arwPcWlY0dDrby7LQ3H/DRVCejRke0Yn
LJXhYXHdZYezBjQEC8s+oUg9WnulaFaCCQ1rt8fwl4nz8CBbOrVmGQ33nuwT
Py/GQ79NfsOF1jRkxH+R8xHlob/MoLK4LQ0Htz7iTCP10HrPyFChAw2L28LM
R0k9HTf9i3c302CoXN5TyE/icecW9SYPGs7255Z78pHnXZXuGdxGQ+TCzhml
kywapTien7OLhnJukbDhCItCf8uDdQ7RcGRr2KqKPywyG+o/zw2ioUwtq2r1
MIurc9bdkAqm4YmAlev63yzWJPyy7gijoTdjujTvG4scHH0+P5YG84U+wun9
LKYNm8/gi6dhzmfRhdP7WHx3LDTtSSINdVJnlj3tZrEi0vytSTINT9XipYQ+
sJi6LXZJWyYNCzxq3uTUs5hUrxgn84CGTNfokKo6FhUSHPhDS2hoS1/k8+El
i/v8oyp6H9Hwp1uPb3oNix8abmtfq6DBqtuPnV3B4q9RgcgPtTQ0tiZ8lkIW
Ly7x2jj3FQ1v3D2bp5Wx6HnZ8ZDr6/89TzKq/QGLUZgV+egdGV9hkub6QhYd
TseImL4n61OweEQnn+xfVJyifQcNIXZXZEZzWZyRPurr1knDbqEnahHXWAye
I9Pr+ZmGnN++mT5pLLrQX6fP+0ZDUpLHszVnWBSOtI3MHyPz7Wp87Opp0n+I
WMZHTtDgqvO+6Hs4i0MftN5tmqIh7vftRP/jLNqduSjwm58LHXamlpb+LHq8
MxeoEeaCe9mWgR1+LKZnHn+xR5QL/jcvzY3cy+LoibJaMXEu6JdcnvFwJ4uH
Hm7ZyUpxof7EkGzTJhYbLYaVjOS4ML/jd1/9BhYXHXwWkS7PBU+fu9ZVLixq
aWjRMxS4sGjN4JXLDiw2ZA2MVyhxwUW98ZO4FTmOuoPdc7lQI+0q32ZO+oX3
hX0q6lxouZXbkmnKoljDC6k1GlwQ9vaU4Swg/VfM7r5ULS4kDPXv7tFh0ffs
9poeLjmen78gkmYxdP9FtlebC2xrYQqlxaLMne7aTzpc0J5apuugwuIn/fvH
nuqR8fJVuXYosvjm+u3UG/pcSI3couklz2KlwIPu0/O4ECHy5sx2KRZ3Cn8d
Ywy5sG5Rhl67GDnunv5skrhje9juNcIsJv7aU1ZhxIWrzQdfafKT+LYL0TVm
uVB5PGYgfJLBMmOXjM/EbZ8r7n8aZdA1JtAyhscFv9UphtG/GeT+a5pWa8yF
Q/WOPc0/GBTNeaSx2YQLXWK2lmpfGTzQaLLrK3H39PgVW78wuPemavv++Vz4
upz9m9bF4FYdu8BfxGtazO0bPzCovPrqEp8FXJBeWecs/J7Blr/D2u+JJQ7l
b3NrYPC1BudY7kIulL3V8wupZ1BKvqpHeBEXlJaHGKS8ZPDgoV8BW4grO0sv
36lmcKQh3qCAWIfhK6+sZHBhbpz0CPHild7xbx4zGLy9UXHRYi6I35VUbHnE
YMkmJ1t/4qRjcuvaHjCY/H446wbx5vmpK5vvkvMVC6gmYqP1vBHZ2wzWtLz3
GycO8iqRWH2LwT1bB6oVl3DhctCcM8dvMCi29BOXIXaoW7m/IJvBOz55CcuI
Nz5iKlquMtjkaSPkQOzxuPrIv8sMblZ4eMKFODdg6qraJQYv/Pwjup64K+U5
b+l5BpdUT0t1JG4UVzRem8Cg/0iniTWx2bPezB2xDDavjm8zJo77rB92KIpB
TwnFKFXi9MzO+tBTDIYOBlvwE5/aPHY2IoxBQd5zwQ7y/rZx/k9PhzCoHTRZ
f5f4Xt3qneFBDMb16lwLJxZtOHYiOIDMn+LGCHviyoMiMvv9GIxQSdkvR+yZ
1afg7kveL2R0ewOZX92DaudtfMh8LD61LYb4w6yCM4ZeDJ5+6bjHjPjkywtj
M7cyaKPmd/w7WU810Y6uH5sYfJw6cvkcsYDVee2UtQyunEgcqSfrr5cpe9rH
gUH812zsRZywXGS78WoG03Z3Bw+T+BFwDEorW8bgpU+V8wSINTUf6V1kGUz9
ITC7gcTrWCwn1dKAwckb7bcWEu/v2ZXQr8Mg79op+2QS3yZpTbN1Nch8Xv/0
cDnDhZ8pW7MCpBmMjturvsGAC+2KXTumxBj8+3Gz8lmSX/FJ3x+FzmDwvUio
xmOSf79bxBSOTBnh2G9dV0mSnzd6kx8u+GaEKyqlfT1JfovxxSle/mKExSqh
TTtpLkSK8s+a/GSECeE9a3woLiTK9tcXtBjhum0xvq6kPkTZ/szpfGaE8T4R
PgOkviSPrnyw74oRvr/UlMJP6pNl3LY9VIoRpjhunDwjy4UCvxPiTUlGeM9b
xUdKhgvOLr8ltc8YYfkueW9+aS78Uf685qy/EXKuuI/Hi3Chh7tZfc9KI3RK
mDmyfZyGfWsEmLeWRqiU7m0VOkpDwdvPVoypEW6oe5Gd9JeGNP2e4C7GCKms
kas3Bmmw8CxyE51jhJ8S+i+EfCX7h8vgil3fDfHgugG+9hYaOt8kO4V+IWYU
n0U20TB4TPtowkdDjJFWu27wHw07P3Tq5/xniMeiQ6u86kk/YTV9WWKZITJ9
8ofDntEg1bHzSXi0IdZp6Xjtu01DKeRFNVOGODP/Q4Mu2V+Hm/VIiBniquN7
E8WP0RAmrGMnpmSIJmjwvOcIDf1fyzX0JAwxu6YyPsKfhuu32f37egywqnvp
y6AdNHhZlm34e9QAvZ+tyOKupoHvftPGw5nz8EZCfv71maQ/Sa2gOE16WCq8
MDSA9JPediYTi2v0cB7tKylJ+k11fv1m21I95Mbb0VdIP9rAaN1el66HeHoT
313Sv/rHMcsVvfUQ7sj4XiL98FDXrDHnYV207jMw8DSlQE6puqZcXBfrzDys
v5Hvjcf7eRs0udq4P2ZMRN2SAyuCP6RKPdLCzxPKmZdPacK8ROv8WCs1fLgy
S3rxBXXIGvCbHrB6NrrPsEmPb1OFZrXY5cLPRfBPSu9qzRxFcJ8/R6n+3pfy
Es1Eg7MespAlZbss2qGn/PDtWU+tVsrCUJbOVfPvn8s5lu/oYUNZuB62LjtZ
61O59bmyMHM+WeBrPbZPjmopz/DQsYtPk4HHK86b8g/nlE/tF66QaZ0FDWqH
P6Y3fTbNiou/2rxqJvxg3/b3L+4xrXFtbmtkZ4JaxgF9gytfTI87jjS9VpoJ
zIRZ3tUd/aZCM1bw7vRKQ3SnR6HG6E/TZwfmOC08KQ3781b9VIoeNhWUxkcF
B6Wg/7Fb3cDSP6aD9p+SxSyk4IDr7B78+cc0UNRsYJOUFORIv+hZ4TRiGpbt
v7znhiTc3O5uxqc0burGDK+M6JCABvf+v8kviI9Oy7iYKwFzm5pMdIMnTOXu
6f68EigBPUqkW+icNH324kfO+VkS0CLcJHAzfso0oy/D8OQHcTjSYG4x2/Kf
6drdmd935IlDWnjSWNDQP9P3t098X3ZYHDb+/+95sv//9zz/BzO7IoE=
        "]]},
      Annotation[#, "Charting`Private`Tag$15155#1"]& ]}, {}}, 
   PointBox[{0, 0}]},
  AspectRatio->Automatic,
  Axes->None,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-0.0005, 0.0005}, {-0.00025, 0.00025}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8909067843195953`*^9, 3.890906817926996*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"c318c276-9f91-43e0-9be7-fb5dad9af96b"]
}, Open  ]],

Cell["\<\
Finally we put all the plots together to illustrate the type of motion.  This \
is Fig.3.15.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.856766570422817*^9, 3.856766575597426*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b6fd9db9-cbc9-4ee4-81dc-7781a2cc3ab4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"traj", ",", "ellipses", ",", "zvcurve"}], "]"}]], "Input",
 CellChangeTimes->{{3.890906794851026*^9, 3.89090679485494*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"400a67fc-1b34-44d2-b40f-216da38343c5"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwsW3k41N/3tytLljBjNzOWGWbGGMbwiTmiREmSqEQISZQoypYUSpEsrdJK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        "]]},
      Annotation[#, "Charting`Private`Tag$3938#1"]& ]}, {}}, {{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], Dashing[{0.01, 0.01}], FaceForm[Opacity[0.3]], 
        LineBox[CompressedData["
1:eJwtm3k41N/7/+3rjN2MbWZUtkqlVQvnlkhKJamEyC6kXdpQ1lQiKu1SqSQh
W+i8UIl42ypLyW5sZd/X7/lcv99fcz2uc15nve/7PJ9/zALHYxYufDw8PDR+
Hp7//f59+ODupxcNaEbRsm5DRRf6Vkz7pz/6G704tXWnPl83KryZqVdl9Bs5
aS9etX9tN/oo5OWzpb0ejX2cUSx+0I3ajCUEbNRqUWycs8CbIz3o+H7RyQuv
q5BHfYSJo+hf1B77pv3jwlw0329yV9+qH8VFbXlcpfsfPiYdUuumMIwWbtu3
fd7vH/Y9SdPom5lCjnVWSusOTmDG3NULCzx5YaCXmbzxFA+VG8sntcJbEGhn
rwfiIB6Kkdhyt8FfEGx70uQ33OGhJlKbRa5HCcJfpcO2Mh94KA+P7bcG0gWh
Kriu23KOhyrcw5tVMS0IO1KqC+VDeSmN8bHOlqtCsDDhe4dzFB9VNl1dvuql
MGycs3m/NkyAGnl0N9KrQxS2h+nmGd4RoJZcYxhuGBOFYeXf77c+F6AyI6eC
hITFIEEoy2F1vgB11fRYcryWGNy51XngybgA9ejHCZUWTzGY0sjMxM6ClF9A
4teTQ2KgNmEwyb9eiFpadsyrbF4czoi9mBotEKYY+df2nVCSgItXlwk8KRem
dEzPrkjUloAflzLP6f0WpuTe815qRRIA69F9yxFh6kPU30N7nCQg57ak2aS6
CCXVMPpMM0kC6pIY+6RDRajeU+avUvUlYSTYocDJQJR6nMj1EteRgrWZLP/o
HaLUnOziOcUNUhBfOLgxa78odWPbgVFNQynI7haN++UlSqUgAXFDSylwXFpX
FBkrSpU+DAn39pWCmX6Tkqx/otTY59mohHwp8Dc28/odIUYZzitdDzCXhqPP
340diBWjZjq+TpodlIaXDjlRxU/FKLPX/11RcJQGJ33T/uB0MSrijvKfpFPS
EBn9aP54vRgVNLbP+9sdaTBNubdRaIE4JWFX3FzTIA2FdddHlV+KU6dCDvOo
ucsAj/ZtSv6dOCXmvXtBxXEZ0I0vMOPPEqdibP5InjsnAw2/sl9+KBKnsm+u
NisJl4HD1/QWRXeIU5l6R+as38qAD0q2HFelUWYJyis2D8lAjNfAGZ8IGrWO
kyEockEW+lRPOPrE0Kic6wyesSuykJ107YTnfRoltyTibWu4LMT3lg2uSaBR
k/VyStn3ZYFTVmJh/JFGCSxu59+bIwuLLJ46WHfTqOkbud4mk7LwoSS88k0f
jTrfycrg8MpB6umNZkPDNGp3vmTkmIgcdPH8cLabo1EN0+IzTxTkYH12/Xia
DJ3yOnT4bIuuHKwMWXPbbAOdGtc/ZsnykYMTF9X0+/TpFG3NIE/jJTko1H3b
GGRIpxQ6vy96FCwH2yuVxKJ20Cme63pfGLflwLxsok3tEJ0Kk9I1HH8vB8I7
mB82+NEpxU3DVzwH5SDt0qoLS66Q+QyPZMhMysGtZicNqRA61ep/3CCbRx7S
LLauyblBp46cKLOak5QHmpCZ3NWHdKr4rqC9z3J5+M9AX1U6m049FtBRl/OU
B3GpZY9v59Kpgy+tOw1PycMv73e8dIpO5U82xhy7IA9GOZfO/PhCp1KKX74q
vCYPV4IiRr9U06kxvc0ndyfJQ1nG1uCWn3Sq3kNv19F0edi1njHcX0enyhWE
+a/myYNWUJBLRyOdeuhS9e9DmTxEf9eJWNVDp0q9S0J5/8mDoqDKePtfcj4C
Zd30UXnY6npLN7yfTiWxNskozMrD3McFem9H6JSl2Ya36nQG5L1+Bvvm6NT1
/dWl6ssYcJz20vwxjwS123nPAtW1DDCSvrf6F58E5XOJb6mCPgP2DhZ4LRGW
oMzau/fw7mRA1BuTB9qSEpRA64XkLC8GGFwuWkKTlqDuKa11fXKaAckuoaGN
MhLUknTJ/KCLDLjrmJ9gw5Cgfrks27PtOgMeOG50F1KQoLptRwI1Yhjw1WBq
5JmiBKVxun0330MGFH/w9c5SkaDyDHYnpr1hQMH2A9bL2BKUt9neNaHvGeCY
kCt5hyNBbdSI3nUwlwEv+Px/wkIJ6sr15iVj3xgwJq7SEbBIghKavtiVX82A
iMGcvHQ1CWpm5uSyq78YcDP/WeGIhgRVuS7KSKaHAYnFpgM8WhJU/MBOme+D
DEjoed0+T1huyw27qEkG+D268GRwsQSluk5ZcycvE+yVz6vWLJGguGGfjwiJ
MqHAwdnt7VIJalvafrWPUkzwXjl76qy2BBXS8sTyhAITxDZb/WlbJkHtSoqm
V2syoet72oaQ5RJUh3FjlN8KJsjc+WutvEKCet/KCdTSZQKf0m+DZ4TRviVN
FYgJ3IwDvSwdCUpbu/LZ6a1MSAgE62uEG9Payxm7mDB0+NSNXsLSQ5vsMvcx
YWd/bRBaKUGdT0ncvfcQE0Ri9hkEEXY/JfT0nzMTgkpb3T4QtjIuRAJeTEgv
TRZqI3yFxbmpcIoJaYbvVHhXSVAPHttELjnPhMqchteyhIdmMw02XmaC7/1V
yUqEq/lPPDYJY8I2tXeLGYTHxb+9tLjJhFmfvSpChOcE+W1s7jAh7MaikB4y
fuWZQ5kOj5gwjDTcPhGWO62c7fKcCVeQCxVJ+FGyv53bGyZcVf4XYUG4xv2/
l65p5PvN//0UIbz+4rZbTh+YoDzBjHlP9ptotVbFLp8JI46tJRaEpwTqt+z/
yoT6y0ZnueT8dnHOCZuVM+GxzsGH3oSD/ti4wE8mMDTRhl5y/q/pxTY6DUxQ
nZTdZUvYgyHYzW5jQjhj7lcBuS/fcWtx8R4myJYubFYmPGoqUzAywARb9OaQ
B7nffwanRRrGmdB46tPe/91/5utvTflzTIj0c0iUIvGxnOavG0hTgNgXO8VX
kvjpenkq/bCsApxadafDmMTXoamrOZuUFOB8lJbwThKPph932/RoKoDNrf5d
oE7y5/39oY/LFcB7P11ag8Svnyei3VyrALRhV8GqBRJU6Nh/1OItCrDz57r1
t1UlKBIW+4dNFaDvRjB3J8kPi/UB7jnmCqDJ05n5kOTTY56WCQM7BUjS26WT
QvIxIkDywYpzCjCjeXubgrwEtemyX1O7vwK8Za9pOi1L5lPRvHU3RAEe8LKu
iktJUDwLL28ajVaA35zk38kiEtQi4DkelUzG60sfyhEi93u2aXxlhgKI3n52
LVdAgsLT+c0VuQrw6uw64/ukvtBCpsv5SxQgJehzx3/jdMrvQWj/jjYF0E9x
t5Zop1MO+/7+sGEqQpu63uHjLXQKb7bUTGUpgpapr9NXUv+sy6d/86spQvnu
TGfLejr1XyC/61MdRTDYlOzc8x+d6or6W51nqgjGT3aOCWXQqbJbAwWnLijC
1DlftQ+ppB4ubw96fFkRVn3zsDmcTKcsHpjcKgpVBFWpeu6Nl3RqandAiESM
IsTt/Rnuco9ObbEsf3MpSRFy7F98Fb5Axj+W+Ly2QRF6ClI6xc7SqW2FM/Y1
rYpQtMWfzX+KzHcgZld1lyLwZMKPag86FVXcRBWMKALXoOZC/0E6VfVardSP
pgQSlqw49jo6VfkncNvxTUpQY73txamVdGprQnDE5s1K8C27tOqjNp3S6DUb
lDRRAusjNi9WLqJT4T+fCT+3UILkz8n770rSqeXbW8xfH1ECRX5Wrw2XRp1c
u3eR5l0lsCjsXnyzmUZVB7mLGz0i/b89ycn4RaP+cr1PHXqmBOHhNnUN5TQK
VZ3NC36nBNtutq2OzqRRnYMVfElflWCk3u3f00AaNTEQyt05rgTPuk4zxS/R
KC1mKN+qWSV49W/fOzcfGrVUJyJQhl8Zbm4T05l2p1EFoqzkYglluBSIEq/t
pFH4996zohrKIGN0fK2lHI3ycV/t/XuvMpzK61g0SqNRCZsZzOCDynAxPO7J
VUEataZaSXypvTI8Yuqb3BgTp0biV5d7eijDneq1t+ZrxSnDlWEx+QHKkPbr
3XRUrDhV7rz7c0aSMqhp8IxfkhIn+iZ45hOvCjAE9ZuWiZD2Z0t3PhBSgYbS
BJ3v82Lk/ffYcExcBfrEljHn+sQo+oOpJpq8CsQVFmv/LBOjNBxjjThaKiAV
9cM8PESMav4n5P5kpwoo/L6RxRkSpZ7fr1AXvKMC/E6oN6BLlJqQ7k45el8F
bmO78tpGUYoZHfC++rEKJN9ySHItFaW+nm9SuvVSBTr72WKiz0UpkZJgS262
Cgh+0vZw3CtKPZyKCW37pQJ0IYVl5xJFqJiTibmLVViwWo8vMPGxCJUw+l71
tCoLwndPKlTeEqEkLQPW56ixwPdJkszEeRGqcOz8hQ3LWPBv68ZHudtFKDu3
Pm0BxAIzmyAluS5hyvvi7ZUldiz4EfpJ6hrR0/a8+1eVO7Ig317Cf4zo7fry
8upyVxbYb9lUnZghTGlYW/QVerNgQrIu++oVYSrb9OsxHz8WRBkrFixSEqZS
8cenoo9YELTm8kAbTZhaJz7AKI5jQcMbw++x80JUSaC00pXnZP4mZmFzuxDV
vqjhS9cbFvBrvErpThaiOE19twNyWCB0p3Z9m4EQtYe2dkV9DQseTf1XF2kr
SGXammzRpLGBabn07epdgpT/xpJnWyXZwPcRFMtAkIq82PXQQYYNxjoBxX8W
ClL3eyL3hSuw4cXZp8NBXQKUandJcYIaGwQsvwtzTwhQjU5tM2J6bEi9PLap
3VGAaretvdKG2PAmoGNb3V4ByvG2fkzWZjZ8X1ox+3StAJU0ZrDfwoQNi8OE
TfMm+CmrwaubLSzYMPW3hSl1iZ+yXulGu+DGhn83UfXRo/zUAgHLPnEPNvy5
vf11wSF+atehT7tjvdgwtPwb3oH4Ka7GwYhnJ9jwbugEb88cH0ULHOYGXmCD
n/EDbOHHRxn03PT2jGBDtH2Z98gZXips+p5dVQob5M3ylDa78lJ1XZN3ktPY
cDLr3+vg/byU6/5L30PT2bDVcOPlsXW8VKyZ1oHl2Wywi+i9dHach/KKqb24
g2KD/rco0Skf4gerRdu+lLGhn3fifZErD3Ugx26JUzkbksPk/K/t56Gez2gf
m6lgw+aHUqGza3ko8w9J/Qu/k/kO4rvC3fNYxiC1AOrZ4Lz48cYNzXNYLDvX
KrudDdd3Bhz4hefw9gWPdshz2aC04soar0dz+OJro3XenWT8+7K7Ha3ncJr2
g0HZHjZ8zvHriv0+i8WGbo4v72eDb8b+rvzUWdx+8csTzwE2xEmKddffJBxp
pP98kA22ES/oTTtmcbz/8H7RETbU3eotXvdpBr9YoDAbP8EGtkJBemfcDLat
umNCTbJBy1+u7arfDOZLVg2unSL920y14jfM4BwD07rpGTactjDRX/RuGq9I
KK2V5eVAc2hFk/fdKby9NEvwsggHIpVcLumdmMJlF7sLvUU5sP2QhePk9inc
7vQ964AYB8IHQ5dtnpvEqpdKTJRpHLAeSJsUdZ7EwvvsJt0lOSB2ZD3fXv1J
nPfe7aiOFPn+vu7ra4xJLFYNzGHC2/Kuz5UWT+B75pfFPWQ4UGwxPnVVewI7
HYw9zpbnAM3m5tI9ghN4u96hGxRhx/JeC5HGcRymaddow+DAEhHvtK03x3Hg
FWeVECYHKtX+8JS7jePM6/KicgocSLF4dtLYYBzv+nFw8SPCJwUm/woMjmE5
Az6Bp4ocWP91VHxnyRhO+a2ClZU4kCSjdiH46Ri+/0z3TRTh8DeqZ7/uGcNB
sd2sY8pkP7n+SlWLx/AKZcNnNYQzK1duKuUdw5FnWDYbVMj5DTQviEodxSm7
+xwGCO/6FTVne3UU+wikpBixOGB3eTZY0WEU06avr4wh3J4e9qlo/SjmTfdu
byS87e7DQmepUdwnblCixuaAwYOEiOHOERyy6V+TC+GYAIXVp6gRHFPrpBVP
eM7cPbftzgjmq7oVX0841lZqtbH3CG4/7bGLxuEAj+7NF3eNR/BJr4alG//H
6W7s3yojmPHx90Ynwgrtqq8lR4axe7HthVDCztJb96wtHcbrzPb9SyDsmue6
0Cx+GAc55kUWEI6NZWhZnhvGty6Hu9QSXn/139Gd5sO44cIHzy7CYo9D53U1
h7FCgNGzEcICUsFdsnNDGClq0WYIi6DwNS0/hvDV5Y4Jc4RjXkP/kzdD+Cj/
0In/tV8Z3qNmfmUIv9Kt8x79X3vdiaZBqyG86ivjUTdh2+WW2sErhrCRWOpM
HeGyplSGmNAQtsl4c+MT4dZuk8SAhkG8rJ5m/pqwl1XtUFfaIE5u/b0l/H/j
GarPGF4dxGIPFhxxJZz/daoqwn4Qv9LsovQJN4urB5StHcTqYpu2Sf1vPWvO
yMyID+Ktqpp8jeR817nkx7BaB7DY85x/CYQjdqfErosYwJqvmdZLCI/kHAqb
dh3Ahudvx3eT+3wV7Xk4HQawnfjJ3OeEzbXLm/lb+7GU+3U7CcJWzT5nl0X3
423G/V15JF4UNC5og1E/zhGc3uJG2IB2EpQT+jDfW0evdyTeLmo4fO7Y34dd
ub0bdhKOzXueESvch5mvfOu4JF7DHByXZrv/w7yFfFfphJtlw8OaFv/FY7MN
OVok/lUKimL663vxsX4/2RckX3xD7RO7rvZiqdXiiEV4Ivi2wZ3uHmz65ogo
L8mvi2uaDFtedmOPHq1Ld2Q50PAj7tOmA91YpYDnyCDJ15TzOn/9hbqxxste
zW2E14Bt0BfnLrw9Mp7TTfLb7HfYvIlqJ/7M4zo9QeeApbruv8FyLlYziQta
RTilN3hhyCUuZmyyanUj9eNwimX60V8deEBATKWI1JfPHMlXm6Lb8elH2hHm
wqQeiY9eaOdpxWpnwh4/mifvmf3fA3rJLfiMl8nVmDk2HN+8iPK3acHno9lm
obOkvm7tDSjJaMaa4xybw9NseLXsgkpNdSN2VB560TxG6ut0TfDAvXosEmKy
XOkfG5qzLLRZ7XW4lTe9Lq2XDTxZzlUqy+tw0Z2jL7eSen04RKbndkENHuAc
e29P6nn+pXrlM9zvuL3/WtSBFjaoTjd+WGpehuFNSYndDzZETqqcYTR9w1pG
Qf9eV7PBwEi/4u3REhwiU6o3UEm+R8Pi7VeLsJfKnL33f4Tt5ezP43w8kr3z
q04R6R/GaUl1fI6jwr5ElmeyIeDf5xcP5B7hAllIKiPvXcAnpd3eDlGYKu+e
/kLeQx52Ic9GHV+0+ov2xsRk8v0NoR+xlxPRnrGlWzYkkPM5YO7X7lmI6t6k
S5+MYUNs7mFzW+WfKPdhJNp7lA0Dv7ePmNX+RAuDgk2/kPd7YGqg3ya6Bl1u
jytZ5c6GypQQlR/idWgOlmrzOLFBJ/X+Nc25X8gneizC2YoNtJT9+xmnm9E7
q/KTloZsyHu/5w/bnYu0Iz7r1BB98jekJqzkKxcJxvfbZhP9wiOlJB2g2Ynk
kl8x7xB9U/ZHeKdUZyfaZGasZyREzu/qUHCOazfKgiFrz0kWaBlvu8F2/4t4
lM9kdzSyIKe449iaDYPoDI93aFQCC9KWqdR6uQ6itl5JF41nLJC7u2zoVfQg
mpRZ4J/1hAWZKQNM7b5B1JrU6Vkey4JYt5V9ts+GEHvfXagIZ4HBsXg1e4kR
9L1d6CaL6L3tdefDYrlj6Dzr1+TQShZ0edwLPPVoBm3kndqRkawCVU2zR1gV
M0hjUVcjX6IK/OfT4V7MM4vY3lvNzF6oADUTenaB8yy6Y5GZW/2A9N8qtaNx
yRxCmw7KJoepgJOCsqNP9jxKclpX/8RBBWQiTQIaj/CC8rvG2HNSKhARKdbw
OVAAqsQdz1o5KkP5/BZ6JhKDh09C/7MdVYRb6XGTqZmSsKz18d9mBwXg3jBK
1EyVATOPe7KMAAbRk/PzvNry8MN2MePwQzlIE/9mqx/PhGnHaevcUzIQ/0lz
qvSrIiTqB1WXb5aCx13Xp6FCEZY4bzoWskEKAhZsznlXowgOhd3h+iul4K3n
EfcrHYrwwUHbJFFVCj6dztg3wqcEVVXxjJk5ScjdFdgpoq8E3oOnBReclwS/
vLUfut4qQfqh6OONxyTAzKWUo35FGQJ8HzwVsabBQ0l5iv+qMnz9t1qkz4QG
J+gGjQ03lSGC18T7+1oaNN85HeP3SBk4J712Ppamgd0900T/bOKDfj/pXFMi
DnfNrCt9/inDh5BeMY/14sCjLTm/dK8KrHL9xq/AFAPOjg8j+w+qQKLg9l3C
gmLwu4e94qK9CpT2xumND4mC76NFnhmeKpDy44BifbkoqOU/rmgNVAFdEx/H
FyGi0FqhVKb5XgVCXqi/cx4TgZMXU8d30VnQs/IPX3yNMFicmKhxlGGBlLkV
tHwRhu0j7VdPMFlQ7t4euyBDGAYSkl38F7DA40Th+xfRwrD8iVm17VoWmFiE
z+SaC0PXmiXeLFsWRAqO+KqVCoGaM9397QviI26+5uUrEISTki7uioksUE+I
afFKEYSNB+oZAcksCMi95lj/hLAEPqefxQLhcQGrLD9BWLt01wbfYhaU6jUG
huoJglzpzbS/3SzQCXt46mK2AHwdCfT8pkV07BVj+JnKD4+Lcvae1WbDjxel
keVP+WHeVpuHo8OGhPW7B0qi+OHzRpN4O12i8/nDu4pO8IOe7r7hx8ZskP25
R+vXSn7IKs2kLXJgQ0jmI90jaXxwUjDg0mpSV3ys5mlGGbzwrsZov+5dNhRe
0DwT8oIXykdb69feZ4PwGg3n0tu8cMLte+PCOOITXj3ssPXhBd0V3NK8N0T3
X+ZpeqzLC1ptwvf7C8h8zNV9T3N4gC+96ooZqcO0is2tF4PnUc8rhl7tX6LD
U05ukHWeR1n587dtiI42yA19kGI4j3xi+7T2EJ0s9QG/4OGZRwZPR7L6ybvw
8EN07dj5OaT1dhl3kuhUd7PK71tOzqLYK5IH2eQdWxjgtG73nllU363uqCfH
Ae/R4+sddWZRmGH0GhfyjuatqIUnfTPoRfi2b0dUyTtPP3zIx3MGLSz8qo9W
cEBjS0pdnOs0SnqVXzmtw4H4FfoBS7ZOo4aF2wfTVhGdsCr7YJ76NHreoVZP
X0d0a01R0UT7FErZObnOR4/oMK/ukJ9OU2i87shiHkR0dce93KdbptBJRtGL
QODAt5RYD59FU2hrZNTGs4YciEsKstnQNolMVoqWSG3jQPraV0EaTpPI54D9
vKspB5RKj4bqbplEetLH8zK3c2BGbLvZnkWTqEFpR4nhTjJf6Aw8aZtADXQZ
NboFBywms4tfOE8go9fWISv2ciD5cvrPWaMJ9CYjzmuHJQcaFw712qlPIAGx
7k/H9nPAKO/eAT3uOJJMXnrbw5oD1dyfC13cx9EXr3hTUxsOcLvm5VR3jKPP
ShIHFtpyoI79bUHbsnFkKTV04dMhoot8P768PDyGwt8JRF+z40BaueqKQzVj
yOufAd8ue6K7cmP/GXwYQ4dZ57sKDnOgr1BNe4H/GCo6qmJ/yoGMT3PKYTmO
oVjF1cs4jhyQMxF7uNB4DE15MCtcnIjufF51xlh8DLUE+6m/c/lfe9C2gbuj
iOfhxb2rXYnOuGylq3NhFH3/UFSbSvhhREOqr90oGlL80vrIjQOGRgMui9RH
kV4NHBF35wDfF9+3wSKjyDQi2vgU4e2f4x8O9I4grpzj/MojZL6vGTea00ZQ
gntyQxjhusKQRy53RtD9Qh/JX4QTl5QcHz43gkQOvryr7kHi5aWnRPihEZT7
adkZT8KJedaXFm8eQXwzEy/fEPYrCfhcpTaCcmwnV3AJiwkU9VwRGUHb41Xp
yp7kvs5Jjev9HUbvehxgO+GN4kYD8xXD6EJGatEpwq+8Df+Uvh9GP9sEn90l
rLSk93Pc3WEUmL3vRwbh1mjlZL8Lw6i19p51OeGAyuQnLvbDqN+kbG0L4brK
S3H7tgwjs+NdLn2Es83ts3ZpDqM1Sr09o4SHfmj2mosPo2vHqz+PE658/drQ
tn8IVc4/Gh4mfKUl/fPx70NIK3PX2R7CthZM34isIWTbxt39m/Cq2w+dMh4M
oR/rPS4VEU7gl4jo8B9C90r+zL8hHJ65ao7tPIQsxLbVXiOsFlSR47BtCBlV
pfC7Es6fS/j2VnsIWe5fELyRcM3Jc2v4pYfQzKrnNqKEj3cIzDuMDqJdjsah
1eT87sgIrvxWP4gGDGRE7hCO9VxdtQkPIqUbio17CZ+WN+Fmxg+iKFdPURrh
JZ0jPptCB1H8LsVw/L/7de+/WuI5iA7r1lyTIbx9NmwP39pBtHyhJD2dxENe
4GXZt4qDqLp/vG03YY/75046zA2gX7p60T4knvLieRd2fh1ArS/LPHkJX99W
55+dNIBmOnzuh5D4S2jbdDs6agA95kZN+ZN45XFg8brZDKCsb98WdzkTX/Wi
dJUSGkDumh9STQkHJZ/rr1MdQP65R8smSPzrWSTuHyrrR5neMfZbCae8P+2T
casfCd1aaXaD5EtMDKv/plU/OiX3YpUwyScp97hl19r7kIx2r/ZGkm8Ctuly
SYl9KE0t9LIrycfPxUp324/3oRXKGRvfkPydqRZJeTj7Dw3Z8420WxFd7ybN
s1ThH/L35i9uPUB8gEzkTbGmvyjowemJelIfXvnwI76Ev2jwVt2xdFI/4mjM
DRvX/EVKaz0KFM1JvPy9dax8Ty9apx5/uXUXyU/2VXxcsRcVchrjnpP6FLfC
NnlpSw9SNqicldtBfEmBcGrv8R704YuoXoIxqR+G/fx3orrR+f0FcxuMONC1
31d5/mA34tqGL/pK6qOVOL/l5YXdyDtkOuY/Uj8n0l66Vb3vQjb+xxZd20B8
TZTDj6e1nejnmxy+Hl2ynouH3v2M60ThPI9NDEl9Tln9fvEij0508ZicQBOp
35/d6JvEZ7loq+WlfSVLyflnmwZLq3HR/TMbjg0vJr5TSk5Krq8DufveGGJo
kfzJz8nUye5AEX9U129XI/Eqv+d2tlkHKqyzKncgPu+iRZexwNl2dH3twVf7
xInvW7yoPLayFV3/8rxLT5QD257Tn+Y8aUVit5JOsokPqtNaKT7i3YpU1KRc
K/nIfl79/PmW3opmavbU90+ywTx/cSwya0Hpj/KPsYhPMT9okI4fNKGBe14R
r9uJz4l3u8Wj34S8J8fmV7SS93HxMs6pxkbEWbCgcekf4kNcJ+J7FjSiaOWT
sU3Et2jlJnaov2lAAiOtd3Q/smH9V8n8lqJ6pGKRqXMkh4z36rHfBs96tF9q
VPN2FmlXqbT/JFmPVpleXdmQyoY6zyMdRw/WIU7i0i8axIcUi/w5p9pfg3IE
e6OTbxBf8ffGZUm1H8jtja1xBPERBvJJZw8f+Q85nDiYyN5HfNpavkDjwjLk
ulDm4+s9xGf15WyKVC5DDHWx/nfbiQ9ZYLrvQMU3dHhD3MOLemQ/Z3UCUzYV
o17PvkYmh+zn5WqzVM1PSFqDP2SvMvFxVuEf+EMLEepK67rKJPN792/D3AJk
+y60nUt8idTCN25eL/PReo1vFQ48pL9f2ksHmzy0rGJ4q20zC1Q/9TLHH6Sh
ItFbTKMGwgW5NZ/cUtFPob40jToWxBkLRLmsSUG2jd93NlQQvdZdrG8R9wb1
8O3UEaWIzxhrMz2xKB7NSeRe83jIAh7VR2ElqeZYreXTtMVe0j8nMd98WxrO
+35BZ8UuMh41IMA69x43vk3wEjQl/Vl7t7W/SsdL6pbyxiEW5P+NPOMomIU3
+K/8fGMxGT+AqSSXlot51tzl3TmnAjx3Zvx5jxZiX+6Cw98mVCCusb5y6Wwh
FpnRa9w8rAKRMocFqq5/wgckXIHTRdoHTE9cS/yMx3BSQXSVClTeFJjJbSrC
thuxtsszMp5etkq3TikW++W9JfgR+X5igJucXYpDtHyin9wl/XsCVf5BGR4r
Wc0tvKYC5ncVV1ab/Yffip0K/nyK6O0xqYaNhyvwj8FbWhmGKjAQPF6allmF
9x91NbRqUIauGIli6cif+LwH9/jqGmVQPf9GyPXrTzwS4lUsWqkM7rtGjC/N
/cSvnj+cePmJ+Ik2p8gRzxq89plpWGIi4X3TDQJGtfj3f09xyVllmGAFFcd1
1eFNkoLrrE4og4Ld4zq2Sj2+/EK/v8VDGdYbxDPtd9fj1vRryzoPKUO2j8iA
ekY97vjsKvRhizKIeEq8Lb30Cz9Q2xx9QUIZIiuYcV78Dfi55pZuLEzWJ2JR
K7y6AYdZyz2Y5SHttK7zzo4N+CNPqcLRYSU4/PNhnUN+AxbhHngjV6cEqmvx
G89zf7DED5WXoXFKUCe1oTK1qRHn26YKii5XAjXfXJYdbsY1P6P92BpKIDdS
c7npezP+cnv3l+VsJQh6J2q3qbsZp4kEfAEJJZDKkXa9ItuCh/ZaVi3qU4S4
uttiO11bcFW6lupYkiL4/vHyrRBoxWei5q5/eK4IMY72UaPMVhwUKvHv7ENF
8Er79nl0SSs28HGP7LimCEkaC12CzFuxPtZ8GeShCOZmtSP191rx/StJq35o
KMJnCd88B/U23KdyZcSErQjuS/fwaa5rw7w098pMeUUwqh2TLNrahtNPmzUH
CyjCcyO/Y1Fubbh6lXJCd4sCfF72Jdf2ZRu+QoVMlzxQAAWlwpsFnHYc4+4Z
PnBLAeo2ey1ZsLwdZ1fH2ciEK0BxrYGxtV47VjiOKkx8FSB7lWCvlVU7Lq6x
3HLeUgHM174NCY1ox17Gzc/mxRWg60ZcXMJwO14jLwVC/GR8NbMR5/l2nLDn
3HGRKSZon/81OCvWgdt6Z57MdzKhgUn9oRZ0YDHNFb4fPjFBKrhMNXBnB/ZD
YeKPcphwuOiIJ8OqA39fZWR6MZUJZljXJMixAx8+I1W+7AkT8tKqE/p9OnDQ
3DGjQ+eZ8Ld+a5bA4w48umDnSfYJJuiJO+l5vezA+yv47X+7MWH9cKxeckoH
Lvm423/bPiYc/0J7XlDYgSNftiwaWMGE/PpzJeodHVj1Kl/UTQ0meIgHtBz+
14HbT1BVS1hMGAhRd/AZ7cAXS4LqLMWYUP3vQISOIBczXAqNzrYzYGC006ll
IReLLjOIHf3FAJlk7Yv9i7k4odb1x7EqBpivXNNbq8PF1wV3SFthBvj5t3/R
ReT7yOHO8bsM2DoXuHH1AS6W3rS2dF8EA7Z77/4pe4iL9107k/QuiLQbx2WX
O3Lx5d1ppw6cYMBYz3mL70e52HnqweGz2xmg8X72FfMKF9dEbPfPMCDz+8Yc
+hbCxdpjMan96xigZiW7+8A1Lk5Pb7axWsQAhfOFbfPRXCwUsL8+RJEBARFX
g5RjuXhMYM+ZVEkGVDq5HpJ+yMV0Wons9LQ8aL/he3/tGRfvJMmvNCQPNcy3
y6RecnGFtv7OtV3ysGrTlgbvRC627k/TPfxDHtYfuliVk8LFU1Vrxo59k4fK
UDvGq/dcHNVl0H0hXx58CxKvHcvk4qCnEr5hSfIwEXJK4EYuFzfyObHXPpOH
hkAv8byPXGxk3RzQeE8eToZMan2juPh5c8nToEh5+Cz/wDargItbY50CNUPl
wTat/kXgJy7evHtI8+slefCqMRZY8YWLB2Jzo5xOk/WOnj37oYiLvb8Lfprx
kAdrP6n5hcVcPLxIAd9ykIek2qz7niVkvT4bg9WtyHxO7O3R37j4tX+GUsYu
eTh+aYZ2v5SLV2VVB2w2lofICzJt/mVc7Grb8OHbJnnoeatVZvQfF8ufYhWb
r5KHVjvJ4i7CJz61vP2uJQ8a3x/XeJZz8bP6M0f3cuShyDRr/D/CLEFN0Up5
eVCdMVgqWUHiwWpLoClNHiTY2idWEBZ+qdhI8clD/p/jJcsJi4RNKq+elIMG
J8k1dMJbLVbDs345OP5dMvUbGS+ApbBdiisHA6ZXDNwInyqYROcb5GBbk19r
K1nP6p9LVFuq5SD5hfpdfcJ5yXP9RiVykPP6sd1Zsp/9jiUpLyg5sBhS3BBJ
9jtU0OTMnykHDwMqNMLIeaTb3pWwS5KDod3zmvbkvGz9tqZkxJP17BvUkyfn
+XS5kZnYPTnouzzqkkjOm9Lpare5KQeFH52escl9bPwTLD92QQ6u/BU89Jzc
n3baqjR0Uo74IelfGeR+RZb9tQxyl4PY9+uOJpD732M7nCG0Tw68/H7Uqn3g
YlOeKd8tO+Rg6rVzShqJn3FN/x2XNsvBrV36TznpXKyV66fVtYysN2tX+Z1k
LsbFWbqKamQ/nxvFn74h5/3or72JkhxY/nJxDn/FxXGPywUeCMlBjL39kamn
XCxrjNo4TbKQn9Ndv5vkR0Wd0uyGn7LgsbJdcO9NLn68T3LLnlJZkNqXunct
yady3d+2Z7Nkoa+s2Oouyb/kSUfx+Juy8PdiuUbVMS7mc7AreREsC76xIv7/
eXDxp6QPRQkXZEHmbR/vaxeSf+8Nrsa5yQK6V3h91prE1+/wE6eAfP/R4beK
ERdHZP03FbpGFsz3pf6M0Cf5+CXP7t5iWahcmmT4ax0XH14v/ylNVhYOB1lc
nNXiYo9kxX35nTJAWxyVcEaciwtHF4jnNciQes/yfs/PxQ3TdenpVTKw8XJF
9rdpUu9WdPQ/zJWBuoyM5uDeDixS/8zW9KYM7A/cnbe8pAMbPDMVWRYkAwu1
wxvX53fg1zvq8unnZMBiqdpdlawOHOJ4yKXIUQZcn7b+PP68AwtcHvwht04G
UugdP8wudeClj7crLG6QBhGrrAM/NTvwOlc/qaZKaZhy119xXqUDm/6XvO3W
F2n42/y1dEKqA7O8ucEDydIQJiLtEDjZjhMX80dcvywNlXlc6/LidtxuL5Ro
rCENGz2b4tHhdgzWpc3VR6WA9tft7LOTbZjxlXN9xpGwzm35B05tmPbrrbaa
lRTw1TaWn7BswzvK9KyOGkrBafXGp3lr23BOf+LzToYUnLw/uqZ4rBUv12W3
zPhJgnVOeHDOyVYslHQm6yZbAm6taVqy2KIFr58MavQQkQC8a588DVqwlrfu
Y8MhOkQMKz0rX9qClwiHzXZ+oRP9l507JNCCDdczasSO0mHi44R7VkYz7lsb
+ikjhwbHz6WK60o345V+PYe+7hWH49zNSW6H/+CJIk52qr44xDidcJBd/Qcv
+XH87D1NcUiRfKV+RfAPPvn80kaHaTH4jLOEXr9uwEF6Iq7V8WKgutrNntX/
G68eFRqGQVGwule0MdH7F5b1CuU/el0Efkh9oCUY1GIn5V8PN3wUBNq9ktvN
qyqxgczS5XnPBYGnm2bMbqvAYlqTBvrXBeHzmSKrYfsKfP/tLaFNNoJgpe3H
J2RVjj3SLlSrTwqA6uepY1Wby/Dt/COn8RoBcD7wOmvBzFecY35Qm7wVUHej
IeOYIsbeErnqk9rzSEoj999Kl6eoQtmieHxuDsVxeQ7If32GrOstq8cq51BA
Hv+55CUJqCv8senY6TkkJR0UOT+WiBZIG/HM5M2iyNU+O4Qs0tC82GEX7Z0z
iGf7Bt8EzTxU7R5AHfOeRF0VR7TDNxQj3ux6idHMYeTwQ2vIoLEGWfyyw4pB
w6hXm69kdHMtyvp03NtwzzAac/vu2/WiFnmbr5GI6x1CKc9Odod416GE1C+z
N1SH0NtwlYznfL/Q+0vK6obXBtCe4YS/29b9QQL3X8v2F/egRLuE9qUdLSjm
6jXP0849KGxL9OsvSq1osV3yY0GeHvTj30eHi+atyNp7obSZLvHFT7Z5GOS1
IoGSTj+vhE60sfeN5ILbbchDOHwVI7Qd+ddXLFlH/GmyvulNt0XtaMqV5nw3
sAMJnNd7V0S1oRXZQSFyuR2I4qxIS55oRXtpF7Y4LuGigG5X+cWeLWjVyo4C
U7FOtERX8E+vcAt6ujn+SJhhJyrINbH++LwZhR52Ptl6vhO9erTpj+LHJrRV
Ut+xq7cT6ZzRCWKMN6Lasy0aMWpdSFdcNGzlykaUlZggbHOoC6mCvLqn5x80
34KG9e50IcFH/+//CqP///8K/wdjX62H
         "]]},
       Annotation[#, "Charting`Private`Tag$15129#1"]& ]}, {}}, {{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], Dashing[{0.01, 0.01}], FaceForm[Opacity[0.3]], 
        LineBox[CompressedData["
1:eJwt2nk0Vt/XAHAkmSlDhsj03PuYwr0PzbYhKUqmklKRolQqRVIUJZEhpBJR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         "]]},
       Annotation[#, "Charting`Private`Tag$15155#1"]& ]}, {}}, 
    PointBox[{0, 0}]}, {GraphicsComplexBox[CompressedData["
1:eJxc3X/sv/tcx/Hjx3SSxeHg4OD4EU5CPw4i0Y/ZWlLN0mT5g2qUiWmV+MOK
EaORfqjZasWwFdOWVtvxURtNaypTS0pG9AOrdSoroeV63O6fuf46u29nXO/r
9Xxdt7Nzvtf1utfTnv2EH7r5FVdcccODrrji///6oG+99hMfedgjL46/fuXF
x//5zdd+91sfUf/aqx7+nTfe/7Kf9PB3vfArf/3r66s+9IS3/fI1l/0nL/7w
R2756ofXL3rgj1793C+97Ee97zOP/fufflj9n8972U9+x/88tH7LPe/85t9/
7mU//d2v/5v7feKG+rpnfe1tfuEHLvsDd3jnN97sb7+u/vk/ePyzf/R7Lvtx
T/3gr3/wT7+2vuWVP/y+b3vsZd/4lv+6xdtv/Jr6J5744ofe52GX/ZD/verp
r3rLV9f/9Bu/9trP3u+yv/U1T/6Fv3z0Q+q3f/jHP/3Whzy4vv7Br37yy697
UP26F/zWjT941VfVt33PH1/3mJs/sP6ZO330RXe56frL+/MDn/v4TR99QP2M
t93l29/7/vvXH/zcDb/9pnfdr/7O7/ju273o7V9R/+GvPPPHnvLG+9Y3/ONL
/urhr71P/cYbfuMRt3/Zveu7/syNr/vkT92rfuWf/fXn3/0j19Wff8Q/vetb
fu8e9T+8/x6v+PRrr63f8+wnPuG3nn/Xy/W89Suueer3X1O/5g1/9KE7PvpO
9fO+6b9f/yf3vLp+ygcf8swX3uz29Ys/+adPe8a7b3v5++79yH/9i5d9WX3N
k974gm94/JfUH3nl1Ve+4Xa3uJzXl97i+ru/6bPv0J/897/75n978H/WN7vx
Ob/7kmf+c/09D3jce7/v3/+8fvL1X+hHdz3H318/+KYv/O/Vv3r8/9W3+Lkv
XM9j9COO662fffye+g3H762fddyP+meP+1X/5nE/63cc97v+wLEe9X8c61Xf
9pFfWM/6F4/1ru99zEP91mNe6kcd81S/55i3+nuPeaw/esxr/ZxjnuvPHvNe
v/zYD/Wdj/1Sv/7YT/XXHPvt8n4c+7F+3LFf608e+7n+umO/188/ngf1Hx7P
i/rK43lSf9fxvKl/6Xge1X93PK/q+x7Ps/qZx/Ou/p3jeVj/9/G8rL/peJ7W
Lz2et/V7j+dxfcfjeV1///E8v5yn43lf/8vhQT0vzj03rs8PzQ/ND80PzQ/N
D80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND82P7s/80PzQ
/ND80PzQ/ND80PzQ/ND80PzQ/Gg954fmh+aH5ofmR79vfmh+aH40r/ND80Pz
Q/ND86PrmR+aH5ofmh+aH5ofmh+aH5ofmh+aH+2P+aH50fzND80PzQ/Nj/bz
/Gj954fmh+aH5ofmh+aH5ofmh+ZH92N+9DyYH83D/ND80PxoP80PzQ/ND80P
zQ/ND80PzQ/ND80PzQ/ND80PzY/maX5ofmh+nHpOXPqh+aH5ofmh+aH5ofmh
+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofnR/Zkfmh+aH5of
mh+aH5ofmh+aH5ofmh+aH63n/ND80PzQ/ND86PfND80PzY/mdX5ofmh+aH5o
fnQ980PzQ/ND80PzQ/ND80PzQ/ND80Pzo/0xPzQ/mr/5ofmh+aH50X6eH63/
/ND80PzQ/ND80PzQ/ND80PzofsyPngfzo3mYH5ofmh/tp/mh+aH5ofmh+aH5
ofmh+aH5ofmh+aH5ofmh+dE8zQ/ND82PU8+FB+SH5ofmh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH92d+aH5ofmh+aH5o
fmh+aH5ofmh+aH5ofrSe80PzQ/ND80Pzo983PzQ/ND+a1/mh+aH5ofmh+dH1
zA/ND80PzQ/ND80PzQ/ND80PzQ/Nj/bH/ND8aP7mh+aH5ofmR/t5frT+80Pz
Q/ND80PzQ/ND80PzQ/Oj+zE/eh7Mj+Zhfmh+aH60n+aH5ofmh+aH5ofmh+aH
5ofmh+aH5ofmh+aH5kfzND80PzQ/Tj0HLv3Q/ND80PzQ/ND80PzQ/ND80PzQ
/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pzo/swPzQ/ND80PzQ/ND80P
zQ/ND80PzQ/Nj9Zzfmh+aH5ofmh+9Pvmh+aH5kfzOj80PzQ/ND80P7qe+aH5
ofmh+aH5ofmh+aH5ofmh+aH50f6YH5ofzd/80PzQ/ND8aD/Pj9Z/fmh+aH5o
fmh+aH5ofmh+aH50P+ZHz4P50TzMD80PzY/20/zQ/ND80PzQ/ND80PzQ/ND8
0PzQ/ND80PzQ/Gie5ofmh+bHqffcv39+aH5ofmh+aH5ofmh+aH5ofmh+aH5o
fmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+dH/mh+aH5ofmh+aH5ofmh+aH
5ofmh+aH5kfrOT80PzQ/ND80P/p980PzQ/OjeZ0fmh+aH5ofmh9dz/zQ/ND8
0PzQ/ND80PzQ/ND80PzQ/Gh/zA/Nj+Zvfmh+aH5ofrSf50frPz80PzQ/ND80
PzQ/ND80PzQ/uh/zo+fB/Gge5ofmh+ZH+2l+aH5ofmh+aH5ofmh+aH5ofmh+
aH5ofmh+aH40T/ND80Pz49R7zl/6ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5
ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH50f2ZH5ofmh+aH5ofmh+aH5ofmh+a
H5ofmh+t5/zQ/ND80PzQ/Oj3zQ/ND82P5nV+aH5ofmh+aH50PfND80PzQ/ND
80PzQ/ND80PzQ/ND86P9MT80P5q/+aH5ofmh+dF+nh+t//zQ/ND80PzQ/ND8
0PzQ/ND86H7Mj54H86N5mB+aH5of7af5ofmh+aH5ofmh+aH5ofmh+aH5ofmh
+aH5ofnRPM0PzQ/Nj1PvuX6//ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND8
0PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Oj+zA/ND80PzQ/ND80PzQ/ND80PzQ/N
D82P1nN+aH5ofmh+aH70++aH5ofmR/M6PzQ/ND80PzQ/up75ofmh+aH5ofmh
+aH5ofmh+aH5ofnR/pgfmh/N3/zQ/ND80PxoP8+P1n9+aH5ofmh+aH5ofmh+
aH5ofnQ/5kfPg/nRPMwPzQ/Nj/bT/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ
/ND8aJ7mh+aH5sep9xz/ivzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND8
0PzQ/ND80PzQ/ND80PzQ/ND80Pzo/swPzQ/ND80PzQ/ND80PzQ/ND80PzQ/N
j9Zzfmh+aH5ofmh+9Pvmh+aH5kfzOj80PzQ/ND80P7qe+aH5ofmh+aH5ofmh
+aH5ofmh+aH50f6YH5ofzd/80PzQ/ND8aD/Pj9Z/fmh+aH5ofmh+aH5ofmh+
aH50P+ZHz4P50TzMD80PzY/20/zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ
/Gie5ofmh+bHqffcvvRD80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND
80PzQ/ND80PzQ/ND80PzQ/Oj+zM/ND80PzQ/ND80PzQ/ND80PzQ/ND80P1rP
+aH5ofmh+aH50e+bH5ofmh/N6/zQ/ND80PzQ/Oh65ofmh+aH5ofmh+aH5ofm
h+aH5ofmR/tjfmh+NH/zQ/ND80Pzo/08P1r/+aH5ofmh+aH5ofmh+aH5ofnR
/ZgfPQ/mR/MwPzQ/ND/aT/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND86N5
mh+aH5ofp95z+r75ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh
+aH5ofmh+aH5ofmh+aH50f2ZH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+t5/zQ
/ND80PzQ/Oj3zQ/ND82P5nV+aH5ofmh+aH50PfND80PzQ/ND80PzQ/ND80Pz
Q/ND86P9MT80P5q/+aH5ofmh+dF+nh+t//zQ/ND80PzQ/ND80PzQ/ND86H7M
j54H86N5mB+aH5of7af5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofnRPM0P
zQ/Nj1PvuXzph+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmR/dnfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH60nvND80Pz
Q/ND86PfNz80PzQ/mtf5ofmh+aH5ofnR9cwPzQ/ND80PzQ/ND80PzQ/ND80P
zY/2x/zQ/Gj+5ofmh+aH5kf7eX60/vND80PzQ/ND80PzQ/ND80Pzo/sxP3oe
zI/mYX5ofmh+tJ/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH8zQ/ND80
P0695/B98kPzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pz
Q/ND80PzQ/ND86P7Mz80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Ws/5ofmh+aH5
ofnR75sfmh+aH83r/ND80PzQ/ND86Hrmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH
+2N+aH40f/ND80PzQ/Oj/Tw/Wv/5ofmh+aH5ofmh+aH5ofmh+dH9mB89D+ZH
8zA/ND80P9pP80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pzo3maH5ofmh+n
3nP30g/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80P
zQ/ND80PzY/uz/zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND8aD3nh+aH5ofmh+ZH
v29+aH5ofjSv80PzQ/ND80Pzo+uZH5ofmh+aH5ofmh+aH5ofmh+aH5of7Y/5
ofnR/M0PzQ/ND82P9vP8aP3nh+aH5ofmh+aH5ofmh+aH5kf3Y370PJgfzcP8
0PzQ/Gg/zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Nj+Zpfmh+aH6ces/Z
e+eH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH
5ofmh+ZH92d+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofrSe80PzQ/ND80Pzo983
PzQ/ND+a1/mh+aH5ofmh+dH1zA/ND80PzQ/ND80PzQ/ND80PzQ/Nj/bH/ND8
aP7mh+aH5ofmR/t5frT+80PzQ/ND80PzQ/ND80PzQ/Oj+zE/eh7Mj+Zhfmh+
aH60n+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5kfzND80PzQ/Tr3n6qUf
mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+a
H5of3Z/5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+dF6zg/ND80PzQ/Nj37f/ND8
0PxoXueH5ofmh+aH5kfXMz80PzQ/ND80PzQ/ND80PzQ/ND80P9of80Pzo/mb
H5ofmh+aH+3n+dH6zw/ND80PzQ/ND80PzQ/ND82P7sf86HkwP5qH+aH5ofnR
fpofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh/N0/zQ/ND8OPWeo/fKD80P
zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/N
j+7P/ND80PzQ/ND80PzQ/ND80PzQ/ND80PxoPeeH5ofmh+aH5ke/b35ofmh+
NK/zQ/ND80PzQ/Oj65kfmh+aH5ofmh+aH5ofmh+aH5ofmh/tj/mh+dH8zQ/N
D80PzY/28/xo/eeH5ofmh+aH5ofmh+aH5ofmR/djfvQ8mB/Nw/zQ/ND8aD/N
D80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND82P5ml+aH5ofpx6z81LPzQ/ND80
PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80P7o/
80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Oj9Zwfmh+aH5ofmh/9vvmh+aH50bzO
D80PzQ/ND82Prmd+aH5ofmh+aH5ofmh+aH5ofmh+aH60P+aH5kfzNz80PzQ/
ND/az/Oj9Z8fmh+aH5ofmh+aH5ofmh+aH92P+dHzYH40D/ND80Pzo/00PzQ/
ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/mqf5ofmh+XHqPSevyw/ND80PzQ/N
D80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzY/uz/zQ
/ND80PzQ/ND80PzQ/ND80PzQ/ND8aD3nh+aH5ofmh+ZHv29+aH5ofjSv80Pz
Q/ND80Pzo+uZH5ofmh+aH5ofmh+aH5ofmh+aH5of7Y/5ofnR/M0PzQ/ND82P
9vP8aP3nh+aH5ofmh+aH5ofmh+aH5kf3Y370PJgfzcP80PzQ/Gg/zQ/ND80P
zQ/ND80PzQ/ND80PzQ/ND80PzQ/Nj+Zpfmh+aH6ces/FSz80PzQ/ND80PzQ/
ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND+6P/ND80Pz
Q/ND80PzQ/ND80PzQ/ND80Pzo/WcH5ofmh+aH5of/b75ofmh+dG8zg/ND80P
zQ/Nj65nfmh+aH5ofmh+aH5ofmh+aH5ofmh+tD/mh+ZH8zc/ND80PzQ/2s/z
o/WfH5ofmh+aH5ofmh+aH5ofmh/dj/nR82B+NA/zQ/ND86P9ND80PzQ/ND80
PzQ/ND80PzQ/ND80PzQ/ND80P5qn+aH5oflx6j0H75kfmh+aH5ofmh+aH5of
mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5of3Z/5ofmh+aH5
ofmh+aH5ofmh+aH5ofmh+dF6zg/ND80PzQ/Nj37f/ND80PxoXueH5ofmh+aH
5kfXMz80PzQ/ND80PzQ/ND80PzQ/ND80P9of80Pzo/mbH5ofmh+aH+3n+dH6
zw/ND80PzQ/ND80PzQ/ND82P7sf86HkwP5qH+aH5ofnRfpofmh+aH5ofmh+a
H5ofmh+aH5ofmh+aH5ofmh/N0/zQ/ND8OPWee/fID80PzQ/ND80PzQ/ND80P
zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Nj+7P/ND80PzQ/ND8
0PzQ/ND80PzQ/ND80PxoPeeH5ofmh+aH5ke/b35ofmh+NK/zQ/ND80PzQ/Oj
65kfmh+aH5ofmh+aH5ofmh+aH5ofmh/tj/mh+dH8zQ/ND80PzY/28/xo/eeH
5ofmh+aH5ofmh+aH5ofmR/djfvQ8mB/Nw/zQ/ND8aD/ND80PzQ/ND80PzQ/N
D80PzQ/ND80PzQ/ND82P5ml+aH5ofpx6z7m754fmh+aH5ofmh+aH5ofmh+aH
5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5kf3Z35ofmh+aH5ofmh+
aH5ofmh+aH5ofmh+tJ7zQ/ND80PzQ/Oj3zc/ND80P5rX+aH5ofmh+aH50fXM
D80PzQ/ND80PzQ/ND80PzQ/ND82P9sf80Pxo/uaH5ofmh+ZH+3l+tP7zQ/ND
80PzQ/ND80PzQ/ND86P7MT96HsyP5mF+aH5ofrSf5ofmh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmR/M0PzQ/ND9Ovefatfmh+aH5ofmh+aH5ofmh+aH5ofmh
+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofnR/Zkfmh+aH5ofmh+aH5of
mh+aH5ofmh+aH63n/ND80PzQ/ND86PfND80PzY/mdX5ofmh+aH5ofnQ980Pz
Q/ND80PzQ/ND80PzQ/ND80Pzo/0xPzQ/mr/5ofmh+aH50X6eH63//ND80PzQ
/ND80PzQ/ND80PzofsyPngfzo3mYH5ofmh/tp/mh+aH5ofmh+aH5ofmh+aH5
ofmh+aH5ofmh+dE8zQ/ND82PU+85drf80PzQ/ND80PzQ/ND80PzQ/ND80PzQ
/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND86P7MD80PzQ/ND80PzQ/ND80P
zQ/ND80PzY/Wc35ofmh+aH5ofvT75ofmh+ZH8zo/ND80PzQ/ND+6nvmh+aH5
ofmh+aH5ofmh+aH5ofmh+dH+mB+aH83f/ND80PzQ/Gg/z4/Wf35ofmh+aH5o
fmh+aH5ofmh+dD/mR8+D+dE8zA/ND82P9tP80PzQ/ND80PzQ/ND80PzQ/ND8
0PzQ/ND80PxonuaH5ofmx6n33LpLfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5o
fmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofnR/5ofmh+aH5ofmh+aH5ofmh+aH
5ofmh+ZH6zk/ND80PzQ/ND/6ffND80Pzo3mdH5ofmh+aH5ofXc/80PzQ/ND8
0PzQ/ND80PzQ/ND80Pxof8wPzY/mb35ofmh+aH60n+dH6z8/ND80PzQ/ND80
PzQ/ND80P7of86PnwfxoHuaH5ofmR/tpfmh+aH5ofmh+aH5ofmh+aH5ofmh+
aH5ofmh+NE/zQ/ND8+PUe05dc3n+4LrzB9edP7ju/MF15w+uO39w3fmD684f
XHf+4LrzB9edP7ju/MF15w+uO39w3fmD684fXHf+4LrzB9f80J0/uO78wXXn
D647f3Dd+YPrzh90f5w/uO78wXXnD647f3Dd+YPrzh9cd/7guvMH150/uO78
wXXnD647f9B6On9w3fmD684fXHf+4LrzB/0+5w+uO39w3fmD5tX5g+vOH1x3
/uC68wfXnT/oepw/uO78wXXnD647f3Dd+YPrzh9cd/7guvMH150/uO78wXXn
D9ofzh9c86P5c/7guvMH150/uO78QfvZ+YPW3/mD684fXHf+4LrzB9edP7ju
/MF15w+uO39w3fmD7sf86HkwP5qH+aE7f3Dd+YP20/zQnT+47vzBdecPrjt/
cN35g+vOH1x3/uC68wfXnT+47vzBdecPrjt/cN35g+bJ+YPrzh9cd/7gF/ee
S3fOD80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/N
D80PzQ/Nj+7P/ND80PzQ/ND80PzQ/ND80PzQ/ND80PxoPeeH5ofmh+aH5ke/
b35ofmh+NK/zQ/ND80PzQ/Oj65kfmh+aH5ofmh+aH5ofmh+aH5ofmh/tj/mh
+dH8zQ/ND80PzY/28/xo/eeH5ofmh+aH5ofmh+aH5ofmR/djfvQ8mB/Nw/zQ
/ND8aD/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND82P5ml+aH5ofpx6z6E7
5Yfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofm
h+aH5kf3Z35ofmh+aH5ofmh+aH5ofmh+aH5ofmh+tJ7zQ/ND80PzQ/Oj3zc/
ND80P5rX+aH5ofmh+aH50fXMD80PzQ/ND80PzQ/ND80PzQ/ND82P9sf80Pxo
/uaH5ofmh+ZH+3l+tP7zQ/ND80PzQ/ND80PzQ/ND86P7MT96HsyP5mF+aH5o
frSf5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmR/M0PzQ/ND9OvefOHfND
80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pz
Q/Oj+zM/ND80PzQ/ND80PzQ/ND80PzQ/ND80P1rP+aH5ofmh+aH50e+bH5of
mh/N6/zQ/ND80PzQ/Oh65ofmh+aH5ofmh+aH5ofmh+aH5ofmR/tjfmh+NH/z
Q/ND80Pzo/08P1r/+aH5ofmh+aH5ofmh+aH5ofnR/ZgfPQ/mR/MwPzQ/ND/a
T/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND86N5mh+aH5ofp95z5ur80PzQ
/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND8
6P7MD80PzQ/ND80PzQ/ND80PzQ/ND80PzY/Wc35ofmh+aH5ofvT75ofmh+ZH
8zo/ND80PzQ/ND+6nvmh+aH5ofmh+aH5ofmh+aH5ofmh+dH+mB+aH83f/ND8
0PzQ/Gg/z4/Wf35ofmh+aH5ofmh+aH5ofmh+dD/mR8+D+dE8zA/ND82P9tP8
0PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PxonuaH5ofmx6n3XLlDfmh+aH5o
fmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofnR/
5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH6zk/ND80PzQ/ND/6ffND80Pzo3md
H5ofmh+aH5ofXc/80PzQ/ND80PzQ/ND80PzQ/ND80Pxof8wPzY/mb35ofmh+
aH60n+dH6z8/ND80PzQ/ND80PzQ/ND80P7of86PnwfxoHuaH5ofmR/tpfmh+
aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+NE/zQ/ND8+PUe47cPj80PzQ/ND80
PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND+6P/ND
80PzQ/ND80PzQ/ND80PzQ/ND80Pzo/WcH5ofmh+aH5of/b75ofmh+dG8zg/N
D80PzQ/Nj65nfmh+aH5ofmh+aH5ofmh+aH5ofmh+tD/mh+ZH8zc/ND80PzQ/
2s/zo/WfH5ofmh+aH5ofmh+aH5ofmh/dj/nR82B+NA/zQ/ND86P9ND80PzQ/
ND80PzQ/ND80PzQ/ND80PzQ/ND80P5qn+aH5oflx6j03rsoPzQ/ND80PzQ/N
D80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND82P7s/80PzQ
/ND80PzQ/ND80PzQ/ND80PzQ/Gg954fmh+aH5ofmR79vfmh+aH40r/ND80Pz
Q/ND86PrmR+aH5ofmh+aH5ofmh+aH5ofmh+aH+2P+aH50fzND80PzQ/Nj/bz
/Gj954fmh+aH5ofmh+aH5ofmh+ZH92N+9DyYH83D/ND80PxoP80PzQ/ND80P
zQ/ND80PzQ/ND80PzQ/ND80PzY/maX5ofmh+nHrPidvlh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmR/dnfmh+aH5o
fmh+aH5ofmh+aH5ofmh+aH60nvND80PzQ/ND86PfNz80PzQ/mtf5ofmh+aH5
ofnR9cwPzQ/ND80PzQ/ND80PzQ/ND80PzY/2x/zQ/Gj+5ofmh+aH5kf7eX60
/vND80PzQ/ND80PzQ/ND80Pzo/sxP3oezI/mYX5ofmh+tJ/mh+aH5ofmh+aH
5ofmh+aH5ofmh+aH5ofmh+ZH8zQ/ND80P06958KX54fmh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5kf3Z35ofmh+aH5o
fmh+aH5ofmh+aH5ofmh+tJ7zQ/ND80PzQ/Oj3zc/ND80P5rX+aH5ofmh+aH5
0fXMD80PzQ/ND80PzQ/ND80PzQ/ND82P9sf80Pxo/uaH5ofmh+ZH+3l+tP7z
Q/ND80PzQ/ND80PzQ/ND86P7MT96HsyP5mF+aH5ofrSf5ofmh+aH5ofmh+aH
5ofmh+aH5ofmh+aH5ofmR/M0PzQ/ND9OvefAbfJD80PzQ/ND80PzQ/ND80Pz
Q/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Oj+zM/ND80PzQ/ND80
PzQ/ND80PzQ/ND80P1rP+aH5ofmh+aH50e+bH5ofmh/N6/zQ/ND80PzQ/Oh6
5ofmh+aH5ofmh+aH5ofmh+aH5ofmR/tjfmh+NH/zQ/ND80Pzo/08P1r/+aH5
ofmh+aH5ofmh+aH5ofnR/ZgfPQ/mR/MwPzQ/ND/aT/ND80PzQ/ND80PzQ/ND
80PzQ/ND80PzQ/ND86N5mh+aH5ofp96+v3V+aH5ofmh+aH5ofmh+aH5ofmh+
aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+dH/mh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5kfrOT80PzQ/ND80P/p980PzQ/OjeZ0fmh+aH5ofmh9dz/zQ
/ND80PzQ/ND80PzQ/ND80PzQ/Gh/zA/Nj+Zvfmh+aH5ofrSf50frPz80PzQ/
ND80PzQ/ND80PzQ/uh/zo+fB/Gge5ofmh+ZH+2l+aH5ofmh+aH5ofmh+aH5o
fmh+aH5ofmh+aH40T/ND80Pz49Tb51fmh+aH5ofmh+aH5ofmh+aH5ofmh+aH
5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmR/dnfmh+aH5ofmh+aH5ofmh+
aH5ofmh+aH60nvND80PzQ/ND86PfNz80PzQ/mtf5ofmh+aH5ofnR9cwPzQ/N
D80PzQ/ND80PzQ/ND80PzY/2x/zQ/Gj+5ofmh+aH5kf7eX60/vND80PzQ/ND
80PzQ/ND80Pzo/sxP3oezI/mYX5ofmh+tJ/mh+aH5ofmh+aH5ofmh+aH5ofm
h+aH5ofmh+ZH8zQ/ND80P069fX2r/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ
/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Oj+zA/ND80PzQ/ND80PzQ/ND80P
zQ/ND82P1nN+aH5ofmh+aH70++aH5ofmR/M6PzQ/ND80PzQ/up75ofmh+aH5
ofmh+aH5ofmh+aH5ofnR/pgfmh/N3/zQ/ND80PxoP8+P1n9+aH5ofmh+aH5o
fmh+aH5ofnQ/5kfPg/nRPMwPzQ/Nj/bT/ND80PzQ/ND80PzQ/ND80PzQ/ND8
0PzQ/ND8aJ7mh+aH5sept49vmR+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+a
H5ofmh+aH5ofmh+aH5ofmh+aH5ofmh/dn/mh+aH5ofmh+aH5ofmh+aH5ofmh
+aH50XrOD80PzQ/ND82Pft/80PzQ/Ghe54fmh+aH5ofmR9czPzQ/ND80PzQ/
ND80PzQ/ND80PzQ/2h/zQ/Oj+Zsfmh+aH5of7ef50frPD80PzQ/ND80PzQ/N
D80PzY/ux/zoeTA/mof5ofmh+dF+mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5of
mh+aH83T/ND80Pw49fbtzfND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pz
Q/ND80PzQ/ND80PzQ/ND80PzQ/Oj+zM/ND80PzQ/ND80PzQ/ND80PzQ/ND80
P1rP+aH5ofmh+aH50e+bH5ofmh/N6/zQ/ND80PzQ/Oh65ofmh+aH5ofmh+aH
5ofmh+aH5ofmR/tjfmh+NH/zQ/ND80Pzo/08P1r/+aH5ofmh+aH5ofmh+aH5
ofnR/ZgfPQ/mR/MwPzQ/ND/aT/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND
86N5mh+aH5ofp94+/fw7+KH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh
+aH5ofmh+aH5ofmh+aH5ofmh+dH9mR+aH5ofmh+aH5ofmh+aH5ofmh+aH5of
ref80PzQ/ND80Pzo980PzQ/Nj+Z1fmh+aH5ofmh+dD3zQ/ND80PzQ/ND80Pz
Q/ND80PzQ/Oj/TE/ND+av/mh+aH5ofnRfp4frf/80PzQ/ND80PzQ/ND80PzQ
/Oh+zI+eB/OjeZgfmh+aH+2n+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5
0TzND80PzY9T75/rPpMfuu/vrvv+7rrv7677/u667++u+/7uuu/vrvv+7rrv
7677/u667++u+/7uuu/vrvv+7rrv7677/u667++u+/7uuu/vrvv+7rrv7677
/u667++u+/6u++P7u+u+v7vu+7vrvr+77vu7676/u+77u+u+v7vu+7vrvr+7
7vu7676/az19f3fd93fXfX933fd3131/1+/z/d11399d9/1d8+r7u+u+v7vu
+7vrvr+77vu7rsf3d9d9f3fd93fXfX933fd3131/d933d9d9f3fd93fXfX93
3fd37Q/f3133/V3z5/u7676/u+77u+u+v2s/+/6u9ff93XXf3133/d11399d
9/3ddd/fXff93XXf3133/V33w/d3PQ98f9c8+P7uuu/vrvv+rv3k+7vrvr+7
7vu7676/u+77u+u+v7vu+7vrvr+77vu7676/u+77u+u+v7vu+7vrvr9rnnx/
d933d9d9f/eLe/8e4NP5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5
ofmh+aH5ofmh+aH5ofmh+aH50f2ZH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+t
5/zQ/ND80PzQ/Oj3zQ/ND82P5nV+aH5ofmh+aH50PfND80PzQ/ND80PzQ/ND
80PzQ/ND86P9MT80P5q/+aH5ofmh+dF+nh+t//zQ/ND80PzQ/ND80PzQ/ND8
6H7Mj54H86N5mB+aH5of7af5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofnR
PM0PzQ/Nj1Pv3xvflB+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+a
H5ofmh+aH5ofmh+aH5ofmh/dn/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH50XrO
D80PzQ/ND82Pft/80PzQ/Ghe54fmh+aH5ofmR9czPzQ/ND80PzQ/ND80PzQ/
ND80PzQ/2h/zQ/Oj+Zsfmh+aH5of7ef50frPD80PzQ/ND80PzQ/ND80PzY/u
x/zoeTA/mof5ofmh+dF+mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH83T
/ND80Pw49f4746fyQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND
80PzQ/ND80PzQ/ND80Pzo/szPzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND9az/mh
+aH5ofmh+dHvmx+aH5ofzev80PzQ/ND80PzoeuaH5ofmh+aH5ofmh+aH5ofm
h+aH5kf7Y35ofjR/80PzQ/ND86P9PD9a//mh+aH5ofmh+aH5ofmh+aH50f2Y
Hz0P5kfzMD80PzQ/2k/zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/OjeZof
mh+aH6fen0v5WH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+
aH5ofmh+aH5ofmh+aH50f+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmR+s5PzQ/
ND80PzQ/+n3zQ/ND86N5nR+aH5ofmh+aH13P/ND80PzQ/ND80PzQ/ND80PzQ
/ND8aH/MD82P5m9+aH5ofmh+tJ/nR+s/PzQ/ND80PzQ/ND80PzQ/ND+6H/Oj
58H8aB7mh+aH5kf7aX5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofjRP80Pz
Q/Pj1PtzjB/ID80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/N
D80PzQ/ND80PzQ/Nj+7P/ND80PzQ/ND80PzQ/ND80PzQ/ND80PxoPeeH5ofm
h+aH5ke/b35ofmh+NK/zQ/ND80PzQ/Oj65kfmh+aH5ofmh+aH5ofmh+aH5of
mh/tj/mh+dH8zQ/ND80PzY/28/xo/eeH5ofmh+aH5ofmh+aH5ofmR/djfvQ8
mB/Nw/zQ/ND8aD/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND82P5ml+aH5o
fpx6f+79nfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh
+aH5ofmh+aH5ofnR/Zkfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH63n/ND80PzQ
/ND86PfND80PzY/mdX5ofmh+aH5ofnQ980PzQ/ND80PzQ/ND80PzQ/ND80Pz
o/0xPzQ/mr/5ofmh+aH50X6eH63//ND80PzQ/ND80PzQ/ND80PzofsyPngfz
o3mYH5ofmh/tp/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+dE8zQ/ND82P
U+89qXc+mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+a
H5ofmh+aH5ofmh/dn/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH50XrOD80PzQ/N
D82Pft/80PzQ/Ghe54fmh+aH5ofmR9czPzQ/ND80PzQ/ND80PzQ/ND80PzQ/
2h/zQ/Oj+Zsfmh+aH5of7ef50frPD80PzQ/ND80PzQ/ND80PzY/ux/zoeTA/
mof5ofmh+dF+mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH83T/ND80Pw4
9d6r/UB+6N4fXPf+4Lr3B9e9P7ju/cF17w+ue39w3fuD694fXPf+4Lr3B9e9
P7ju/cF17w+ue39w3fuD694fXPf+4Lr3B9e9P7ju/cF17w+ue39w3fuD7o/3
B9e9P7ju/cF17w+ue39w3fuD694fXPf+4Lr3B9e9P7ju/cF17w9aT+8Prnt/
cN37g+veH1z3/qDf5/3Bde8Prnt/0Lx6f3Dd+4Pr3h9c9/7guvcHXc/80L0/
uO79wXXvD657f3Dd+4Pr3h9c9/7guvcH170/uO79QfvD+4Pr3h80f94fXPf+
4Lr3B9e9P2g/e3/Q+nt/cN37g+veH1z3/uC69wfXvT+47v3Bde8Prnt/0P3w
/qDngfcHzYP3B9e9P7ju/UH7yfuD694fXPf+4Lr3B9e9P7ju/cF17w+ue39w
3fuD694fXPf+4Lr3B9e9P7ju/UHz5P3Bde8Prnt/8It732H4WH5ofmh+aH5o
fmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH50f+aH
5ofmh+aH5ofmh+aH5ofmh+aH5ofmR+s5PzQ/ND80PzQ/+n3zQ/ND86N5nR+a
H5ofmh+aH13P/ND80PzQ/ND80PzQ/ND80PzQ/ND8aH/MD82P5m9+aH5ofmh+
tJ/nR+s/PzQ/ND80PzQ/ND80PzQ/ND+6H/Oj58H8aB7mh+aH5kf7aX5ofmh+
aH5ofmh+aH5ofmh+aH5ofmh+aH5ofjRP80PzQ/Pj1Ptuz6fyQ/ND80PzQ/ND
80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pzo/szPzQ/
ND80PzQ/ND80PzQ/ND80PzQ/ND9az/mh+aH5ofmh+dHvmx+aH5ofzev80PzQ
/ND80PzoeuaH5ofmh+aH5ofmh+aH5ofmh+aH5kf7Y35ofjR/80PzQ/ND86P9
PD9a//mh+aH5ofmh+aH5ofmh+aH50f2YHz0P5kfzMD80PzQ/2k/zQ/ND80Pz
Q/ND80PzQ/ND80PzQ/ND80PzQ/OjeZofmh+aH6fed95uyg/ND80PzQ/ND80P
zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzY/uz/zQ/ND8
0PzQ/ND80PzQ/ND80PzQ/ND8aD3nh+aH5ofmh+ZHv29+aH5ofjSv80PzQ/ND
80Pzo+uZH5ofmh+aH5ofmh+aH5ofmh+aH5of7Y/5ofnR/M0PzQ/ND82P9vP8
aP3nh+aH5ofmh+aH5ofmh+aH5kf3Y370PJgfzcP80PzQ/Gg/zQ/ND80PzQ/N
D80PzQ/ND80PzQ/ND80PzQ/Nj+Zpfmh+aH6cet8F/XR+aH5ofmh+aH5ofmh+
aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+dH/mh+aH5ofm
h+aH5ofmh+aH5ofmh+aH5kfrOT80PzQ/ND80P/p980PzQ/OjeZ0fmh+aH5of
mh9dz/zQ/ND80PzQ/ND80PzQ/ND80PzQ/Gh/zA/Nj+Zvfmh+aH5ofrSf50fr
Pz80PzQ/ND80PzQ/ND80PzQ/uh/zo+fB/Gge5ofmh+ZH+2l+aH5ofmh+aH5o
fmh+aH5ofmh+aH5ofmh+aH40T/ND80Pz49T7jvRn8kPzQ/ND80PzQ/ND80Pz
Q/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND86P7Mz80PzQ/ND80
PzQ/ND80PzQ/ND80PzQ/Ws/5ofmh+aH5ofnR75sfmh+aH83r/ND80PzQ/ND8
6Hrmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH+2N+aH40f/ND80PzQ/Oj/Tw/Wv/5
ofmh+aH5ofmh+aH5ofmh+dH9mB89D+ZH8zA/ND80P9pP80PzQ/ND80PzQ/ND
80PzQ/ND80PzQ/ND80Pzo3maH5ofmh+n3rkDn88PzQ/ND80PzQ/ND80PzQ/N
D80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND82P7s/80PzQ/ND80PzQ
/ND80PzQ/ND80PzQ/Gg954fmh+aH5ofmR79vfmh+aH40r/ND80PzQ/ND86Pr
mR+aH5ofmh+aH5ofmh+aH5ofmh+aH+2P+aH50fzND80PzQ/Nj/bz/Gj954fm
h+aH5ofmh+aH5ofmh+ZH92N+9DyYH83D/ND80PxoP80PzQ/ND80PzQ/ND80P
zQ/ND80PzQ/ND80PzY/maX5ofmh+nHrn1Nz8MfzQ/ND80PzQ/ND80PzQ/ND8
0PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pzo/swPzQ/ND80PzQ/N
D80PzQ/ND80PzQ/Nj9Zzfmh+aH5ofmh+9Pvmh+aH5kfzOj80PzQ/ND80P7qe
+aH5ofmh+aH5ofmh+aH5ofmh+aH50f6YH5ofzd/80PzQ/ND8aD/Pj9Z/fmh+
aH5ofmh+aH5ofmh+aH50P+ZHz4P50TzMD80PzY/20/zQ/ND80PzQ/ND80PzQ
/ND80PzQ/ND80PzQ/Gie5ofmh+bHqXeu2S3zQ/ND80PzQ/ND80PzQ/ND80Pz
Q/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pzo/szPzQ/ND80PzQ/ND80
PzQ/ND80PzQ/ND9az/mh+aH5ofmh+dHvmx+aH5ofzev80PzQ/ND80PzoeuaH
5ofmh+aH5ofmh+aH5ofmh+aH5kf7Y35ofjR/80PzQ/ND86P9PD9a//mh+aH5
ofmh+aH5ofmh+aH50f2YHz0P5kfzMD80PzQ/2k/zQ/ND80PzQ/ND80PzQ/ND
80PzQ/ND80PzQ/OjeZofmh+aH6feOZi3yg/ND80PzQ/ND80PzQ/ND80PzQ/N
D80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzY/uz/zQ/ND80PzQ/ND80PzQ
/ND80PzQ/ND8aD3nh+aH5ofmh+ZHv29+aH5ofjSv80PzQ/ND80Pzo+uZH5of
mh+aH5ofmh+aH5ofmh+aH5of7Y/5ofnR/M0PzQ/ND82P9vP8aP3nh+aH5ofm
h+aH5ofmh+aH5kf3Y370PJgfzcP80PzQ/Gg/zQ/ND80PzQ/ND80PzQ/ND80P
zQ/ND80PzQ/Nj+Zpfmh+aH6ceucmX5kfmh+aH5ofmh+aH5ofmh+aH5ofmh+a
H5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5of3Z/5ofmh+aH5ofmh+aH5ofmh
+aH5ofmh+dF6zg/ND80PzQ/Nj37f/ND80PxoXueH5ofmh+aH5kfXMz80PzQ/
ND80PzQ/ND80PzQ/ND80P9of80Pzo/mbH5ofmh+aH+3n+dH6zw/ND80PzQ/N
D80PzQ/ND82P7sf86HkwP5qH+aH5ofnRfpofmh+aH5ofmh+aH5ofmh+aH5of
mh+aH5ofmh/N0/zQ/ND8OPXFMWe3zg/ND80PzQ/ND80PzQ/ND80PzQ/ND80P
zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzY/uz/zQ/ND80PzQ/ND80PzQ/ND8
0PzQ/ND8aD3nh+aH5ofmh+ZHv29+aH5ofjSv80PzQ/ND80Pzo+uZH5ofmh+a
H5ofmh+aH5ofmh+aH5of7Y/5ofnR/M0PzQ/ND82P9vP8aP3nh+aH5ofmh+aH
5ofmh+aH5kf3Y370PJgfzcP80PzQ/Gg/zQ/ND80PzQ/ND80PzQ/ND80PzQ/N
D80PzQ/Nj+Zpfmh+aH6c+uKYq9vkh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmR/dnfmh+aH5ofmh+aH5ofmh+aH5o
fmh+aH60nvND80PzQ/ND86PfNz80PzQ/mtf5ofmh+aH5ofnR9cwPzQ/ND80P
zQ/ND80PzQ/ND80PzY/2x/zQ/Gj+5ofmh+aH5kf7eX60/vND80PzQ/ND80Pz
Q/ND80Pzo/sxP3oezI/mYX5ofmh+tJ/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH
5ofmh+ZH8zQ/ND80P059cczRl+eH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH
5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH92d+aH5ofmh+aH5ofmh+aH5ofmh+
aH5ofrSe80PzQ/ND80Pzo983PzQ/ND+a1/mh+aH5ofmh+dH1zA/ND80PzQ/N
D80PzQ/ND80PzQ/Nj/bH/ND8aP7mh+aH5ofmR/t5frT+80PzQ/ND80PzQ/ND
80PzQ/Oj+zE/eh7Mj+Zhfmh+aH60n+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofm
h+aH5kfzND80PzQ/Tn1xzM3t8kPzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80Pz
Q/ND80PzQ/ND80PzQ/ND80PzQ/ND86P7Mz80PzQ/ND80PzQ/ND80PzQ/ND80
PzQ/Ws/5ofmh+aH5ofnR75sfmh+aH83r/ND80PzQ/ND86Hrmh+aH5ofmh+aH
5ofmh+aH5ofmh+ZH+2N+aH40f/ND80PzQ/Oj/Tw/Wv/5ofmh+aH5ofmh+aH5
ofmh+dH9mB89D+ZH8zA/ND80P9pP80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND
80Pzo3maH5ofmh+nvjjm5Kr80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ
/ND80PzQ/ND80PzQ/ND80PzQ/ND86P7MD80PzQ/ND80PzQ/ND80PzQ/ND80P
zY/Wc35ofmh+aH5ofvT75ofmh+ZH8zo/ND80PzQ/ND+6nvmh+aH5ofmh+aH5
ofmh+aH5ofmh+dH+mB+aH83f/ND80PzQ/Gg/z4/Wf35ofmh+aH5ofmh+aH5o
fmh+dD/mR8+D+dE8zA/ND82P9tP80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND8
0PxonuaH5ofmx6kvjrm4fX5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+
aH5ofmh+aH5ofmh+aH5ofmh+aH50f+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofm
R+s5PzQ/ND80PzQ/+n3zQ/ND86N5nR+aH5ofmh+aH13P/ND80PzQ/ND80PzQ
/ND80PzQ/ND8aH/MD82P5m9+aH5ofmh+tJ/nR+s/PzQ/ND80PzQ/ND80PzQ/
ND+6H/Oj58H8aB7mh+aH5kf7aX5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5o
fjRP80PzQ/Pj1BfHHNwhPzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80
PzQ/ND80PzQ/ND80PzQ/ND80P7o/80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Oj
9Zwfmh+aH5ofmh/9vvmh+aH50bzOD80PzQ/ND82Prmd+aH5ofmh+aH5ofmh+
aH5ofmh+aH60P+aH5kfzNz80PzQ/ND/az/Oj9Z8fmh+aH5ofmh+aH5ofmh+a
H92P+dHzYH40D/ND80Pzo/00PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/
mqf5ofmh+XHqi2Pdr84PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80P
zQ/ND80PzQ/ND80PzQ/ND82P7s/80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/Gg9
54fmh+aH5ofmR79vfmh+aH40r/ND80PzQ/ND86PrmR+aH5ofmh+aH5ofmh+a
H5ofmh+aH+2P+aH50fzND80PzQ/Nj/bz/Gj954fmh+aH5ofmh+aH5ofmh+ZH
92N+9DyYH83D/ND80PxoP80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzY/m
aX5ofmh+nPriWOc75ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmh+aH5kf3Z35ofmh+aH5ofmh+aH5ofmh+aH5ofmh+tJ7z
Q/ND80PzQ/Oj3zc/ND80P5rX+aH5ofmh+aH50fXMD80PzQ/ND80PzQ/ND80P
zQ/ND82P9sf80Pxo/uaH5ofmh+ZH+3l+tP7zQ/ND80PzQ/ND80PzQ/ND86P7
MT96HsyP5mF+aH5ofrSf5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmR/M0
PzQ/ND9OfXGs653yQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND
80PzQ/ND80PzQ/ND80Pzo/szPzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND9az/mh
+aH5ofmh+dHvmx+aH5ofzev80PzQ/ND80PzoeuaH5ofmh+aH5ofmh+aH5ofm
h+aH5kf7Y35ofjR/80PzQ/ND86P9PD9a//mh+aH5ofmh+aH5ofmh+aH50f2Y
Hz0P5kfzMD80PzQ/2k/zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/OjeZof
mh+aH6e+ONbxzvmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5
ofmh+aH5ofmh+aH5ofnR/Zkfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH63n/ND8
0PzQ/ND86PfND80PzY/mdX5ofmh+aH5ofnQ980PzQ/ND80PzQ/ND80PzQ/ND
80Pzo/0xPzQ/mr/5ofmh+aH50X6eH63//ND80PzQ/ND80PzQ/ND80PzofsyP
ngfzo3mYH5ofmh/tp/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+dE8zQ/N
D82PU18c63ZNfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5o
fmh+aH5ofmh+aH5ofnR/5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH6zk/ND80
PzQ/ND/6ffND80Pzo3mdH5ofmh+aH5ofXc/80PzQ/ND80PzQ/ND80PzQ/ND8
0Pxof8wPzY/mb35ofmh+aH60n+dH6z8/ND80PzQ/ND80PzQ/ND80P7of86Pn
wfxoHuaH5ofmR/tpfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+NE/zQ/ND
8+PUF8c63SU/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/
ND80PzQ/ND80PzQ/uj/zQ/ND80PzQ/ND80PzQ/ND80PzQ/ND86P1nB+aH5of
mh+aH/2++aH5ofnRvM4PzQ/ND80PzY+uZ35ofmh+aH5ofmh+aH5ofmh+aH5o
frQ/5ofmR/M3PzQ/ND80P9rP86P1nx+aH5ofmh+aH5ofmh+aH5of3Y/50fNg
fjQP80PzQ/Oj/TQ/ND80PzQ/ND80PzQ/ND80PzQ/ND80PzQ/ND+ap/mh+aH5
ceqLY13ulh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+a
H5ofmh+aH5ofmh/dn/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH50XrOD80PzQ/N
D82Pft/80PzQ/Ghe54fmh+aH5ofmR9czPzQ/ND80PzQ/ND80PzQ/ND80PzQ/
2h/zQ/Oj+Zsfmh+aH5of7ef50frPD80PzQ/ND80PzQ/ND80PzY/ux/zoeTA/
mof5ofmh+dF+mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH83T/ND80Pw4
9cWxDtfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH
5ofmh+aH5ofmR/dnfmh+aH5ofmh+aH5ofmh+aH5ofmh+aH60nvND80PzQ/ND
86PfNz80PzQ/mtf5ofmh+aH5ofnR9cwPzQ/ND80PzQ/ND80PzQ/ND80PzY/2
x/zQ/Gj+5ofmh+aH5kf7eX60/vND80PzQ/ND80PzQ/ND80Pzo/sxP3oezI/m
YX5ofmh+tJ/mh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH8zQ/ND80P059
cdz3u+eH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofm
h+aH5ofmh+ZH92d+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofrSe80PzQ/ND80Pz
o983PzQ/ND+a1/mh+aH5ofmh+dH1zA/ND80PzQ/ND80PzQ/ND80PzQ/Nj/bH
/ND8aP7mh+aH5ofmR/t5frT+80PzQ/ND80PzQ/ND80PzQ/Oj+zE/eh7Mj+Zh
fmh+aH60n+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5kfzND80PzQ/Tn1x
3Od7XJ4fte78qHXnR607P2rd+VHrzo9ad37UuvOj1p0fte78qHXnR607P2rd
+VHrzo9ad37UuvOj1p0fte78qHXnR607P2rd+VHrzo9ad37UuvOj1p0f5f7M
D935UevOj1p3ftS686PWnR+17vyodedHrTs/at35UevOj1p3fpT1dH7UuvOj
1p0fte78qHXnR/l9zo9ad37UuvOjzKvzo9adH7Xu/Kh150etOz/K9Tg/at35
UevOj1p3ftS686PWnR+17vyodedHrTs/at35UevOj7I/5ofmR/Pn/Kh150et
Oz9q3flR9vP8aP3nh+78qHXnR607P2rd+VHrzo9ad37UuvOj1p0f5X44P8rz
wPlR5sH5UevOj1p3fpT95PyodedHrTs/at35UevOj1p3ftS686PWnR+17vyo
dedHrTs/at35UevOj1p3fpR5cn7UuvOj1p0f9cV9cdzXe+aH5ofmh+aH5ofm
h+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+aH5ofmh+ZH92d+aH5o
fmh+aH5ofmh+aH5ofmh+aH5ofrSe80PzQ/ND80Pzo983PzQ/ND+a1/mh+aH5
ofmh+dH1zA/ND80PzQ/ND80PzQ/ND80PzQ/Nj/bH/ND8aP7mh+aH5ofmR/t5
frT+80PzQ/ND80PzQ/ND80PzQ/Oj+zE/eh7Mj+Zhfmh+aH60n+aH5ofmh+aH
5ofmh+aH5ofmh+aH5ofmh+aH5kfzND80PzQ/Tn1x3Mfr8kPzQ/ND80PzQ/Pj
/8q66/CojkYB40mIe7IxIAkJ7l6cMxTX4gUCFCkULVDcnWDBihQvDsWdFMqZ
FOeDFitaAikuAYKEAAFyudl5Z59s7j993ruS3WO/OXP28NH4QeMHjR80ftD4
QeMHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4QeMHjR96+Sg/aPyg8YPGDxo/
aPyg8YPGDxo/aPyg8YPGD70+lR80ftD4QeMHjR/6+yk/aPyg8UNvr8oPGj9o
/KDxg8YP/XmUHzR+0PhB4weNHzR+0PhB4weNHzR+0Pih9w/lB40fevtTftD4
QeMHjR96f1Z+6PWv/KDxg8YPGj9o/KDxg8YPGj9o/NDLQ/mhjwfKD709KD9o
/KDxQ+9Pyg8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8oPGDxg8aP/T2pPyg8YPG
D7uW1uVm84PGDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPG
Dxo/aPyg8YPGDxo/aPyg8UMvH+UHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4
oden8oPGDxo/aPyg8UN/P+UHjR80fujtVflB4weNHzR+0PihP4/yg8YPGj9o
/KDxg8YPGj9o/KDxg8YPGj/0/qH8oPFDb3/KDxo/aPyg8UPvz8oPvf6VHzR+
0PhB4weNHzR+0PhB4weNH3p5KD/08UD5obcH5QeNHzR+6P1J+UHjB40fNH7Q
+EHjB40fNH7Q+EHjB40fNH7Q+EHjh96elB80ftD4YdfSupyitR80ftD4QeMH
jR80ftD4QeMHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4QeMH
jR96+Sg/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGD70+lR80ftD4QeMHjR/6
+yk/aPyg8UNvr8oPGj9o/KDxg8YP/XmUHzR+0PhB4weNHzR+0PhB4weNHzR+
0Pih9w/lB40fevtTftD4QeMHjR96f1Z+6PWv/KDxg8YPGj9o/KDxg8YPGj9o
/NDLQ/mhjwfKD709KD9o/KDxQ+9Pyg8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8
oPGDxg8aP/T2pPyg8YPGD7uW1uVi84PGDxo/aPyg8YPGDxo/aPyg8YPGDxo/
aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8UMvH+UHjR80ftD4QeMH
jR80ftD4QeMHjR80ftD4oden8oPGDxo/aPyg8UN/P+UHjR80fujtVflB4weN
HzR+0PihP4/yg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj/0/qH8oPFDb3/KDxo/
aPyg8UPvz8oPvf6VHzR+0PhB4weNHzR+0PhB4weNH3p5KD/08UD5obcH5QeN
HzR+6P1J+UHjB40fNH7Q+EHjB40fNH7Q+EHjB40fNH7Q+EHjh96elB80ftD4
YdfSuhzyaj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o
/KDxg8YPGj9o/KDxg8YPGj/08lF+0PhB4weNHzR+0PhB4weNHzR+0PhB4weN
H3p9Kj9o/KDxg8YPGj/091N+0PhB44feXpUfNH7Q+EHjB40f+vMoP2j8oPGD
xg8aP2j8oPGDxg8aP2j8oPFD7x/KDxo/9Pan/KDxg8YPGj/0/qz80Otf+UHj
B40fNH7Q+EHjB40fNH7Q+KGXh/JDHw+UH3p7UH7Q+EHjh96flB80ftD4QeMH
jR80ftD4QeMHjR80ftD4QeMHjR80fujtSflB4weNH3Ytrd/b5geNHzR+0PhB
4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB
44dePsoPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxQ69P5QeNHzR+0PhB44f+
fsoPGj9o/NDbq/KDxg8aP2j8oPFDfx7lB40fNH7Q+EHjB40fNH7Q+EHjB40f
NH7o/UP5QeOH3v6UHzR+0PhB44fen5Ufev0rP2j8oPGDxg8aP2j8oPGDxg8a
P/TyUH7o44HyQ28Pyg8aP2j80PuT8oPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/
aPyg8YPGD709KT9o/KDxw66l9Xvm037Q+EHjB40fNH7Q+EHjB40fNH7Q+EHj
B40fNH7Q+EHjB40fNH7Q+EHjB40fNH7Q+EHjB40fNH7o5aP8oPGDxg8aP2j8
oPGDxg8aP2j8oPGDxg8aP/T6VH7Q+EHjB40fNH7o76f8oPGDxg+9vSo/aPyg
8YPGDxo/9OdRftD4QeMHjR80ftD4QeMHjR80ftD4QeOH3j+UHzR+6O1P+UHj
B40fNH7o/Vn5ode/8oPGDxo/aPyg8YPGDxo/aPyg8UMvD+WHPh4oP/T2oPyg
8YPGD70/KT9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/NDbk/KDxg8a
P+xaWr+XzQ8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8oPGDxg8a
P2j8oPGDxg8aP2j8oPGDxg+9fJQfNH7Q+EHjB40fNH7Q+EHjB40fNH7Q+EHj
h16fyg8aP2j8oPGDxg/9/ZQfNH7Q+KG3V+UHjR80ftD4QeOH/jzKDxo/aPyg
8YPGDxo/aPyg8YPGDxo/aPzQ+4fyg8YPvf0pP2j8oPGDxg+9Pys/9PpXftD4
QeMHjR80ftD4QeMHjR80fujlofzQxwPlh94elB80ftD4ofcn5QeNHzR+0PhB
4weNHzR+0PhB4weNHzR+0PhB4weNH3p7Un7Q+EHjh11L6/fIr/2g8YPGDxo/
aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/
aPzQy0f5QeMHjR80ftD4QeMHjR80ftD4QeMHjR80fuj1qfyg8YPGDxo/aPzQ
30/5QeMHjR96e1V+0PhB4weNHzR+6M+j/KDxg8YPGj9o/KDxg8YPGj9o/KDx
g8YPvX8oP2j80Nuf8oPGDxo/aPzQ+7PyQ69/5QeNHzR+0PhB4weNHzR+0PhB
44deHsoPfTxQfujtQflB4weNH3p/Un7Q+EHjB40fNH7Q+EHjB40fNH7Q+EHj
B40fNH7Q+KG3J+UHjR80fti1tH5umx80ftD4QeMHjR80ftD4QeMHjR80ftD4
QeMHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4QeMHjR96+Sg/aPyg8YPGDxo/
aPyg8YPGDxo/aPyg8YPGD70+lR80ftD4QeMHjR/6+yk/aPyg8UNvr8oPGj9o
/KDxg8YP/XmUHzR+0PhB4weNHzR+0PhB4weNHzR+0Pih9w/lB40fevtTftD4
QeMHjR96f1Z+6PWv/KDxg8YPGj9o/KDxg8YPGj9o/NDLQ/mhjwfKD709KD9o
/KDxQ+9Pyg8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8oPGDxg8aP/T2pPyg8YPG
D7uW1s9ZQPtB4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB
4weNHzR+0PhB4weNHzR+0Pihl4/yg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o
/NDrU/lB4weNHzR+0Pihv5/yg8YPGj/09qr8oPGDxg8aP2j80J9H+UHjB40f
NH7Q+EHjB40fNH7Q+EHjB40fev9QftD4obc/5QeNHzR+0Pih92flh17/yg8a
P2j8oPGDxg8aP2j8oPGDxg+9PJQf+nig/NDbg/KDxg8aP/T+pPyg8YPGDxo/
aPyg8YPGDxo/aPyg8YPGDxo/aPyg8UNvT8oPGj9o/LBraf1cNj9o/KDxg8YP
Gj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YP
Gj/08lF+0PhB4weNHzR+0PhB4weNHzR+0PhB4weNH3p9Kj9o/KDxg8YPGj/0
91N+0PhB44feXpUfNH7Q+EHjB40f+vMoP2j8oPGDxg8aP2j8oPGDxg8aP2j8
oPFD7x/KDxo/9Pan/KDxg8YPGj/0/qz80Otf+UHjB40fNH7Q+EHjB40fNH7Q
+KGXh/JDHw+UH3p7UH7Q+EHjh96flB80ftD4QeMHjR80ftD4QeMHjR80ftD4
QeMHjR80fujtSflB4weNH3YtrZ+joPaDxg8aP2j8oPGDxg8aP2j8oPGDxg8a
P2j8oPGDxg8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8oPFDLx/lB40fNH7Q+EHj
B40fNH7Q+EHjB40fNH7Q+KHXp/KDxg8aP2j8oPFDfz/lB40fNH7o7VX5QeMH
jR80ftD4oT+P8oPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/9P6h/KDxQ29/yg8a
P2j8oPFD78/KD73+lR80ftD4QeMHjR80ftD4QeMHjR96eSg/9PFA+aG3B+UH
jR80fuj9SflB4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB44fenpQfNH7Q
+GHX0vp3C2k/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/
aPyg8YPGDxo/aPyg8YPGDxo/9PJRftD4QeMHjR80ftD4QeMHjR80ftD4QeMH
jR96fSo/aPyg8YPGDxo/9PdTftD4QeOH3l6VHzR+0PhB4weNH/rzKD9o/KDx
g8YPGj9o/KDxg8YPGj9o/KDxQ+8fyg8aP/T2p/yg8YPGDxo/9P6s/NDrX/lB
4weNHzR+0PhB4weNHzR+0Pihl4fyQx8PlB96e1B+0PhB44fen5QfNH7Q+EHj
B40fNH7Q+EHjB40fNH7Q+EHjB40fNH7o7Un5QeMHjR92La1/x+YHjR80ftD4
QeMHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4QeMHjR80ftD4
QeOHXj7KDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8UOvT+UHjR80ftD4QeOH
/n7KDxo/aPzQ26vyg8YPGj9o/KDxQ38e5QeNHzR+0PhB4weNHzR+0PhB4weN
HzR+6P1D+UHjh97+lB80ftD4QeOH3p+VH3r9Kz9o/KDxg8YPGj9o/KDxg8YP
Gj/08lB+6OOB8kNvD8oPGj9o/ND7k/KDxg8aP2j8oPGDxg8aP2j8oPGDxg8a
P2j8oPGDxg+9PSk/aPyg8cOupfV9C2s/aPyg8YPGDxo/aPyg8YPGDxo/aPyg
8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/aPyg8YPGDxo/9PJRftD4QeMHjR80
ftD4QeMHjR80ftD4QeMHjR96fSo/aPyg8YPGDxo/9PdTftD4QeOH3l6VHzR+
0PhB4weNH/rzKD9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxQ+8fyg8aP/T2p/yg
8YPGDxo/9P6s/NDrX/lB4weNHzR+0PhB4weNHzR+0Pihl4fyQx8PlB96e1B+
0PhB44fen5QfNH7Q+EHjB40fNH7Q+EHjB40fNH7Q+EHjB40fNH7o7Un5QeMH
jR92La3vY/ODxg8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8oPGDxg8aP2j8oPGD
xg8aP2j8oPGDxg8aP2j8oPFDLx/lB40fNH7Q+EHjB40fNH7Q+EHjB40fNH7Q
+KHXp/KDxg8aP2j8oPFDfz/lB40fNH7o7VX5QeMHjR80ftD4oT+P8oPGDxo/
aPyg8YPGDxo/aPyg8YPGDxo/9P6h/KDxQ29/yg8aP2j8oPFD78/KD73+lR80
ftD4QeMHjR80ftD4QeMHjR96eSg/9PFA+aG3B+UHjR80fuj9SflB4weNHzR+
0PhB4weNHzR+0PhB4weNHzR+0PhB44fenpQfNH7Q+GHX0vq6ItoPGj9o/KDx
g8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/KDx
g8YPvXyUHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB44den8oPGj9o/KDxg8YP
/f2UHzR+0Piht1flB40fNH7Q+EHjh/48yg8aP2j8oPGDxg8aP2j8oPGDxg8a
P2j80PuH8oPGD739KT9o/KDxg8YPvT8rP/T6V37Q+EHjB40fNH7Q+EHjB40f
NH7o5aH80McD5YfeHpQfNH7Q+KH3J+UHjR80ftD4QeMHjR80ftD4QeMHjR80
ftD4QeMHjR96e1J+0PhB44ddS+vzbH7Q+EHjB40fNH7Q+EHjB40fNH7Q+EHj
B40fNH7Q+EHjB40fNH7Q+EHjB40fNH7Q+EHjB40fNH7o5aP8oPGDxg8aP2j8
oPGDxg8aP2j8oPGDxg8aP/T6VH7Q+EHjB40fNH7o76f8oPGDxg+9vSo/aPyg
8YPGDxo/9OdRftD4QeMHjR80ftD4QeMHjR80ftD4QeOH3j+UHzR+6O1P+UHj
B40fNH7o/Vn5ode/8oPGDxo/aPyg8YPGDxo/aPyg8UMvD+WHPh4oP/T2oPyg
8YPGD70/KT9o/KDxg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o/NDbk/KDxg8a
P+xaWv9bVPtB4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB4weNHzR+0PhB
4weNHzR+0PhB4weNHzR+0Pihl4/yg8YPGj9o/KDxg8YPGj9o/KDxg8YPGj9o
/NDrU/lB4weNHzR+0Pihv5/yg8YPGj/09qr8oPGDxg8aP2j80J9H+UHjB40f
NH7Q+EHjB40fNH7Q+EHjB40fev9QftD4obc/5QeNHzR+0Pih92flh17/yg8a
P2j8oPGDxg8aP2j8oPGDxg+9PJQf+nig/NDbg/KDxg8aP/T+pPyg8YPGDxo/
aPyg8YPGDxo/aPyg8YPGDxo/aPyg8UNvT8oPGj9o/Mi6firLGVmOW1V0x1kf
F3aP6+b1cVnWcxXdvN6+7f++amn3uLR7XH9+3u/m1nEVPwdVkdb/FlX/rSLs
mseF3eP689q/nr/P6+3/vt376c9v97i0e39h9/7iZubxKkq4Zx6HguXyzONH
HjFSHVd5nO6ZeTzJq/uHzONPbvE887hpkRMzj18Runk/mvejeT+6cebxMafo
rI7jvD/N6+nSmcfDUPFP5v/fX7+e5u/TvJ4OsX5vEaec4P1oXk9/sH5OMTDz
e/ro19N8f5rX00nWvyu+VQ7xfjTfl+b96BnW9xHVMr+nh34/mu9P8350K+t/
RZRyj/ejeT0dmfn9XISr9b/69TTLi+b19KPMz+cgnihXeT+a5UfzfnS3zPd7
b5y3vo9+P5rlR/N+9LvM/6YYvZTjvB/N6+mwTK+TjHLW55m8nmZ507ye5vWf
1DiB5Uvzetrh//+vs0O1k9a/o19Ps7xp3o9elPnfJDOvGofwfjTLm+b96P3q
ffar9+H9aF6/P8vfea+ed16/nmb90LyePqnWi/VzplTl/WjWD8370dbl5iLD
1LiK96NZXzTvR/N66/OSDJY3zevpcmq/6abGbbyeZnnTvB/dS+33j7JsRx66
Wd4070efV8epSDVO5P3oRVnWU6rxRB1HW2XZb/x178+yXb3Xr6d5/Qw1DmX9
0PuzbIefDFflRlKW/dyim/VD582yHzmo40yo2o9zCN6PZnnTvB9tPa7lVPu9
i34/muVN8340ry+txtUsX5rX09bjcG51nPPQr6dZ3jTvR1sdiFDHZS/9fjTL
j+b9aKtDeZQLPvr9aJYf/SSLyz769cvVeQLLi3bNMg7wU05GKTf99etpvj/N
+9G8vqc6D+H70ryetrqeV75Vx1VeT/P332ZxOEI370/zfhPVeQ/vR+vlafe4
v3KE8QnjI8YP1vNi23iI1v/7uWp8hP/W82bbeIfmfOp5lvWeW51XB0rOr3ic
8yn78RTP53yN8REeW8/LA/Tzac73GA/hr/W83V9/H/vxFI9z/sj4CH+t5/m+
+vk055+Mh/DTOg/grb+v/XiKx3/Msh156fGPdd7AUy9P+/EUj3N+zHgIT63z
DO56+dmPp3ic823GR3hqnZdw1c+nOV9nPISH1nkLZ7387cdTPK7nj9V4CA+t
8xxOevnbj6d4nPkExkN4aJ0XyTBZH/bjKR4vmcWdT3o8ZJ1HSdfjH5r5Dfvx
kHWeJc1k/dmPp3ic51vnYV6brC/78RSPx2QZB6To8Y913uaZyfqyH0/xOPM1
jIfw0DrPc99k/dmPp3ic+R/GR/ho/f9f18+n9f/+Rpa/+159jgRT/+9l2I2n
eJz5KMZDeGhdDgkG69t+PMXjzG/Zj4es6+26wfq2H0/xOM+3Pu++wfq2H0/x
OPNr3bJsFx5qu3xmxGQZp9nGUzzOfB3jITy1LqfXRqssy8k2nuJx5v8YH+Gp
db2m6efTzB/aj4es21G6wfq2H0/xOM+3brcZRnKW7dY2nuJx5i8ZD+GvdT9x
0vOP9uMpHmc+lPEQ/lr3a2c9n2k/nuJx5lftx0PW44qrnh+1H0/xOM+3Hsfc
9fyq/XiKx5nfZTyE19bjrqeer7UfT/E488WMh/Dfetz31vO/9uMpHmf+2X48
ZHXHV88n24+neJznW13018vffjzF48x/24+HrI4H6OVvP57icZ5vnTcN1MvP
fjzF48y/249/rPOsFv397cdTPM7ytX894yG+j/14yTpvG6T/Ps/X//udajny
fjx/nPrfke+WOW8ZJF9lzqdGiauZ85wWuS1zfjZcNMycFw2UPJ/+OXMeLqe6
DhMgh2XOB4eK0pnzsP76/egOmfPJwaJu5jyun/xafe9imfO+PvJU5nxvpO6C
aj34Z84be+nPQ4ep7cJ6ncVdfx76jtpub2TOW7vKrWq/kZnf31l/Xnqo2q/X
Za5PJ/156XHqODM9cz046M9PW9Rx72bmevxofqOOwxsyt7N3Jt+H5vMPyFyf
b8xE5cSgzO3ihcnnpxP+sDrmlrmdPzT5PnQF5ar1v4nqeWnqdadNvh89SI0z
rH93p8H3oweocZD1e1w2+H4038/6/7+rvqe7Wk5PDb4PfVONI62f45XB96Gn
q3Gt9Xu9NdapcbV1OXww+H4038+6HD8bUp0HWJezo+D70dbtIESttxyC70db
t5swtd5dBN+H5vNbtxs3tR3mVtudh+Dz09btOEJtt96C70Nb94M8arv3FXx+
ms9r3Y/81X4UpfbDAP15aT6Pd+Z1jUC1X0bLJZnXMSz679G8X8HM6xhBopK1
RaS15bfW54t51ufL4+p/N5yOsv49dV02ULp0y/w8Ypj180jej35i/T7iifX7
yHPqOBRv/b7679F71XF1hXV5yarW5al7iTrOW6+7eujPQ39U7vSwri95QjnY
2Lo+9eel5yqXy1i3B/156X1q3BBi3Z7056cbqHHM28zj/GfzoBpHJVi3V5Pv
Q/P5Z1i3d/O4Gue1su4PJp+fvlDIOg6tbt2fTL4PfVaNiy9k+nFX/fe1+v9f
Nvl+dHV13mB9350m349upc5jrJ/rtMH3o/l+1v8mGjPUeZf1eQ8Nvg+doM4D
rX/nhcH3od+q81Tr53yjlnOAWm/vDL4fzfezLqePRhl1Xm9drg6C70db13Ow
2q6cBN+Ptm4noWq9Ogu+D83nt24Xrmo7y6m2I3fB56et22m42i69BN+Htm7n
kWq79hF8fprPa90v/NR+E6X2K3/9eWk+j3U/DVD7XbRsYfVafx6a97tt9V4/
v691PCDY3xkfcDzhccYXPM74g8dpxiu8nuMNr2e+hr/H+IPn8/kYf3B84vn2
zfwO34e/RzP+YfzE48zP8H78PeaX+DyM12jej/kl5n/4fjTvx3iJ+RHmM5j/
oBnPMH5hfoH5AOYPaMYjjD84396f5TzLTTfjB8YLnP9xvsb5HY3X+Mz4n/E3
41sab/BLz5dmmYeK0MuT9Tcyy3lARLYun2U/idAeMX6kWd74xOuZL2O+i8Yf
fKIZr7I+8ITlzfGe5cd8SUyW8/xUfXy3P94z/mN9cPzmfE+f36vtgub4ZH/8
ZTzG+uJ4yvkU58Ocb9Ecf+yPp4yvON/h/JLzIZrjj/3xkfES2wPHM85HOJ/i
eEGzv9ofzxjfcPxkPFNSPpxgBEWLATnOyeFTbMcD9l/WN9sT65fjDc32xfwp
j7N/M9/L+3M+RDM/zPsx/8r+znwm4xXOV2jmP9nfmQ9kvMH5Bs38IdsT83Ps
/8lZ3HTX5ws082tsP8wfsT0zn4PXjNdp5n/YXphfYf0z/8D+zvk864/xLs35
P+ub82uOL6xvxtc068v+9xSsf85HOb5zPOD4zPw1zfkmxw/W3z9Z5kVy6eb4
wHiX+WiOL8w305x/crzBHx5n/p/m8/N85quZr2c+mub8lfE02xPz8/hBczxj
fM3yYfvl+Mr7Mf/M9sr8Ms35LuNx3o/HWd40y5vnMz+Nh+uzzPO46fN/jscz
sswbuejrBTTn04z32T+Yv9e/D1fN8ZjxP8ubv09zvYH1yfuz/nk//ftw1Tyf
92e+mv2Z+Wia83fON/j7PM76p1n/PJ/5bMYLzFfTnP/jGfPXXC9gfppmPoDz
Gear8Y75aZr5Avxj/fL3aa5nsP3w/qxf/j4dlmUewFfYvz/XH9h+9O891PM5
v+J4x/GT+Qse5+9xvGT7otm+OB9jftv+9yJc/8Bnns98tv3vQzh+M//B+ID5
bPvfh3C9g/kRzvd4P65PJGf5HUxKVZ7P+R/bC+9P8/5sj7w/f5/rF8yf08zH
cP7I9sX1FprrLWyPfB7m3xn/ML9OM5/DeIj343G2X5rtl+ez/XI9hO2XZvvl
fJbxWcks83zu+vyX6zH4yHiQZvvi/Jf5evvfr3A9hvkn++dzPYT5e5r5KM6X
mc9nvMd8Pc38FOM/thfG/zTXa9geeX99PU39fZrrM2xfvD/jUcYLzH9xvs76
5vPRPJ/tiecz/2//+xau1zCfxvk+12N4Ps3z2Z54Pu/HeJfrBzTzcYx/2T64
/kNz/YfthfkF1ifXe3plcd1Vzz/y/ozHGV8x/8f8A+ubz0fzfLYPns/4zP73
Mlz/YbzF/AV/n/Ea1y9ons98BteDGmdx16Lfn+2P92f7+CGL48H6ehLbC+/P
+uHv04w3Wf+cf3D+b/97G64fMT/K/ArXazg/4XoMzfM5X+F6Eu9P8/5sL7w/
y5PrUXTeLNdBcuv35/yJ8THzEczv6OttapzH+RfzKaxfPj/N+7H+eD/ObxgP
c77C+IvzEcYPnF/o+Uh1vsD5KON91gfjQ86vOL/n/Irxd64s82i59XwK433G
74yfaeajeT7js1lZ9oMwfb2K8TiP83oeZ/zF+Jj5YuYLGG/z+xmWD9e3+D6M
1xkP03x/ns94m9/TMJ/M9TCWH4/zeh5nPMT555Is26G7Hj8znmX+mfknxq+M
f1lePM54mt/PsP65vsb4lt/HMB/N9TWWJ4+zPHmc8Qfnw8xXcz6M94wfma9m
PozzE8abLD8e179fVU4xv831OsaPjD9ZfjzOfBnjPbZ3rt+xfBn/sXx5nN83
MP5jvpvzdcZrjMeY/2b+jvMFHmf58jjjfcZbLD+uB+I1v1dh/pzrgSwfxouM
p2iWN8/Ha36/wnw71w/176GyXCdI09cX+XuMr1gfzG/xewfGS8zPc72R8Rfj
J+ZHeBwPGY8xfqKZz2e+A48Z//A486GsP8ZLrD8e5+8xHuJ6ANczWb+Mn1i/
PM54mvEQ64f5OX4PwXiG6wdc/2S8zOOsDx7HJ8YrjG9orjdwvZT5SB5n/ojH
8ZfxC6/neirrj/EO64/HWR+MX1jezCcy3mA8wfUNrr8yvuVxljePM//J+IL5
K67PsjwZT7A8ma/Cf3znegrz3Sw/Huf78zjzp3jPfBnXc/l++Mz3Y/6T8Qi/
96C5HoFfzGcyH858Jj7Ye878Fcd35pvwj+b4zHwQvjF/xPGV+Rz+Hs3xk/ED
x0PmT/CD+RGOZ8xn8PdpjmeMPzieMH/A8YP5Af4e59/sT5yfsn9wfsj70byf
/fVO++uZnB+x/XH+w/bAeJ75LzxmfEAzn4N3jC9o5h/wAo9pzjc5njHfQTPe
Y/tmPEgzfrS/fsf2xHgK/9l+WH+MP5hfYf0zv6Lvj1Dn/xz/OP9nPMz4n/2B
8T/bP+Nl9kfGy/p8RY2H9fmKar4/42Pr77Dy6esF3D9LW/fDvHo+mfEm88/s
L1wfpZmPZn/kehV/j+sH/D2av8d4mPXD/s94n2Z9cT2Wv8fxgOVRLcu8b7j+
/vw9+8/H96P5PtbzBNvy4HH+Ho/zfnz+01l+BxKpP2/Z00/Kh3WNzvb7/vT0
v9ptqxAkF8fPOhXdKjzb7/XznS212X+MRSb/+N+xyIbR+nGj5tamQ+7Yfo/v
MyjvNO9Ztt/bWw7VLN0/2DbeDwidem19E9vv6c+EWdYdyJP99/Lz2u0plzzT
V25fvWv73Qzb7+HjZzU9XzjZ9vv3hEnTJ1a6avu9e1Tcqk0Xfsylu9q2pS/P
/Wn7PfumAXNiBv+R/ffqm2rfSRg220WaayLOWb6x/V79nt+8ITuPOerxc+9F
M3K+32r7Pfow/9nxAbvS9e/Pq76c9DLcL0iPp/uF9Kstk1/r8fPj+bXqTh70
KNvvx6f7rbl8fM4HPR5OSNgya1v5VPPt3utzOrv5Zvt9+PPtuzakXnllJk4o
V/bVPM9sv/8udrhGqz4+yebFzmeaTo9wy/b77sTBLXtFx9zR49/Oqb3SzWIX
zKVuE3OcvP0u2++3fwoccntmyhXzUJddFZ1yZP999im/LX3qzN5gDulSct3o
BTn0+DQ1sEZL16Uv9Xj0WsXxaWcH3sv2e+rTS4bkaLTqvnF92slHY8ecMOx/
Lx01YGGX/RkvjKvHN+55OO+i/j30d8X9bwYesP3+edmm4gOufR+Y7ffN+aoU
GPXvz2l6PBi/ZK3L9Gof9fXaZv1FscTnGXo8WG97xpjrfR30eGWw653bfx5y
0uO9zt9NiB6/10nEno+Le5wYlu33xSvSD7kPfONsG4/53z72v2K267uDtw3p
+6iPux6P9TQ7ThjfzkMfP2OOPCtZupeX2Ltr5k6zR/bfAxc8OvlSh9Fewjtn
QefblyOz/d73wYNmw9/87KM/f3RU1za/LPPT46vmCyLu13vuLwIntJj3IT77
73eHFAlqm/d/tvHU47f5ajb8crznevKuy/tOl34YKDx7PW692SP7721nhfxd
9a/1gaJ1lXprP26JzvZ72leXy8X02hokppUZ+bbU0GjR/sn2nLm2BMmYj9Gm
w4hw8WbVqlU+SwJl2eTGN7xjosUv/wv8+HJToHw6s8mIGWVziYDBX0//tCJA
5p42r3uPd6Hilv+3148u95dzVg5snlghSsx3ENt3rvSXJVwrNO16KlgMuT64
9dvifvLW5+G9jq+yiNkhv578GOoj743Lt7nS+ADR4kwXy+t0Tzl8Z/djY8qH
izoLfHMVvO0p2/78IqLFGV9x+cCHKsnX3WXtiImLKg7KJWp17PTP5e/dpVfq
4t8GrvIUdavNn3B8t6ts+LnzrZ5jXcWAH5e/LjfVWS7Pf/asZzcnEeD/z7Sz
bZxky7Fia8fkYLHNac+Kii2d5JQhE+ISVn00Tn6IbetVwEG6+LZ/2i8kSMxo
7nElz/UM893EFlPKTXlj9LoxrsnOW+nmklWxlshHj4yWt6PXBfdLM5/EP9i8
8ryvWPHnB9nP9Y25sEZ0z9xOX7aLRl9VnHHguflXeU+P6uXcxNHKYYWedb1v
RmREdhlQKs0Ma9e0UcybU+aJvHJBy1efzfrDfjcc5h8wfjlU3O9c2xxyt6v/
klsNrxmnbiTd3VT7tREfN/R92qLLxqi4PoEzTzwwNse0HzDw5l3D+9k+jwM3
zxj3R25cFPEw2Yges+LwybMXzF61ijZsk/rK+Hnx87432vnLpZZfnF90emt8
d29P2LFKgbKff9kF9XOnG18tilzZZmOYDM9Vul2e1y7iSony5qTgCOk02iOm
T7i3eFljVsTe05EyolytfhfW+YppO353r7oiShZac3P+8HoBYkDzZzOHbY+W
D0LbPNz6vUX8+ctc49S1SNk+vmyuIVMtosyjn3Y77YoSBSZcTIjuEiS/7vlx
3PLEaLF6T/G522oFyco11857mBQtGm3se6ZshkV+KHW358HVEWL37/l7XrFY
5IN/NhcNux8hVpV/NC1vKYtslGA5FNAqt+jnXWtKp/BA6TbskOuN6GgRV2TV
2ozSgbL1ySZGcFBOcW7tzemBkV/OQ+dvfGPcDhH92j4YXDaXv2z9Yd3EEsvz
iEu33tRcm+InZ7atWXLlniDxMfrXav3z+cqH7qdn7JgTKHpvnNL3pKe3POLa
P6jGQH/R7nbj/queesg/nP7p3rZlbvHg5hXDYY2HrDG26K+793qL4zfnJ6Sc
cJM+OU7d+2G2uyjSrGzR8StcZJ2xh5JaDXAWbU6tj3/VP4f8c+WwUjeuhoiY
erVbucbmkEH+fy3p285BVP5qRs/zhqOce3vpkYqOwaJ1tdlNAqMcZbnk3kUW
z3tnOA748kGCP5sn2p/y7TkqxTibr+zCjA3vzaEvz/XyvJVkPEj4mMv5i1dx
y76uUOLhLaNIB8sQce6N+Ws7Z9njsbfY9W3DSn67XpobP53rEp/LQ4yqtrtD
Pp8nZvFVC3t0CEg3Z5b8Jm/7jpvNpc1eNC3by1EusQyZ86LE38a+PLVKu9Z3
kdPOjX9ZIiHJGPxo0fhevz1X/71l+N2qctL3z0SjQ1LO8Su6PjLCX10NfLZ/
pfl6eIE3T/emGMvXRDQLfnLLbJz4zfDl594YXQt9KFK9QYAsmRD4WR5+ZzjV
eHKjb2GLjMnXdtKs4Z+MKUv3Bjb+M1Tu2nl+8+2DzmJcSVk1x+yc8tmDtqlm
UTdxqE/GpH+eR8jKa93+7t7FR0R5jPttVUaUDE9Pn1PpTYDo0PHm2bH5o+VL
vz97rSsXKGptmFH95I0I+V1E28APRSxi6MMKUa3vRMvFjR1iVjkEia+Gd7xd
2jtKLjCc0v56a9Hnl892TD9Qe0KQXOTo2b5SA9v9l1NH/vbfp6PR2e63vFTb
qdVfGwKl54f4t+WWRmS7/7L39H5t35az/X6uoSVq1OrHgXLaJFH75Szb72v4
/cW8y5UPGWaA3HH2aYv6obmz3X95OXL/ypt1AmTcyrjdCQeist2PuTh35LnY
W7b7MYO61413POMv+3xds+hve7Pfn1lg8qFnN5rY7s8Mujrt8+sX/vJq6tBV
Nftmv19ze9Volx9y2u7XHDvsRUT0Cj9Zd26nx497Z79/s+x/jQ/PWWq7X9Pp
rwfedRb4yLEj9lU4VD77/ZvtnXd/M3aGt2y6/fCQuNy2+zc/vxFBCd1t928y
P1xqz2+rHr+33c/ZrdGHm4PGeMmKNRbsquib/f7OwfPejYz50XZ/Z3Biv7BZ
fbxkWPI/Ky3bs9/veWDQzx+Tn3no32vMHDwiZ+cYD9nw1/Gj7zzKfv9nk5ML
3+2qbbv/88P4ulfK9rPd7zlvXfUtw4q7SU+3lrla/y/7/Z8Jo0vMvxLgKr9Z
m3Ro4c2wbPeDFtsc2rzVJ9v9oGsKV53/8o2znHB99bWGh7PfH1q4d61mjy7n
kGlVpy8/GJT9/tAxA3qGbom03R86oofX8mt7nWSoqBDvKLPfL9pt3dH0xHmO
ev1vC5nXLOSwk2zxVbs8Bcdkv3/0RbumLwPaO+r7R0uXt+wP+NFBFrlY+tb0
pRnZ7idNLdgvNmzWZ/170AFbRhklXtruH13+ZuO3J6t9NEdVfZqy8GxatvtJ
l/QoV7rd4/emR2EPt+LfBwr7+0s/l673vHv1T/r3HCVFQL3Un9PM1rHHr1YN
SMl2v2nhDW9ny8qpZvWwP92XxgXo+fICMfcTxu633W/K9tXh/mvvcnfSzJUj
vvI48Wf2+00jbt/Y+mzJK3P8z0dO7ojapu83dftcfKTnmBP69xTMZ5SfFtko
cECK/n3G7cZ7k/c5pJj9Ko6OmdnYO9v9qN2X9vxtyfkn5pW+JeOPh9zQ8+8b
Br1asWPgPf37C36/Uad8mdkOFR7q39Ou6tr1w6jV982730fIkZef6vn5mm97
X/pyPqF/j8H8xtfJ7s0939wwN+cb3qrcghzC/n7VnjmaX2g2Ocms9/faG63r
Zb9fdULtwoGTLv5hvptR58/9Zxz1/apdI7ttv+Jku1+V7c+o4fmp+R+n9f2r
tQuVv153+gajX7Nd61oP+pjtflbPDa07DTt42pg0deY3OQd91PP7bXeUWrb6
9jt9Pyvb34UK9Qv6XPhD/x6jkNfEaXVeXDF2p81ZlHLGMdv9ru337p85epLt
9xi+q+vcX17sgrEw3j+xbr3s97/6/XJ6v++bG/r3GJPjJziWirljRGybPDru
8tNs978e/pBeM6jCQ+PVoL5Ti19z19cHtt+eNm7Jz5769xRcj3d4eHFp4XNP
9O8z3P6qeHKMT7JRr/X+rp6hN7LdH5tnlmV+6IAUo4xX5ff1mnjr6wVeY4/s
LOfuq++P5XpB3wbn0p4vfqV/T73o9OMnr6680tcb1oYktuhQLtVovapHxJUj
2e+XDWj1eW98Uprx+YX/kuuDHpn2988WerKx8Z7Kqfr3HM/quo2Jmv3BMIbP
klVmBWS7n/b0qiIHF1b9ZHRtdbLG+ADbv0fS8XLR7/I9e61/r8H2+urllvBS
j98bvlvrN476K01ffzh5qWXlk7vS9f20+vcfaXdPH4n7bDT36tEj7pbt/lqz
6d3xqdts99dyPf/uxt37LrVzFHsvjVoycFmGvt82fWfxWl8fd9TPZ/ucX8Oj
+aJ5juJizYK+Jcba7r8tPyU0pEBT2/23+t/XGFs6qEaEs3h34Jseu6XtflyX
kndmNDhsux+X7fNUpYYFxly2Xf/4/G+J9fviXERVl4VF3EKy369b+2qneePS
XUWx1fXi65m2+3VnjCjyw7sjtvt12d5KTdxd+OsAV/G0juOybWds9+sGDr8q
jl+z3a/L9tO+pm9Qci13EfbfV7m3lbD9+yee8/q5XXhmu39X/z7bo9HcxU89
xIpfRtXf8MR2P2/UgNWe9xwC9PPZvvb95Fu4U19P8WD1pOqHdmS/v3eV9Lz5
6a23GDIrPa6Nn+3+3lK7ylR7H2W7v5ft61Ep2a/hdNv9vhfKCuEz3Vc4lKr1
a54Ktvt7n13JP7FkU9v9vWwPBaVXm7xLfEXt/ePHxIbYfo/B/G7s+VetVob6
i+mT8m79pa/t/t+2H5t+d3u27f5f1n/0nLBe7k38ReG3skGjH7PfD3w0o/Ls
CTcDxIq4HDGr9tvuB95/5+2vs+/Z7gdmfYdvv/j4Ze0A8axCvbDxOW3/nkqO
F47Lfvo2XP9+gvVxamO1ZR/KBgpzaz7PdrOis93/u77y4n1r/7WIpX2Knfl5
ue3fU2H+489BNR6u/ipItJjQrMFfDbPf/xteNza43Pgv52UbvI9M9ooSZ/1a
Bo1Ms0j3ljcGbXoWIZIPFb81r6uPPFMsrsXchFDRJ8/73ssOOcvICvPHPWwW
Kn6IvL9paD5n6dvZO/pB/QBx9Zvnfv3Md+aKivMsw3b6idTqa159Dks1q031
fu8ev9I47dfuj8d7U0xLAbfmjxMSzfBXcXkXdH1kPur6d0i3356r/94yh9zp
J2ffSzXd57fYUNn3nNl6TJt/g3o5ilPbypX/t+TfZuVz4zbUCEg3OuV56f9r
+81GzW3hpkduD1knMWzdeO8nRu1jLSr/89hb+ianH16z86WxYvHMf2aNSjG7
TGm2O3nDe6PR7qOF7897Z771jnnxLOiz0f9KwJUEx2A5rE5olel5HIVP5YO1
t7VzkIdXWSw7DUfx67eDhg28FiJHz6nv3W9KDpG8bGG+/QOc5aTfK4Ue6Z9D
LBqaOCZl9hcvFm3sWHWFi+hc8tTgPvu85T7n460XnHATE0+nnGnaKreMCjl4
zX21h5ix5V7vAwP95bwqV8OKfNnfnD++33r4cbiMbRDsv/iGl/ghccuftecG
yqcX13xV1tNbLFtfvmzLvUEy+Z+tlQ7m9RVdOvzXMCgpRJYcfPr0yZz+Yl5y
3fbXf4qSSXV+L9L3vb94t2j8OffgnPJz1Vp/Lo4IEANudKsU0Tq37DBu6Ynr
uQNFvuZJleqvjpYZHSquc6hkEecc6yxM3xUlp/bISCzcOUiY4YP+O7A+Su6d
NT/2UEyQeHzVnNdgU5Q4V/92hSYdg+SowNb921yNFJ9Hnp9QYppF1mi0tEzv
bdEiJHLz1we7WeSyFf638v4aLXr81qPBv19Z5JVpfW/2XR4lrp8qklC3foBs
2jRvvlf9osTsTQteTn7rLy0NnQfMPhUp0ouczZ223lc+LXqqcougCPFs7JBb
yyO85YKSt2v9czdcvB31YcP2f7zkxWFLEhZuCBPjKu2r8N9rF/nvocOFu1cK
FAO7RA52DU83Z32T1H9mO3+xeuOez3Gd35o9Gu5x+OPsBSNh+sk/26a+Mo32
e04MuXnG3FK4Xr/gh8nmrR9qWEafeGDeOHk8pffNu+b0/CH7t9Z+bVaP+m9F
xqLL5mK34902tc0htl7ZXnNEo2tmvqennIq8+mx0LN/n71YLDpgTU2807loq
zdhcVnyIfnPK6LgtYrz3vVRjcK9f1tb0P2c0atht6YRybvK0bzfnbl3vGxXH
fP9hhJOXPHVhZ+Bf+58bhYMHuOe84Cs7df+p6xuXN4ZjzxqrRu7zk8v6NR/n
FJlqzJifc2PjR4/MX/JWz/Dol2YU+61Y3T5T3phN61l+XHAr3ejWZnVUSkiQ
PGuO7hNxLcN43vpppwKrP5rbJm7N9yq/g/AJuNX7eXKwfN0/6PaGFk5ipFPK
rphuTjI6uuaidW2cRMk/p5aY1TpULvrt+rfhhZ1F3e9rDUsc6ypfVim28X2s
s9hb769gy2pPmRI4otGQ3a4i9tcdZvHBuaTjv2W2JnV1F0f/aBlV4KyvXLnm
1O8Tr7uLB3E1dw39KlxePVCmRIlbnuKeQ/B8c3yAbNFwQNEf0z1FsTrvmvde
bZFfn89zu02oj1j9uMSgQqeDpePb0WXKFPcTN9NGusdWjJJ1N1ZIc1vpLxZU
bdyg8ftQmffA8B7Nl/uL8kdnW2aWyyX7XouqNmZFgPg7znvlw5homV6kZaXQ
TYHi3up7rywjw2Wpb4Tr5MWBwpLk1Hjj0Gh5vmrBY2s2B4n4vRsaOE2IFm3O
tooatP3/r8/FuJUZHy2/a+x+a/U22/XJiKUDn0ZsC5KlanT3f37Ldj/iltZ1
26780pVO3DmwpWaQKN57x9DOidFyYeGnY41JQWJcx4d/yb+/vL77uUFp/7NI
6d9pWdy5aJm4q82Gov+ziPQfP8x7ejNatCpeYenpibb7jWY7dZjYeKpFdhpY
p2DTwGhpNPspd8+pQeKVz3KPKd1t88vc3xI40uG1+/Igsf5Fg+UrD9juR8w1
aUsz/33Z70dMihkxM3xFkFxXvlBQxPHs9yOmXjw2sshkW1+bPjJv67VBov7i
gSdvu9juRwz6+691jz5HicIVti1IeRMgex1LK7h7ve3fn8xf8/OuqrNyivqX
co6LLeYm46efii5exfbvNXq1b5zhUtgi6j2bX6X9iE/mV4mJXVt2sP17hUer
/Dj5cj0X8eOS4g3mJCSZMQOmvG5w1vbv5e12KWZE30oyr6bf7/75y/g38Oy+
vQ0n2f59tGVLPcJ+XpFHzjbmbjNe+OnxyP/+be0RG2wRgyfE5vzlbvb7Bc3I
JbGxIRa569Dc5IlVIkVEk4Q3zk2/rL/YSqe2lIwWx67sFQmNA+XoKRNdMsbb
/n3RGE/HkCGBeUTDzP/6yS3frUqKKZ9HvDwZVL9ZAz+58XBsg49Nc4nRbQ/7
7SrjLgN8xlQ/6ZBLPDo4bm7USTcZdsbrfv4bFrHW8dWd8KoZZo5Gkybf+dUi
Bg180evZxs/mhrOF2uY5a/v3KcfHF63ULOG6kdNxzeAywW/MHTfd5s9p5Cqu
pK8csLjYXXP5pgFt6glX8XJqfEhN37vmsnex5bd1sP37iWWb+edKa+Iqu93d
MbZH6bvGuI/xo8YIV1kkqdDfl33uGstHLSowIOG6uXfam6Elgt8YQ/KfHnqv
iu3fF2zoX2zpxUSLbBBXusnwmhmGl9u2bk1WWWS3D8t+C9342Qj3n3rBe6Pt
3+ebde/RugGtc8mJ4/L0KVDRXczrVkjMc8wle35/efa3X3x0mDvg6tSwPNI/
879+wnv7xG6nv8oj5w4ve+y/en5idfOVPT662u7ve3Zmj/OqUtFy0bzKOc42
ChTVnfO4fKgaKa8WHtGzwTcWMemnm9c2eUeL3M1v9PSdFSTDZuWZca9QtIi5
4HoqckmQbJt2pXWH7bbrw+x/hfKnXpq6NkguSRl3MGpoHlGh+7bN7RMs8qe7
z09nfIy0Xf9W9+dN/mF5vdU7bff7tRtXd0bF/ywyot/YiiHxtvv/HJ91Sf0x
Nlr45huwI5+zRfbbnMth0uVIfX34fpOHTgXv5hKlb99y9snhIZsPqtKpc2nb
/Xz8vubh5mNVdhf1kNdd13c6OfPLcabrr5aOsQ7Sb3Dq0gdJtvv5+D1N0YhV
bbttdJCV/DzHzpxwUd/fx+9NboZXfVHc8425fHHtR58Kuov21SrcdIx/aG6r
7ehUJNF2fx+/p6k/6vTW/aUfmRHdf5hzJY+bvn+hUvONz2ruP2reDqtyvcbl
l8abFfsvHnXaqu/v4/eM38/8utDdDS+NCqXHxW72D9K/xx/5VYdqjgNy6fOX
W+4r/hfUIVKuif8mf6McvuJx1NxS3vlt9/dxvT84YWjzyb/7iIRy3U/VbGq7
34/jY6u/Oi3f+63t98wZ7XLsWD3GIjqNj3Er2dB2P6CDb98X59dEyB0Nk/I3
slhEmzzjoqI7Ron4lBaTB5QIkj+5ru8X8iC3WHMk+f2LmEB54MDhJa/W5BT3
nH/ZXOG7AFnkp1VNYvuECv9aNxetbu8vr2c4PGzh9GWV1TUabmrkL+8cXFQu
oXqwKDew1D8DN/nKmT82HOYcZhEtUx+FL57nLX32LP70NCZSDPJt+XKQs68c
caJrDd8v47jSF6snpQ3ylOervfjnzNHcolPrVX131/CU0VuPz9kjfUTXd0Xv
L2zmLv8d0PZZ4V88xLkzfx+pXdhV+l28fCTfMBfh0HzMvZ3pOeS7742CY8uF
ibNLipW/1MZFpsb9G3SgSajY43Xcq2keZ9l3d8Sbqd85imWL6rbtecZR/j5Z
/iCHBouDDb6pu/N3R/lu1JjmFxZ/MKrMOhF0tFSGOW7L9ZMfx70yPP8bONDh
6Adzafp/FafcuWcMW/v16tLN35oRe99UX50QIC55PfSr9ezLeX2xmX9dO+on
vtmb5+q4MqlmoTWb/ueS6CPqDOr/wx//vjKdcjncarL/qNEirnzRL9uPmebl
fLCvr6cIfHIzT/Ouyeae4xVK/3jtsjly3dNZXuufmA2HuJ9rFv/E/Nc59F9z
8X/m60+l2+arlmquM15+kN4XzIWnb4bERr03a+19u3F7nDQLHA08+7Szk/Bt
1cI0dl0y1085eK7qTw6yV83zRxqkHzOulVw78qLjJyMkyOts69MLzA8HCvgP
a+Ys5//WfHSf+zeNgHUvf01s/NI4sOdw29lRNwzLqtxtUy7dMbaWPBF7KM8D
Y3Q79wP1C7nLFQe3G30PPDQaX3T4NNEj3li54FLbfYVfGD18k5OLvPWS56ot
Oe8Ym2I0bZLgMPWCv6zqdzjkv9lpRpfJlzst2BkoJ3wVL143+GiE9I+8k/tF
svl3szq9V894Z/Qs/di/xcy35tlHY75Ofv/RmNQpZGrjuCB52aNk8tUpDuL8
uHaHbv322TyyeV+vx7scRK8p/R6v7xoiC2zv+Sko2Ukcc+13u1nvHHL6hR7h
5+46iT/cc5ZZmiunzBeT63unOa6i8Mqfem6MdZO+54c3qhLoIsabgXdSN3vJ
UM+qE3+r5ibm5N7UPPxeLhkbELk/xMlDdOnht2fwNT95a1zTWeO7eoi7pX9o
3n1DuOxx4lWRbqO9RJEnh++kTYiQ1Qd2uxguvcWqmcEPm7oHynwDWw1ynOQl
7o1dkbi2aJAMadAppdYKH7FvePDRNq1C5MicI8cW/HLe+N2dBTda942SXiFz
Xv8vxV/Urrr8YLG/o+Tu/n135loZIEo0yZ/7SmyYXO6W0ThPor+I7dMs9NnR
XHJGx93ut7+cj/c/EX+r9NRoubpBzhOdc1iEb4Uf5k8dlkeOqlnF2CQtYt/d
2KRXPhFyVmxSx0JXAsWO+4/GJnpHiLlTdvjuvhIoHYr+vffBkVyiydjXlbsm
Bsij5W5d6PlXlCg7rOiSxJUBcm3lIjcfTwkTXeaN7rsw0V+6NuifsatPlPh+
x96/+730l5emDlk+o2WI6OCZa/3rnX5yyFdxLmlFgsSUnwecSlnhI5fdD/Y8
PT5CnBnqvaVRgrf8FPpj7yNugeLE/Y8vZk/ykqPl+ct91oeLcxWnre84xkv+
OqZQ3QVX/YQcfPRoSlcP2fuOy8AGm71EvuFfH8yo5iYbnnKddzlnTrFwafEc
J+e4ymvVGswqHOsm9jv4/D4i0EUmJTyY8K5XDjF6cLFG6Xed5PTg3V0CuoYI
58gCU35LdpLjyw4v0/e3z0bI5xLerrsdZL2GJzL8Zr41Etv7NfT58NEsnX5n
fJmdgeJuvRWf4ht+NAututzm9vNkY+bkq3E7Z7wz80/oF1D+gr+Ys7Fzauyc
NLOSb/h3OT3izQ7175vbC78wB1aUg46leoljlhMNesSmmB3e7fa5femOee7G
vP9253lg/pe0p/iX/ctsU6LmwFlRN0y/j0O7NWrmLKot8S6W68FN89659jvy
/uQgBqYcPx748Zh5tHa51DeOn8z4b91Huh5fYLxzed3tp6j3RqtfNoV5xElj
QmDPJJ8uTnJ5yKe++3deMvJ9X+q73NVSDSeP5647vS8YhveV6h3inxitz4/5
+dji/4ztaxtuOebrKdcebFp9dZdkI71Cietzr102ztYoMjxo/RPj6/7FWo1I
9JHFNiTfrP/vK2PBRqev+h/zk76VNvV/XDrVuH3mz54b79wze+zwCC7c/K1R
KDau6ceEAJnQ40ByXPJ748i+6l2LjX9lPv63RoHHRz4Yb5ufvFdkyQez6pro
M4tKZRhnAzP6Nh4WLDce8q2R73dH8a2l4+dz3znKAg8Ktqx9xlFEuFYq3vKb
UDnz555vdkc6i0ubKs6ePcxFruh+duyo9Bzin4vDc1cvHyZTir40gtq4iKcF
688//IuHPJlypf+HQq6iT8Ecg0Yk+MjqVeNel23mLj7vauFz7FhuWSapWvmD
wlP0TpjxMe69vzSuBecfMchTOD7IN3V1mEUmjvbzSZ/rLZpG7C41xgiWJ/yC
ru3b6Cvm9q/exiFHlGx0xfHGh4b+4kX0nMbf9w2V2550Cy3X3l90dp90NXlt
Tjm3w96Zv3cMEH5lihsFH+aWLUsUCewZEyj+D/yb7GY=
     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[1, 0, 0], Opacity[0.5], CapForm["Butt"], 
          LineBox[CompressedData["
1:eJwl1nfcj1UYx/GfLRGSImVUosfMKKRCCkkks2RVUsoWESEjlMqKkD1ShLLJ
JjORlT3LyoqE6H29+uPz+lzX+Z773Of53fd9Xk+epq1qtkyWSCS6JE8kJhRM
JMZgHMbiYfyYlEh8wIULJBLduBDXxw11PU6FJeYs07+kLoKGuKl/hdNgmXy5
vpH6YbyKZIUSiaacFsvlK+SvqYvhTaSQN+d0WClfJX9LXQJvI6W8Bd+KVfLV
8nfUJdEWqeVtOD3WyNfK26kfQae4r7wj34af5Ovk76lL4X3cIu/CmbBevl7e
VV0aPeK+8u6cGRvkG+Q91WXQJ+4r7823Y7N8s7yvuiw+jvvKB/Ad2CLfIv9E
/QQ+Q0b5p3wntsp/kX+ufhJD477yIXwXtsm3yoepy+EjdXnux9PxLcpip3k7
eFTcl7/iLNYZzY/rd8t38Xh9Vp4Ylk+Ifen3yHfz5NgXTw3Lp8S+9Hvlv/E3
sS/OwfuM7Yk9qCtiFrK7ZibfgwPyffLZ6qcxDznkc/leHJIfkM9XPxO/nXpg
/FaYhYo4as5hXiq/m5dzTmssizX1x+VHeXWszWs5t3xNrKmvhPXqPMbW8X34
wzXHjG9QV8XPuF++OYwT8uPyLern4pmpB8Uzwhw8i9PmnIjfPfYTvy8/aI1d
cY3+T/kp3hf74QOcX76fn9dX46NIMnaEH8A515yRHYs5GKweiiGYixdw0Zxz
cf+4Ju7Dhaxxhl/UX5Jf4AuxH87Ll41djGvV1TFfvQDz8HfMwxVzhum/QGd0
wfX4pq19jevqr5nzNyeQhHzGrxu7ok6GGvrhsU8ewYuwMM4O3DTvGqeNcwb5
zWkZ33WcDXhR35iboClaIbmxhpyCG3BzvIk3kCHOjDi7UAS3Ij1qxfcde499
qh/CYvUSfImacQbE2Yd0+Df2buxlTo0S/t40XBCpcBU37L1+7APF5Sm5QOwP
/8Qa8noxL844+c24b4zHbx9ryOvEXH1R+dV4F/RX+FKMy2vHs9MXkV/mfPq/
+K94RvJafE5fWH6e8+rP8vmYJ6/JJ/UF5afiPdaf4LPxLshr8O/6AvI/4juI
b4f/5PPy6nwo9i0/HN+L/iCfjvvIq8UZEfuS7+Vc+t/4JJ+RV+XtsS/5jvi+
9b/Gt8an5FV4a7yz8m1xPuh/4d9j3/LKvDH2Jd/E7+k7xbem/jT2bk4e9U+Y
rf8B36OKfhWOxHdjTm71itifdVZyZfwYZ438iDxXvA+xP/kSroRFOCg/LM+p
XhD7ky/kp4xXiPvF+WNsTpxxcW/eH7+Ra8rzDH02+Xdh/XTey/vl5fjrODfl
07ij/l0MQP/4Hc252/gkzNDPxHd4Sj8OO9W7zMmuHoM7rDOWK2Aktst3yLOp
s8R7zr/G8zD2GA/X3+6aEeH4xnlbPB95GR6kzyQfzB307dEXfeIZmZPV+EB8
rf8G0/C4vn+cneqfzcmi/ggZrNOPH0MvbJJvkmfmTPjQ2MZ41sZKczd9Otd8
wO30bdEbvbDOnIzGO2Oyfiqm4FH9u/EuqNeak0HdHmms04FLxZw4Q9SpjLXm
jPqWvIZXu+YRnoSesSf0iG9b/gZWqleYc4v6dSS3RjMuGecDGqsTxppwG31r
FFV356WuSx3nCSbqG3BxLoZmqKt/Nc4X7hrnSNyDv8JovIJGSBnvpbXeVo/C
SNQ21oKT4hzhxfKlXEd/G48v+P//ef8BHkmupQ==
           "]]},
         "2.990100000554607`"],
        Annotation[#, 2.990100000554607, "Tooltip"]& ], {}, {}}}], {}}},
  AspectRatio->0.5,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-0.0005, 0.0005}, {-0.00025, 0.00025}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.890906795606677*^9, 3.890906817950479*^9}},
 CellLabel->"Out[20]=",ExpressionUUID->"a35381cf-f9fb-40f9-9231-0cbe7b01da28"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{951, 637},
WindowMargins->{{84, Automatic}, {Automatic, 33}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"a890c4dc-d51a-4bdc-9bcf-b48a844a0a37"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"2f94b440-0b22-4549-b621-663571594013"],
Cell[948, 30, 96, 0, 67, "Section",ExpressionUUID->"cd88c690-521f-4a4c-89d1-d50dc4c2e993"],
Cell[1047, 32, 391, 11, 72, "Text",ExpressionUUID->"22138f82-0454-4f6e-a6ad-84b75922f3f4"],
Cell[1441, 45, 18462, 488, 1606, "Input",ExpressionUUID->"11f557bb-9f19-4495-b68f-312ee23bfca5"],
Cell[19906, 535, 216, 6, 53, "Text",ExpressionUUID->"1aaca9fd-8d64-4bdf-93bd-0c9a00847cff"],
Cell[CellGroupData[{
Cell[20147, 545, 313, 6, 30, "Input",ExpressionUUID->"986f690b-3764-4de8-9c1b-f10617aa1ca7"],
Cell[20463, 553, 383, 9, 44, "Print",ExpressionUUID->"fae314b1-e9b8-4556-8f7d-ec60101da6ab"],
Cell[20849, 564, 384, 9, 44, "Print",ExpressionUUID->"804e8b71-0b1e-49f9-b290-e052472f133d"],
Cell[21236, 575, 468, 11, 44, "Print",ExpressionUUID->"a2ba7201-51d9-4540-9bd4-323cb544dc28"],
Cell[21707, 588, 217, 4, 24, "Print",ExpressionUUID->"559e1d09-f9c0-459c-9307-2c4e6884f309"],
Cell[21927, 594, 1334, 35, 102, "Print",ExpressionUUID->"3ac98d6d-d8a1-44b0-91a9-8e6540e5e594"],
Cell[23264, 631, 229, 4, 44, "Print",ExpressionUUID->"c6dd3b3b-ff04-43e1-9b1e-ce54d0da0818"],
Cell[23496, 637, 1200, 28, 76, "Print",ExpressionUUID->"657365bb-6bca-4052-a2e2-e31c36af7cc4"],
Cell[24699, 667, 227, 4, 44, "Print",ExpressionUUID->"0c15eebe-1b9e-4709-80b6-658a4744bfc5"],
Cell[24929, 673, 1201, 28, 76, "Print",ExpressionUUID->"061659e2-1b04-430d-a372-7d8a2bf41bb8"],
Cell[26133, 703, 212, 4, 44, "Print",ExpressionUUID->"c9e89a72-843b-45f4-8fc9-6d08f2932e82"],
Cell[26348, 709, 1348, 32, 69, "Print",ExpressionUUID->"d5032ad2-c676-48e5-bd4b-92eb24aed269"],
Cell[27699, 743, 214, 4, 44, "Print",ExpressionUUID->"72e84018-5ba5-486f-99ec-1f26755066f0"],
Cell[27916, 749, 2132, 47, 88, "Print",ExpressionUUID->"2e27b077-bf11-4bc3-b9d1-521cc24d55fc"]
}, Open  ]],
Cell[30063, 799, 565, 15, 99, "Text",ExpressionUUID->"490dc328-b641-479c-9f8b-048489a96aef"],
Cell[30631, 816, 757, 22, 52, "Input",ExpressionUUID->"0eef0f29-318f-4c4a-bb18-46fee837af82"],
Cell[CellGroupData[{
Cell[31413, 842, 143, 2, 30, "Input",ExpressionUUID->"6c319b7c-3a26-4433-bf72-87f84f0c086a"],
Cell[31559, 846, 705, 20, 63, "Output",ExpressionUUID->"d0652c5c-15e7-4613-9285-ab92fde2a3cb"]
}, Open  ]],
Cell[32279, 869, 348, 11, 53, "Text",ExpressionUUID->"c3ea4aca-8947-405a-8563-68dabe003e3c"],
Cell[CellGroupData[{
Cell[32652, 884, 477, 12, 30, "Input",ExpressionUUID->"96e1baa3-d4ec-45ab-ab74-7f1915b35971"],
Cell[33132, 898, 768, 19, 56, "Output",ExpressionUUID->"a6565ba6-80d9-419c-b10e-d6d6fc9fed56"]
}, Open  ]],
Cell[33915, 920, 383, 8, 76, "Text",ExpressionUUID->"89218f8e-d4b2-4db6-93ff-ac9e365124e6"],
Cell[CellGroupData[{
Cell[34323, 932, 169, 2, 30, "Input",ExpressionUUID->"88a1ef3e-9959-4db8-865c-e051331867ce"],
Cell[34495, 936, 187, 2, 34, "Output",ExpressionUUID->"994525ab-7e06-4526-ab56-5ec19c7b6923"]
}, Open  ]],
Cell[34697, 941, 242, 6, 53, "Text",ExpressionUUID->"7585e019-be2f-4dd6-8df2-272641ccd667"],
Cell[CellGroupData[{
Cell[34964, 951, 909, 25, 115, "Input",ExpressionUUID->"29c1c606-cf35-4f68-8504-18950ccfe9b2"],
Cell[35876, 978, 50860, 845, 197, "Output",ExpressionUUID->"098368ff-00a3-4c51-8feb-19baf8675152"]
}, Open  ]],
Cell[86751, 1826, 467, 14, 76, "Text",ExpressionUUID->"9d1875ef-bbd4-46f4-9c19-380aefe1761e"],
Cell[87221, 1842, 1489, 42, 115, "Input",ExpressionUUID->"f9de7783-a154-439d-a9fe-3ef44dfcce95"],
Cell[88713, 1886, 521, 14, 76, "Text",ExpressionUUID->"f8e2428b-d941-4728-b6aa-54a5f4e9cbc5"],
Cell[89237, 1902, 1699, 49, 94, "Input",ExpressionUUID->"f0938003-53e6-4a44-8930-a2989c1dd690"],
Cell[90939, 1953, 287, 8, 53, "Text",ExpressionUUID->"7e5af23e-3594-45b7-ab02-f82d9baeb051"],
Cell[CellGroupData[{
Cell[91251, 1965, 432, 10, 30, "Input",ExpressionUUID->"81acda16-68dd-416a-8984-c882e0f4f55d"],
Cell[91686, 1977, 188, 2, 34, "Output",ExpressionUUID->"e2e5f575-3d30-4495-ae23-0b7b36c221ce"]
}, Open  ]],
Cell[91889, 1982, 201, 5, 53, "Text",ExpressionUUID->"e6417aae-5254-4a2f-8f40-8a4bad80feed"],
Cell[92093, 1989, 908, 21, 115, "Input",ExpressionUUID->"0a7096ed-afa3-448c-882b-ca1a0285aa93"],
Cell[93004, 2012, 277, 6, 76, "Text",ExpressionUUID->"d44321c0-761b-4129-af36-bfc1a9ee77ec"],
Cell[CellGroupData[{
Cell[93306, 2022, 560, 12, 73, "Input",ExpressionUUID->"f30d5b27-bcca-4c30-80bb-4a10c98973a8"],
Cell[93869, 2036, 102694, 1703, 242, "Output",ExpressionUUID->"38912042-d257-44cb-83bb-7102ae0464e5"]
}, Open  ]],
Cell[196578, 3742, 234, 6, 53, "Text",ExpressionUUID->"4573b8b5-96b4-4063-8f7f-b25d45eb5d64"],
Cell[CellGroupData[{
Cell[196837, 3752, 180, 2, 30, "Input",ExpressionUUID->"be2f87a0-e0bd-44bd-9ce9-c580bfd23841"],
Cell[197020, 3756, 769, 19, 56, "Output",ExpressionUUID->"c5505bb6-c159-4554-a75d-aee79ad4a558"]
}, Open  ]],
Cell[197804, 3778, 202, 5, 53, "Text",ExpressionUUID->"ec29e408-dfa5-4c6a-974b-dc2baa341608"],
Cell[198009, 3785, 225, 4, 30, "Input",ExpressionUUID->"eb32ef30-6600-4a7c-baa7-19d2df08f5d3"],
Cell[198237, 3791, 254, 6, 53, "Text",ExpressionUUID->"6b2ef736-dccf-4bf4-bb07-b5df06f8d4ea"],
Cell[CellGroupData[{
Cell[198516, 3801, 550, 13, 52, "Input",ExpressionUUID->"061b4cf0-a751-4e74-9a89-e3054c04611b"],
Cell[199069, 3816, 230, 4, 34, "Output",ExpressionUUID->"c19e1ea1-553b-44d4-9826-d2353f7357ab"]
}, Open  ]],
Cell[199314, 3823, 252, 6, 53, "Text",ExpressionUUID->"5996ea6a-c8c6-49be-ace8-c7e1b675b92b"],
Cell[CellGroupData[{
Cell[199591, 3833, 721, 20, 52, "Input",ExpressionUUID->"9af4c738-a04f-4089-98ff-07b79f642525"],
Cell[200315, 3855, 382, 10, 34, "Output",ExpressionUUID->"83f7e34e-8fa2-41b4-b764-05caa2ea01a6"]
}, Open  ]],
Cell[200712, 3868, 343, 9, 76, "Text",ExpressionUUID->"0d34882a-64b0-4949-8a98-e42b341f1d66"],
Cell[CellGroupData[{
Cell[201080, 3881, 1124, 28, 178, "Input",ExpressionUUID->"2698cc96-8815-4182-abaa-d1aff2bebf0b"],
Cell[202207, 3911, 17533, 302, 280, "Output",ExpressionUUID->"0a73c1f3-5d61-4afb-a28f-56bc763f7d95"]
}, Open  ]],
Cell[219755, 4216, 224, 6, 53, "Text",ExpressionUUID->"660cbb8f-67bb-4c08-98f5-3c78d11fefb8"],
Cell[CellGroupData[{
Cell[220004, 4226, 958, 23, 136, "Input",ExpressionUUID->"09a22c75-6234-4b53-8761-b2ddca896b4d"],
Cell[220965, 4251, 12974, 226, 240, "Output",ExpressionUUID->"980ddeab-eebb-4250-b4cc-ef0b06805631"]
}, Open  ]],
Cell[233954, 4480, 241, 6, 53, "Text",ExpressionUUID->"6029bef1-5767-42f0-a479-30e8f111f07d"],
Cell[CellGroupData[{
Cell[234220, 4490, 841, 21, 94, "Input",ExpressionUUID->"46730cf9-75fc-4ec2-b8eb-8e0e17a771a3"],
Cell[235064, 4513, 29367, 498, 197, "Output",ExpressionUUID->"c318c276-9f91-43e0-9be7-fb5dad9af96b"]
}, Open  ]],
Cell[264446, 5014, 292, 7, 53, "Text",ExpressionUUID->"b6fd9db9-cbc9-4ee4-81dc-7781a2cc3ab4"],
Cell[CellGroupData[{
Cell[264763, 5025, 250, 4, 30, "Input",ExpressionUUID->"400a67fc-1b34-44d2-b40f-216da38343c5"],
Cell[265016, 5031, 130884, 2164, 197, "Output",ExpressionUUID->"a35381cf-f9fb-40f9-9231-0cbe7b01da28"]
}, Open  ]]
}
]
*)

